︠21ebfe83-c697-4d65-997d-40dd9d19c405︠
def bisect_method(f, a, b, eps):
    try:
        f = f._fast_float_(f.variables()[0])
    except AttributeError:
        pass
    intervals = [(a,b)]
    two = float(2); eps = float(eps)
    while True:
        c = (a+b)/two
        fa = f(a); fb = f(b); fc = f(c)
        if abs(fc) < eps: return c, intervals
        if fa*fc < 0:
            a, b = a, c
        elif fc*fb < 0:
            a, b = c, b
        else:
            raise ValueError, "f must have a sign change in the interval (%s,%s)"%(a,b)
        intervals.append((a,b))
html("<h1>Double Precision Root Finding Using Bisection</h1>")
@interact
def _(f = cos(x) - x, a = float(0), b = float(1), eps=(-3,(-16..-1))):
     eps = 10^eps
     print "eps = %s"%float(eps)
     try:
         time c, intervals = bisect_method(f, a, b, eps)
     except ValueError:
         print "f must have opposite sign at the endpoints of the interval"
         show(plot(f, a, b, color='red'), xmin=a, xmax=b)
     else:
         print "root =", c
         print "f(c) = %r"%f(c)
         print "iterations =", len(intervals)
         P = plot(f, a, b, color='red')
         h = (P.ymax() - P.ymin())/ (1.5*len(intervals))
         L = sum(line([(c,h*i), (d,h*i)]) for i, (c,d) in enumerate(intervals) )
         L += sum(line([(c,h*i-h/4), (c,h*i+h/4)]) for i, (c,d) in enumerate(intervals) )
         L += sum(line([(d,h*i-h/4), (d,h*i+h/4)]) for i, (c,d) in enumerate(intervals) )
         show(P + L, xmin=a, xmax=b)
︡0538c1ec-7ae6-4d94-b2bd-f38dc0f5af49︡{"html": "<font color='black'><h1>Double Precision Root Finding Using Bisection</h1></font>"}︡{"html": "<!--notruncate--><div padding=6 id='div-interact-0'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"\n                                  cos(x) - x\" size=80 onchange='interact(0, \"sage.server.notebook.interact.update(0, \\\"f\\\", 1, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(0)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">a&nbsp;</font></td><td><input type='text' value=\"0.0\" size=80 onchange='interact(0, \"sage.server.notebook.interact.update(0, \\\"a\\\", 2, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(0)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">b&nbsp;</font></td><td><input type='text' value=\"1.0\" size=80 onchange='interact(0, \"sage.server.notebook.interact.update(0, \\\"b\\\", 3, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(0)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">eps&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-eps-0' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-eps-0-lbl'></font></td></tr></table><script>(function(){ var values = [\"-16\",\"-15\",\"-14\",\"-13\",\"-12\",\"-11\",\"-10\",\"-9\",\"-8\",\"-7\",\"-6\",\"-5\",\"-4\",\"-3\",\"-2\",\"-1\"]; setTimeout(function() {\n    $('#slider-eps-0').slider({\n    \tstepping: 1, min: 0, max: 15, startValue: 13,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-eps-0-lbl').text(values[position]); interact(0, \"sage.server.notebook.interact.update(0, \\\"eps\\\", 4, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(0)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-eps-0-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-eps-0-lbl').text(values[$('#slider-eps-0').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-0'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠b62dd0c0-f946-4ef7-b25e-2e1dbd8497c1︠
def newton_method(f, c, eps, maxiter=100):
    x = f.variables()[0]
    fprime = f.derivative(x)
    try:
        g = f._fast_float_(x)
        gprime = fprime._fast_float_(x)
    except AttributeError:
        g = f; gprime = fprime
    iterates = [c]
    for i in xrange(maxiter):
       fc = g(c)
       if abs(fc) < eps: return c, iterates
       c = c - fc/gprime(c)
       iterates.append(c)
    return c, iterates
html("<h1>Double Precision Root Finding Using Newton's Method</h1>")
@interact
def _(f = x^2 - 2, c = float(0.5), eps=(-3,(-16..-1)), interval=float(0.5)):
     eps = 10^(eps)
     print "eps = %s"%float(eps)
     time z, iterates = newton_method(f, c, eps)
     print "root =", z
     print "f(c) = %r"%f(z)
     n = len(iterates)
     print "iterations =", n
     html(iterates)
     P = plot(f, z-interval, z+interval, rgbcolor='blue')
     h = P.ymax(); j = P.ymin()
     L = sum(point((w,(n-1-float(i))/n*h), rgbcolor=(float(i)/n,0.2,0.3), pointsize=10) + \
             line([(w,h),(w,j)],rgbcolor='black',thickness=0.2) for i,w in enumerate(iterates))
     show(P + L, xmin=z-interval, xmax=z+interval)
︡b9bc7082-a1c3-4db9-abfc-79ed95886aab︡{"html": "<font color='black'><h1>Double Precision Root Finding Using Newton's Method</h1></font>"}︡{"html": "<!--notruncate--><div padding=6 id='div-interact-1'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"\n                                     2\n                                    x  - 2\" size=80 onchange='interact(1, \"sage.server.notebook.interact.update(1, \\\"f\\\", 5, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(1)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">c&nbsp;</font></td><td><input type='text' value=\"0.5\" size=80 onchange='interact(1, \"sage.server.notebook.interact.update(1, \\\"c\\\", 6, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(1)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">eps&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-eps-1' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-eps-1-lbl'></font></td></tr></table><script>(function(){ var values = [\"-16\",\"-15\",\"-14\",\"-13\",\"-12\",\"-11\",\"-10\",\"-9\",\"-8\",\"-7\",\"-6\",\"-5\",\"-4\",\"-3\",\"-2\",\"-1\"]; setTimeout(function() {\n    $('#slider-eps-1').slider({\n    \tstepping: 1, min: 0, max: 15, startValue: 13,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-eps-1-lbl').text(values[position]); interact(1, \"sage.server.notebook.interact.update(1, \\\"eps\\\", 7, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(1)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-eps-1-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-eps-1-lbl').text(values[$('#slider-eps-1').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">interval&nbsp;</font></td><td><input type='text' value=\"0.5\" size=80 onchange='interact(1, \"sage.server.notebook.interact.update(1, \\\"interval\\\", 8, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(1)\")'></input></td></tr>\n</table><div id='cell-interact-1'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠12ec6df1-b7c0-4420-97fb-b34eb73c31a1︠
@interact
def _(q1=(-1,(-3,3)), q2=(-2,(-3,3)),
      cmap=['autumn', 'bone', 'cool', 'copper', 'gray', 'hot', 'hsv',
           'jet', 'pink', 'prism', 'spring', 'summer', 'winter']):
     x,y = var('x,y')
     f = q1/sqrt((x+1)^2 + y^2) + q2/sqrt((x-1)^2+(y+0.5)^2)
     C = contour_plot(f, (-2,2), (-2,2), plot_points=30, contours=15, cmap=cmap)
     show(C, figsize=3, aspect_ratio=1)
     show(plot3d(f, (x,-2,2), (y,-2,2)), figsize=5, viewer='tachyon')
︡4f97a285-5e35-4447-b610-37bb22bddf63︡{"html": "<!--notruncate--><div padding=6 id='div-interact-2'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">q1&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-q1-2' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-q1-2-lbl'></font></td></tr></table><script>(function(){ var values = [\"-3.0\",\"-2.9879759519038078\",\"-2.9759519038076157\",\"-2.9639278557114235\",\"-2.9519038076152313\",\"-2.9398797595190391\",\"-2.927855711422847\",\"-2.9158316633266548\",\"-2.9038076152304626\",\"-2.8917835671342704\",\"-2.8797595190380783\",\"-2.8677354709418861\",\"-2.8557114228456939\",\"-2.8436873747495017\",\"-2.8316633266533096\",\"-2.8196392785571174\",\"-2.8076152304609252\",\"-2.795591182364733\",\"-2.7835671342685409\",\"-2.7715430861723487\",\"-2.7595190380761565\",\"-2.7474949899799643\",\"-2.7354709418837722\",\"-2.72344689378758\",\"-2.7114228456913878\",\"-2.6993987975951956\",\"-2.6873747494990035\",\"-2.6753507014028113\",\"-2.6633266533066191\",\"-2.6513026052104269\",\"-2.6392785571142348\",\"-2.6272545090180426\",\"-2.6152304609218504\",\"-2.6032064128256582\",\"-2.5911823647294661\",\"-2.5791583166332739\",\"-2.5671342685370817\",\"-2.5551102204408895\",\"-2.5430861723446974\",\"-2.5310621242485052\",\"-2.519038076152313\",\"-2.5070140280561208\",\"-2.4949899799599287\",\"-2.4829659318637365\",\"-2.4709418837675443\",\"-2.4589178356713521\",\"-2.44689378757516\",\"-2.4348697394789678\",\"-2.4228456913827756\",\"-2.4108216432865834\",\"-2.3987975951903913\",\"-2.3867735470941991\",\"-2.3747494989980069\",\"-2.3627254509018147\",\"-2.3507014028056226\",\"-2.3386773547094304\",\"-2.3266533066132382\",\"-2.314629258517046\",\"-2.3026052104208539\",\"-2.2905811623246617\",\"-2.2785571142284695\",\"-2.2665330661322773\",\"-2.2545090180360852\",\"-2.242484969939893\",\"-2.2304609218437008\",\"-2.2184368737475086\",\"-2.2064128256513165\",\"-2.1943887775551243\",\"-2.1823647294589321\",\"-2.1703406813627399\",\"-2.1583166332665478\",\"-2.1462925851703556\",\"-2.1342685370741634\",\"-2.1222444889779712\",\"-2.1102204408817791\",\"-2.0981963927855869\",\"-2.0861723446893947\",\"-2.0741482965932025\",\"-2.0621242484970104\",\"-2.0501002004008182\",\"-2.038076152304626\",\"-2.0260521042084338\",\"-2.0140280561122417\",\"-2.0020040080160495\",\"-1.9899799599198571\",\"-1.9779559118236647\",\"-1.9659318637274723\",\"-1.9539078156312799\",\"-1.9418837675350875\",\"-1.9298597194388951\",\"-1.9178356713427027\",\"-1.9058116232465103\",\"-1.8937875751503179\",\"-1.8817635270541255\",\"-1.8697394789579331\",\"-1.8577154308617407\",\"-1.8456913827655483\",\"-1.8336673346693559\",\"-1.8216432865731635\",\"-1.8096192384769711\",\"-1.7975951903807788\",\"-1.7855711422845864\",\"-1.773547094188394\",\"-1.7615230460922016\",\"-1.7494989979960092\",\"-1.7374749498998168\",\"-1.7254509018036244\",\"-1.713426853707432\",\"-1.7014028056112396\",\"-1.6893787575150472\",\"-1.6773547094188548\",\"-1.6653306613226624\",\"-1.65330661322647\",\"-1.6412825651302776\",\"-1.6292585170340852\",\"-1.6172344689378928\",\"-1.6052104208417004\",\"-1.593186372745508\",\"-1.5811623246493156\",\"-1.5691382765531232\",\"-1.5571142284569308\",\"-1.5450901803607384\",\"-1.533066132264546\",\"-1.5210420841683536\",\"-1.5090180360721612\",\"-1.4969939879759688\",\"-1.4849699398797764\",\"-1.472945891783584\",\"-1.4609218436873916\",\"-1.4488977955911992\",\"-1.4368737474950068\",\"-1.4248496993988145\",\"-1.4128256513026221\",\"-1.4008016032064297\",\"-1.3887775551102373\",\"-1.3767535070140449\",\"-1.3647294589178525\",\"-1.3527054108216601\",\"-1.3406813627254677\",\"-1.3286573146292753\",\"-1.3166332665330829\",\"-1.3046092184368905\",\"-1.2925851703406981\",\"-1.2805611222445057\",\"-1.2685370741483133\",\"-1.2565130260521209\",\"-1.2444889779559285\",\"-1.2324649298597361\",\"-1.2204408817635437\",\"-1.2084168336673513\",\"-1.1963927855711589\",\"-1.1843687374749665\",\"-1.1723446893787741\",\"-1.1603206412825817\",\"-1.1482965931863893\",\"-1.1362725450901969\",\"-1.1242484969940045\",\"-1.1122244488978121\",\"-1.1002004008016197\",\"-1.0881763527054273\",\"-1.0761523046092349\",\"-1.0641282565130425\",\"-1.0521042084168502\",\"-1.0400801603206578\",\"-1.0280561122244654\",\"-1.016032064128273\",\"-1.0040080160320806\",\"-0.99198396793588817\",\"-0.97995991983969577\",\"-0.96793587174350337\",\"-0.95591182364731098\",\"-0.94388777555111858\",\"-0.93186372745492618\",\"-0.91983967935873379\",\"-0.90781563126254139\",\"-0.89579158316634899\",\"-0.8837675350701566\",\"-0.8717434869739642\",\"-0.8597194388777718\",\"-0.84769539078157941\",\"-0.83567134268538701\",\"-0.82364729458919461\",\"-0.81162324649300222\",\"-0.79959919839680982\",\"-0.78757515030061742\",\"-0.77555110220442502\",\"-0.76352705410823263\",\"-0.75150300601204023\",\"-0.73947895791584783\",\"-0.72745490981965544\",\"-0.71543086172346304\",\"-0.70340681362727064\",\"-0.69138276553107825\",\"-0.67935871743488585\",\"-0.66733466933869345\",\"-0.65531062124250106\",\"-0.64328657314630866\",\"-0.63126252505011626\",\"-0.61923847695392387\",\"-0.60721442885773147\",\"-0.59519038076153907\",\"-0.58316633266534668\",\"-0.57114228456915428\",\"-0.55911823647296188\",\"-0.54709418837676949\",\"-0.53507014028057709\",\"-0.52304609218438469\",\"-0.5110220440881923\",\"-0.4989979959919999\",\"-0.4869739478958075\",\"-0.47494989979961511\",\"-0.46292585170342271\",\"-0.45090180360723031\",\"-0.43887775551103791\",\"-0.42685370741484552\",\"-0.41482965931865312\",\"-0.40280561122246072\",\"-0.39078156312626833\",\"-0.37875751503007593\",\"-0.36673346693388353\",\"-0.35470941883769114\",\"-0.34268537074149874\",\"-0.33066132264530634\",\"-0.31863727454911395\",\"-0.30661322645292155\",\"-0.29458917835672915\",\"-0.28256513026053676\",\"-0.27054108216434436\",\"-0.25851703406815196\",\"-0.24649298597195957\",\"-0.23446893787576717\",\"-0.22244488977957477\",\"-0.21042084168338238\",\"-0.19839679358718998\",\"-0.18637274549099758\",\"-0.17434869739480519\",\"-0.16232464929861279\",\"-0.15030060120242039\",\"-0.138276553106228\",\"-0.1262525050100356\",\"-0.11422845691384322\",\"-0.10220440881765083\",\"-0.09018036072145845\",\"-0.078156312625266067\",\"-0.066132264529073684\",\"-0.054108216432881301\",\"-0.042084168336688918\",\"-0.030060120240496535\",\"-0.018036072144304152\",\"-0.0060120240481117675\",\"0.0060120240480806171\",\"0.018036072144273003\",\"0.030060120240465386\",\"0.042084168336657769\",\"0.054108216432850152\",\"0.066132264529042542\",\"0.078156312625234925\",\"0.090180360721427308\",\"0.10220440881761969\",\"0.11422845691381207\",\"0.12625250501000446\",\"0.13827655310619685\",\"0.15030060120238925\",\"0.16232464929858165\",\"0.17434869739477404\",\"0.18637274549096644\",\"0.19839679358715884\",\"0.21042084168335123\",\"0.22244488977954363\",\"0.23446893787573603\",\"0.24649298597192842\",\"0.25851703406812082\",\"0.27054108216431322\",\"0.28256513026050561\",\"0.29458917835669801\",\"0.30661322645289041\",\"0.31863727454908281\",\"0.3306613226452752\",\"0.3426853707414676\",\"0.35470941883766\",\"0.36673346693385239\",\"0.37875751503004479\",\"0.39078156312623719\",\"0.40280561122242958\",\"0.41482965931862198\",\"0.42685370741481438\",\"0.43887775551100677\",\"0.45090180360719917\",\"0.46292585170339157\",\"0.47494989979958396\",\"0.48697394789577636\",\"0.49899799599196876\",\"0.5110220440881611\",\"0.52304609218435349\",\"0.53507014028054589\",\"0.54709418837673829\",\"0.55911823647293069\",\"0.57114228456912308\",\"0.58316633266531548\",\"0.59519038076150788\",\"0.60721442885770027\",\"0.61923847695389267\",\"0.63126252505008507\",\"0.64328657314627746\",\"0.65531062124246986\",\"0.66733466933866226\",\"0.67935871743485465\",\"0.69138276553104705\",\"0.70340681362723945\",\"0.71543086172343184\",\"0.72745490981962424\",\"0.73947895791581664\",\"0.75150300601200903\",\"0.76352705410820143\",\"0.77555110220439383\",\"0.78757515030058622\",\"0.79959919839677862\",\"0.81162324649297102\",\"0.82364729458916341\",\"0.83567134268535581\",\"0.84769539078154821\",\"0.8597194388777406\",\"0.871743486973933\",\"0.8837675350701254\",\"0.8957915831663178\",\"0.90781563126251019\",\"0.91983967935870259\",\"0.93186372745489499\",\"0.94388777555108738\",\"0.95591182364727978\",\"0.96793587174347218\",\"0.97995991983966457\",\"0.99198396793585697\",\"1.0040080160320493\",\"1.0160320641282417\",\"1.028056112224434\",\"1.0400801603206264\",\"1.0521042084168188\",\"1.0641282565130112\",\"1.0761523046092036\",\"1.088176352705396\",\"1.1002004008015884\",\"1.1122244488977808\",\"1.1242484969939732\",\"1.1362725450901656\",\"1.148296593186358\",\"1.1603206412825504\",\"1.1723446893787428\",\"1.1843687374749352\",\"1.1963927855711276\",\"1.20841683366732\",\"1.2204408817635124\",\"1.2324649298597048\",\"1.2444889779558972\",\"1.2565130260520896\",\"1.268537074148282\",\"1.2805611222444744\",\"1.2925851703406668\",\"1.3046092184368592\",\"1.3166332665330516\",\"1.328657314629244\",\"1.3406813627254364\",\"1.3527054108216288\",\"1.3647294589178212\",\"1.3767535070140136\",\"1.388777555110206\",\"1.4008016032063983\",\"1.4128256513025907\",\"1.4248496993987831\",\"1.4368737474949755\",\"1.4488977955911679\",\"1.4609218436873603\",\"1.4729458917835527\",\"1.4849699398797451\",\"1.4969939879759375\",\"1.5090180360721299\",\"1.5210420841683223\",\"1.5330661322645147\",\"1.5450901803607071\",\"1.5571142284568995\",\"1.5691382765530919\",\"1.5811623246492843\",\"1.5931863727454767\",\"1.6052104208416691\",\"1.6172344689378615\",\"1.6292585170340539\",\"1.6412825651302463\",\"1.6533066132264387\",\"1.6653306613226311\",\"1.6773547094188235\",\"1.6893787575150159\",\"1.7014028056112083\",\"1.7134268537074007\",\"1.7254509018035931\",\"1.7374749498997855\",\"1.7494989979959779\",\"1.7615230460921703\",\"1.7735470941883626\",\"1.785571142284555\",\"1.7975951903807474\",\"1.8096192384769398\",\"1.8216432865731322\",\"1.8336673346693246\",\"1.845691382765517\",\"1.8577154308617094\",\"1.8697394789579018\",\"1.8817635270540942\",\"1.8937875751502866\",\"1.905811623246479\",\"1.9178356713426714\",\"1.9298597194388638\",\"1.9418837675350562\",\"1.9539078156312486\",\"1.965931863727441\",\"1.9779559118236334\",\"1.9899799599198258\",\"2.002004008016018\",\"2.0140280561122101\",\"2.0260521042084023\",\"2.0380761523045945\",\"2.0501002004007867\",\"2.0621242484969788\",\"2.074148296593171\",\"2.0861723446893632\",\"2.0981963927855554\",\"2.1102204408817475\",\"2.1222444889779397\",\"2.1342685370741319\",\"2.1462925851703241\",\"2.1583166332665162\",\"2.1703406813627084\",\"2.1823647294589006\",\"2.1943887775550928\",\"2.2064128256512849\",\"2.2184368737474771\",\"2.2304609218436693\",\"2.2424849699398615\",\"2.2545090180360536\",\"2.2665330661322458\",\"2.278557114228438\",\"2.2905811623246302\",\"2.3026052104208223\",\"2.3146292585170145\",\"2.3266533066132067\",\"2.3386773547093989\",\"2.350701402805591\",\"2.3627254509017832\",\"2.3747494989979754\",\"2.3867735470941676\",\"2.3987975951903597\",\"2.4108216432865519\",\"2.4228456913827441\",\"2.4348697394789363\",\"2.4468937875751284\",\"2.4589178356713206\",\"2.4709418837675128\",\"2.482965931863705\",\"2.4949899799598971\",\"2.5070140280560893\",\"2.5190380761522815\",\"2.5310621242484737\",\"2.5430861723446658\",\"2.555110220440858\",\"2.5671342685370502\",\"2.5791583166332424\",\"2.5911823647294345\",\"2.6032064128256267\",\"2.6152304609218189\",\"2.6272545090180111\",\"2.6392785571142032\",\"2.6513026052103954\",\"2.6633266533065876\",\"2.6753507014027798\",\"2.6873747494989719\",\"2.6993987975951641\",\"2.7114228456913563\",\"2.7234468937875485\",\"2.7354709418837406\",\"2.7474949899799328\",\"2.759519038076125\",\"2.7715430861723171\",\"2.7835671342685093\",\"2.7955911823647015\",\"2.8076152304608937\",\"2.8196392785570858\",\"2.831663326653278\",\"2.8436873747494702\",\"2.8557114228456624\",\"2.8677354709418545\",\"2.8797595190380467\",\"2.8917835671342389\",\"2.9038076152304311\",\"2.9158316633266232\",\"2.9278557114228154\",\"2.9398797595190076\",\"2.9519038076151998\",\"2.9639278557113919\",\"2.9759519038075841\",\"2.9879759519037763\",\"3.0\"]; setTimeout(function() {\n    $('#slider-q1-2').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 166,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-q1-2-lbl').text(values[position]); interact(2, \"sage.server.notebook.interact.update(2, \\\"q1\\\", 9, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(2)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-q1-2-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-q1-2-lbl').text(values[$('#slider-q1-2').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">q2&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-q2-2' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-q2-2-lbl'></font></td></tr></table><script>(function(){ var values = [\"-3.0\",\"-2.9879759519038078\",\"-2.9759519038076157\",\"-2.9639278557114235\",\"-2.9519038076152313\",\"-2.9398797595190391\",\"-2.927855711422847\",\"-2.9158316633266548\",\"-2.9038076152304626\",\"-2.8917835671342704\",\"-2.8797595190380783\",\"-2.8677354709418861\",\"-2.8557114228456939\",\"-2.8436873747495017\",\"-2.8316633266533096\",\"-2.8196392785571174\",\"-2.8076152304609252\",\"-2.795591182364733\",\"-2.7835671342685409\",\"-2.7715430861723487\",\"-2.7595190380761565\",\"-2.7474949899799643\",\"-2.7354709418837722\",\"-2.72344689378758\",\"-2.7114228456913878\",\"-2.6993987975951956\",\"-2.6873747494990035\",\"-2.6753507014028113\",\"-2.6633266533066191\",\"-2.6513026052104269\",\"-2.6392785571142348\",\"-2.6272545090180426\",\"-2.6152304609218504\",\"-2.6032064128256582\",\"-2.5911823647294661\",\"-2.5791583166332739\",\"-2.5671342685370817\",\"-2.5551102204408895\",\"-2.5430861723446974\",\"-2.5310621242485052\",\"-2.519038076152313\",\"-2.5070140280561208\",\"-2.4949899799599287\",\"-2.4829659318637365\",\"-2.4709418837675443\",\"-2.4589178356713521\",\"-2.44689378757516\",\"-2.4348697394789678\",\"-2.4228456913827756\",\"-2.4108216432865834\",\"-2.3987975951903913\",\"-2.3867735470941991\",\"-2.3747494989980069\",\"-2.3627254509018147\",\"-2.3507014028056226\",\"-2.3386773547094304\",\"-2.3266533066132382\",\"-2.314629258517046\",\"-2.3026052104208539\",\"-2.2905811623246617\",\"-2.2785571142284695\",\"-2.2665330661322773\",\"-2.2545090180360852\",\"-2.242484969939893\",\"-2.2304609218437008\",\"-2.2184368737475086\",\"-2.2064128256513165\",\"-2.1943887775551243\",\"-2.1823647294589321\",\"-2.1703406813627399\",\"-2.1583166332665478\",\"-2.1462925851703556\",\"-2.1342685370741634\",\"-2.1222444889779712\",\"-2.1102204408817791\",\"-2.0981963927855869\",\"-2.0861723446893947\",\"-2.0741482965932025\",\"-2.0621242484970104\",\"-2.0501002004008182\",\"-2.038076152304626\",\"-2.0260521042084338\",\"-2.0140280561122417\",\"-2.0020040080160495\",\"-1.9899799599198571\",\"-1.9779559118236647\",\"-1.9659318637274723\",\"-1.9539078156312799\",\"-1.9418837675350875\",\"-1.9298597194388951\",\"-1.9178356713427027\",\"-1.9058116232465103\",\"-1.8937875751503179\",\"-1.8817635270541255\",\"-1.8697394789579331\",\"-1.8577154308617407\",\"-1.8456913827655483\",\"-1.8336673346693559\",\"-1.8216432865731635\",\"-1.8096192384769711\",\"-1.7975951903807788\",\"-1.7855711422845864\",\"-1.773547094188394\",\"-1.7615230460922016\",\"-1.7494989979960092\",\"-1.7374749498998168\",\"-1.7254509018036244\",\"-1.713426853707432\",\"-1.7014028056112396\",\"-1.6893787575150472\",\"-1.6773547094188548\",\"-1.6653306613226624\",\"-1.65330661322647\",\"-1.6412825651302776\",\"-1.6292585170340852\",\"-1.6172344689378928\",\"-1.6052104208417004\",\"-1.593186372745508\",\"-1.5811623246493156\",\"-1.5691382765531232\",\"-1.5571142284569308\",\"-1.5450901803607384\",\"-1.533066132264546\",\"-1.5210420841683536\",\"-1.5090180360721612\",\"-1.4969939879759688\",\"-1.4849699398797764\",\"-1.472945891783584\",\"-1.4609218436873916\",\"-1.4488977955911992\",\"-1.4368737474950068\",\"-1.4248496993988145\",\"-1.4128256513026221\",\"-1.4008016032064297\",\"-1.3887775551102373\",\"-1.3767535070140449\",\"-1.3647294589178525\",\"-1.3527054108216601\",\"-1.3406813627254677\",\"-1.3286573146292753\",\"-1.3166332665330829\",\"-1.3046092184368905\",\"-1.2925851703406981\",\"-1.2805611222445057\",\"-1.2685370741483133\",\"-1.2565130260521209\",\"-1.2444889779559285\",\"-1.2324649298597361\",\"-1.2204408817635437\",\"-1.2084168336673513\",\"-1.1963927855711589\",\"-1.1843687374749665\",\"-1.1723446893787741\",\"-1.1603206412825817\",\"-1.1482965931863893\",\"-1.1362725450901969\",\"-1.1242484969940045\",\"-1.1122244488978121\",\"-1.1002004008016197\",\"-1.0881763527054273\",\"-1.0761523046092349\",\"-1.0641282565130425\",\"-1.0521042084168502\",\"-1.0400801603206578\",\"-1.0280561122244654\",\"-1.016032064128273\",\"-1.0040080160320806\",\"-0.99198396793588817\",\"-0.97995991983969577\",\"-0.96793587174350337\",\"-0.95591182364731098\",\"-0.94388777555111858\",\"-0.93186372745492618\",\"-0.91983967935873379\",\"-0.90781563126254139\",\"-0.89579158316634899\",\"-0.8837675350701566\",\"-0.8717434869739642\",\"-0.8597194388777718\",\"-0.84769539078157941\",\"-0.83567134268538701\",\"-0.82364729458919461\",\"-0.81162324649300222\",\"-0.79959919839680982\",\"-0.78757515030061742\",\"-0.77555110220442502\",\"-0.76352705410823263\",\"-0.75150300601204023\",\"-0.73947895791584783\",\"-0.72745490981965544\",\"-0.71543086172346304\",\"-0.70340681362727064\",\"-0.69138276553107825\",\"-0.67935871743488585\",\"-0.66733466933869345\",\"-0.65531062124250106\",\"-0.64328657314630866\",\"-0.63126252505011626\",\"-0.61923847695392387\",\"-0.60721442885773147\",\"-0.59519038076153907\",\"-0.58316633266534668\",\"-0.57114228456915428\",\"-0.55911823647296188\",\"-0.54709418837676949\",\"-0.53507014028057709\",\"-0.52304609218438469\",\"-0.5110220440881923\",\"-0.4989979959919999\",\"-0.4869739478958075\",\"-0.47494989979961511\",\"-0.46292585170342271\",\"-0.45090180360723031\",\"-0.43887775551103791\",\"-0.42685370741484552\",\"-0.41482965931865312\",\"-0.40280561122246072\",\"-0.39078156312626833\",\"-0.37875751503007593\",\"-0.36673346693388353\",\"-0.35470941883769114\",\"-0.34268537074149874\",\"-0.33066132264530634\",\"-0.31863727454911395\",\"-0.30661322645292155\",\"-0.29458917835672915\",\"-0.28256513026053676\",\"-0.27054108216434436\",\"-0.25851703406815196\",\"-0.24649298597195957\",\"-0.23446893787576717\",\"-0.22244488977957477\",\"-0.21042084168338238\",\"-0.19839679358718998\",\"-0.18637274549099758\",\"-0.17434869739480519\",\"-0.16232464929861279\",\"-0.15030060120242039\",\"-0.138276553106228\",\"-0.1262525050100356\",\"-0.11422845691384322\",\"-0.10220440881765083\",\"-0.09018036072145845\",\"-0.078156312625266067\",\"-0.066132264529073684\",\"-0.054108216432881301\",\"-0.042084168336688918\",\"-0.030060120240496535\",\"-0.018036072144304152\",\"-0.0060120240481117675\",\"0.0060120240480806171\",\"0.018036072144273003\",\"0.030060120240465386\",\"0.042084168336657769\",\"0.054108216432850152\",\"0.066132264529042542\",\"0.078156312625234925\",\"0.090180360721427308\",\"0.10220440881761969\",\"0.11422845691381207\",\"0.12625250501000446\",\"0.13827655310619685\",\"0.15030060120238925\",\"0.16232464929858165\",\"0.17434869739477404\",\"0.18637274549096644\",\"0.19839679358715884\",\"0.21042084168335123\",\"0.22244488977954363\",\"0.23446893787573603\",\"0.24649298597192842\",\"0.25851703406812082\",\"0.27054108216431322\",\"0.28256513026050561\",\"0.29458917835669801\",\"0.30661322645289041\",\"0.31863727454908281\",\"0.3306613226452752\",\"0.3426853707414676\",\"0.35470941883766\",\"0.36673346693385239\",\"0.37875751503004479\",\"0.39078156312623719\",\"0.40280561122242958\",\"0.41482965931862198\",\"0.42685370741481438\",\"0.43887775551100677\",\"0.45090180360719917\",\"0.46292585170339157\",\"0.47494989979958396\",\"0.48697394789577636\",\"0.49899799599196876\",\"0.5110220440881611\",\"0.52304609218435349\",\"0.53507014028054589\",\"0.54709418837673829\",\"0.55911823647293069\",\"0.57114228456912308\",\"0.58316633266531548\",\"0.59519038076150788\",\"0.60721442885770027\",\"0.61923847695389267\",\"0.63126252505008507\",\"0.64328657314627746\",\"0.65531062124246986\",\"0.66733466933866226\",\"0.67935871743485465\",\"0.69138276553104705\",\"0.70340681362723945\",\"0.71543086172343184\",\"0.72745490981962424\",\"0.73947895791581664\",\"0.75150300601200903\",\"0.76352705410820143\",\"0.77555110220439383\",\"0.78757515030058622\",\"0.79959919839677862\",\"0.81162324649297102\",\"0.82364729458916341\",\"0.83567134268535581\",\"0.84769539078154821\",\"0.8597194388777406\",\"0.871743486973933\",\"0.8837675350701254\",\"0.8957915831663178\",\"0.90781563126251019\",\"0.91983967935870259\",\"0.93186372745489499\",\"0.94388777555108738\",\"0.95591182364727978\",\"0.96793587174347218\",\"0.97995991983966457\",\"0.99198396793585697\",\"1.0040080160320493\",\"1.0160320641282417\",\"1.028056112224434\",\"1.0400801603206264\",\"1.0521042084168188\",\"1.0641282565130112\",\"1.0761523046092036\",\"1.088176352705396\",\"1.1002004008015884\",\"1.1122244488977808\",\"1.1242484969939732\",\"1.1362725450901656\",\"1.148296593186358\",\"1.1603206412825504\",\"1.1723446893787428\",\"1.1843687374749352\",\"1.1963927855711276\",\"1.20841683366732\",\"1.2204408817635124\",\"1.2324649298597048\",\"1.2444889779558972\",\"1.2565130260520896\",\"1.268537074148282\",\"1.2805611222444744\",\"1.2925851703406668\",\"1.3046092184368592\",\"1.3166332665330516\",\"1.328657314629244\",\"1.3406813627254364\",\"1.3527054108216288\",\"1.3647294589178212\",\"1.3767535070140136\",\"1.388777555110206\",\"1.4008016032063983\",\"1.4128256513025907\",\"1.4248496993987831\",\"1.4368737474949755\",\"1.4488977955911679\",\"1.4609218436873603\",\"1.4729458917835527\",\"1.4849699398797451\",\"1.4969939879759375\",\"1.5090180360721299\",\"1.5210420841683223\",\"1.5330661322645147\",\"1.5450901803607071\",\"1.5571142284568995\",\"1.5691382765530919\",\"1.5811623246492843\",\"1.5931863727454767\",\"1.6052104208416691\",\"1.6172344689378615\",\"1.6292585170340539\",\"1.6412825651302463\",\"1.6533066132264387\",\"1.6653306613226311\",\"1.6773547094188235\",\"1.6893787575150159\",\"1.7014028056112083\",\"1.7134268537074007\",\"1.7254509018035931\",\"1.7374749498997855\",\"1.7494989979959779\",\"1.7615230460921703\",\"1.7735470941883626\",\"1.785571142284555\",\"1.7975951903807474\",\"1.8096192384769398\",\"1.8216432865731322\",\"1.8336673346693246\",\"1.845691382765517\",\"1.8577154308617094\",\"1.8697394789579018\",\"1.8817635270540942\",\"1.8937875751502866\",\"1.905811623246479\",\"1.9178356713426714\",\"1.9298597194388638\",\"1.9418837675350562\",\"1.9539078156312486\",\"1.965931863727441\",\"1.9779559118236334\",\"1.9899799599198258\",\"2.002004008016018\",\"2.0140280561122101\",\"2.0260521042084023\",\"2.0380761523045945\",\"2.0501002004007867\",\"2.0621242484969788\",\"2.074148296593171\",\"2.0861723446893632\",\"2.0981963927855554\",\"2.1102204408817475\",\"2.1222444889779397\",\"2.1342685370741319\",\"2.1462925851703241\",\"2.1583166332665162\",\"2.1703406813627084\",\"2.1823647294589006\",\"2.1943887775550928\",\"2.2064128256512849\",\"2.2184368737474771\",\"2.2304609218436693\",\"2.2424849699398615\",\"2.2545090180360536\",\"2.2665330661322458\",\"2.278557114228438\",\"2.2905811623246302\",\"2.3026052104208223\",\"2.3146292585170145\",\"2.3266533066132067\",\"2.3386773547093989\",\"2.350701402805591\",\"2.3627254509017832\",\"2.3747494989979754\",\"2.3867735470941676\",\"2.3987975951903597\",\"2.4108216432865519\",\"2.4228456913827441\",\"2.4348697394789363\",\"2.4468937875751284\",\"2.4589178356713206\",\"2.4709418837675128\",\"2.482965931863705\",\"2.4949899799598971\",\"2.5070140280560893\",\"2.5190380761522815\",\"2.5310621242484737\",\"2.5430861723446658\",\"2.555110220440858\",\"2.5671342685370502\",\"2.5791583166332424\",\"2.5911823647294345\",\"2.6032064128256267\",\"2.6152304609218189\",\"2.6272545090180111\",\"2.6392785571142032\",\"2.6513026052103954\",\"2.6633266533065876\",\"2.6753507014027798\",\"2.6873747494989719\",\"2.6993987975951641\",\"2.7114228456913563\",\"2.7234468937875485\",\"2.7354709418837406\",\"2.7474949899799328\",\"2.759519038076125\",\"2.7715430861723171\",\"2.7835671342685093\",\"2.7955911823647015\",\"2.8076152304608937\",\"2.8196392785570858\",\"2.831663326653278\",\"2.8436873747494702\",\"2.8557114228456624\",\"2.8677354709418545\",\"2.8797595190380467\",\"2.8917835671342389\",\"2.9038076152304311\",\"2.9158316633266232\",\"2.9278557114228154\",\"2.9398797595190076\",\"2.9519038076151998\",\"2.9639278557113919\",\"2.9759519038075841\",\"2.9879759519037763\",\"3.0\"]; setTimeout(function() {\n    $('#slider-q2-2').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 83,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-q2-2-lbl').text(values[position]); interact(2, \"sage.server.notebook.interact.update(2, \\\"q2\\\", 10, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(2)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-q2-2-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-q2-2-lbl').text(values[$('#slider-q2-2').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">cmap&nbsp;</font></td><td><select onchange='interact(2, \"sage.server.notebook.interact.update(2, \\\"cmap\\\", 11, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.options[this.selectedIndex].value)+\"\\\"), globals());sage.server.notebook.interact.recompute(2)\");'><option value='0' selected>autumn</option>\n<option value='1' >bone</option>\n<option value='2' >cool</option>\n<option value='3' >copper</option>\n<option value='4' >gray</option>\n<option value='5' >hot</option>\n<option value='6' >hsv</option>\n<option value='7' >jet</option>\n<option value='8' >pink</option>\n<option value='9' >prism</option>\n<option value='10' >spring</option>\n<option value='11' >summer</option>\n<option value='12' >winter</option>\n</select></td></tr>\n</table><div id='cell-interact-2'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠c2ff558a-6a01-41c8-935c-30887445b439︠
html('<h2>Tangent line grapher</h2>')
@interact
def tangent_line(f = input_box(default=sin(x)), xbegin = slider(0,10,1/10,0), xend = slider(0,10,1/10,10), x0 = slider(0, 1, 1/100, 1/2)):
    prange = [xbegin, xend]
    x0i = xbegin + x0*(xend-xbegin)
    var('x')
    df = diff(f)
    tanf = f(x0i) + df(x0i)*(x-x0i)
    fplot = plot(f, prange[0], prange[1])
    print 'Tangent line is y = ' + tanf._repr_()
    tanplot = plot(tanf, prange[0], prange[1], rgbcolor = (1,0,0))
    fmax = f.find_maximum_on_interval(prange[0], prange[1])[0]
    fmin = f.find_minimum_on_interval(prange[0], prange[1])[0]
    show(fplot + tanplot, xmin = prange[0], xmax = prange[1], ymax = fmax, ymin = fmin)
︡1827f83f-ff49-4ab9-95f6-abb46f402dde︡{"html": "<font color='black'><h2>Tangent line grapher</h2></font>"}︡{"html": "<!--notruncate--><div padding=6 id='div-interact-3'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"\n                                    sin(x)\" size=80 onchange='interact(3, \"sage.server.notebook.interact.update(3, \\\"f\\\", 12, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(3)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xbegin&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-xbegin-3' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-xbegin-3-lbl'></font></td></tr></table><script>(function(){ var values = [\"0\",\"1/10\",\"1/5\",\"3/10\",\"2/5\",\"1/2\",\"3/5\",\"7/10\",\"4/5\",\"9/10\",\"1\",\"11/10\",\"6/5\",\"13/10\",\"7/5\",\"3/2\",\"8/5\",\"17/10\",\"9/5\",\"19/10\",\"2\",\"21/10\",\"11/5\",\"23/10\",\"12/5\",\"5/2\",\"13/5\",\"27/10\",\"14/5\",\"29/10\",\"3\",\"31/10\",\"16/5\",\"33/10\",\"17/5\",\"7/2\",\"18/5\",\"37/10\",\"19/5\",\"39/10\",\"4\",\"41/10\",\"21/5\",\"43/10\",\"22/5\",\"9/2\",\"23/5\",\"47/10\",\"24/5\",\"49/10\",\"5\",\"51/10\",\"26/5\",\"53/10\",\"27/5\",\"11/2\",\"28/5\",\"57/10\",\"29/5\",\"59/10\",\"6\",\"61/10\",\"31/5\",\"63/10\",\"32/5\",\"13/2\",\"33/5\",\"67/10\",\"34/5\",\"69/10\",\"7\",\"71/10\",\"36/5\",\"73/10\",\"37/5\",\"15/2\",\"38/5\",\"77/10\",\"39/5\",\"79/10\",\"8\",\"81/10\",\"41/5\",\"83/10\",\"42/5\",\"17/2\",\"43/5\",\"87/10\",\"44/5\",\"89/10\",\"9\",\"91/10\",\"46/5\",\"93/10\",\"47/5\",\"19/2\",\"48/5\",\"97/10\",\"49/5\",\"99/10\",\"10\"]; setTimeout(function() {\n    $('#slider-xbegin-3').slider({\n    \tstepping: 1, min: 0, max: 100, startValue: 0,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-xbegin-3-lbl').text(values[position]); interact(3, \"sage.server.notebook.interact.update(3, \\\"xbegin\\\", 13, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(3)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-xbegin-3-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-xbegin-3-lbl').text(values[$('#slider-xbegin-3').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">xend&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-xend-3' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-xend-3-lbl'></font></td></tr></table><script>(function(){ var values = [\"0\",\"1/10\",\"1/5\",\"3/10\",\"2/5\",\"1/2\",\"3/5\",\"7/10\",\"4/5\",\"9/10\",\"1\",\"11/10\",\"6/5\",\"13/10\",\"7/5\",\"3/2\",\"8/5\",\"17/10\",\"9/5\",\"19/10\",\"2\",\"21/10\",\"11/5\",\"23/10\",\"12/5\",\"5/2\",\"13/5\",\"27/10\",\"14/5\",\"29/10\",\"3\",\"31/10\",\"16/5\",\"33/10\",\"17/5\",\"7/2\",\"18/5\",\"37/10\",\"19/5\",\"39/10\",\"4\",\"41/10\",\"21/5\",\"43/10\",\"22/5\",\"9/2\",\"23/5\",\"47/10\",\"24/5\",\"49/10\",\"5\",\"51/10\",\"26/5\",\"53/10\",\"27/5\",\"11/2\",\"28/5\",\"57/10\",\"29/5\",\"59/10\",\"6\",\"61/10\",\"31/5\",\"63/10\",\"32/5\",\"13/2\",\"33/5\",\"67/10\",\"34/5\",\"69/10\",\"7\",\"71/10\",\"36/5\",\"73/10\",\"37/5\",\"15/2\",\"38/5\",\"77/10\",\"39/5\",\"79/10\",\"8\",\"81/10\",\"41/5\",\"83/10\",\"42/5\",\"17/2\",\"43/5\",\"87/10\",\"44/5\",\"89/10\",\"9\",\"91/10\",\"46/5\",\"93/10\",\"47/5\",\"19/2\",\"48/5\",\"97/10\",\"49/5\",\"99/10\",\"10\"]; setTimeout(function() {\n    $('#slider-xend-3').slider({\n    \tstepping: 1, min: 0, max: 100, startValue: 100,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-xend-3-lbl').text(values[position]); interact(3, \"sage.server.notebook.interact.update(3, \\\"xend\\\", 14, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(3)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-xend-3-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-xend-3-lbl').text(values[$('#slider-xend-3').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">x0&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-x0-3' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-x0-3-lbl'></font></td></tr></table><script>(function(){ var values = [\"0\",\"1/100\",\"1/50\",\"3/100\",\"1/25\",\"1/20\",\"3/50\",\"7/100\",\"2/25\",\"9/100\",\"1/10\",\"11/100\",\"3/25\",\"13/100\",\"7/50\",\"3/20\",\"4/25\",\"17/100\",\"9/50\",\"19/100\",\"1/5\",\"21/100\",\"11/50\",\"23/100\",\"6/25\",\"1/4\",\"13/50\",\"27/100\",\"7/25\",\"29/100\",\"3/10\",\"31/100\",\"8/25\",\"33/100\",\"17/50\",\"7/20\",\"9/25\",\"37/100\",\"19/50\",\"39/100\",\"2/5\",\"41/100\",\"21/50\",\"43/100\",\"11/25\",\"9/20\",\"23/50\",\"47/100\",\"12/25\",\"49/100\",\"1/2\",\"51/100\",\"13/25\",\"53/100\",\"27/50\",\"11/20\",\"14/25\",\"57/100\",\"29/50\",\"59/100\",\"3/5\",\"61/100\",\"31/50\",\"63/100\",\"16/25\",\"13/20\",\"33/50\",\"67/100\",\"17/25\",\"69/100\",\"7/10\",\"71/100\",\"18/25\",\"73/100\",\"37/50\",\"3/4\",\"19/25\",\"77/100\",\"39/50\",\"79/100\",\"4/5\",\"81/100\",\"41/50\",\"83/100\",\"21/25\",\"17/20\",\"43/50\",\"87/100\",\"22/25\",\"89/100\",\"9/10\",\"91/100\",\"23/25\",\"93/100\",\"47/50\",\"19/20\",\"24/25\",\"97/100\",\"49/50\",\"99/100\",\"1\"]; setTimeout(function() {\n    $('#slider-x0-3').slider({\n    \tstepping: 1, min: 0, max: 100, startValue: 50,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-x0-3-lbl').text(values[position]); interact(3, \"sage.server.notebook.interact.update(3, \\\"x0\\\", 15, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(3)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-x0-3-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-x0-3-lbl').text(values[$('#slider-x0-3').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-3'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠e6a4bf1e-4845-4894-af1d-123f474b86dd︠
var('x')
@interact
def midpoint(n = slider(1,100,1,4), f = input_box(default = "x^2", type = str), start = input_box(default = "0", type = str), end = input_box(default = "1", type = str)):
    a = N(start)
    b = N(end)
    func = sage_eval(f, locals={'x':x})
    dx = (b-a)/n
    midxs = [q*dx+dx/2 + a for q in range(n)]
    midys = [func(x_val) for x_val in midxs]
    rects = Graphics()
    for q in range(n):
        xm = midxs[q]
        ym = midys[q]
        rects = rects + line([[xm-dx/2,0],[xm-dx/2,ym],[xm+dx/2,ym],[xm+dx/2,0]], rgbcolor = (1,0,0)) + point((xm,ym), rgbcolor = (1,0,0))
    min_y = find_minimum_on_interval(func,a,b)[0]
    max_y = find_maximum_on_interval(func,a,b)[0]
    html('<h3>Numerical integrals with the midpoint rule</h3>')
    html('$\int_{a}^{b}{f(x) dx} {\\approx} \sum_i{f(x_i) \Delta x}$')
    print "\n\nSage numerical answer: " + str(integral_numerical(func,a,b,max_points = 200)[0])
    print "Midpoint estimated answer: " + str(RDF(dx*sum([midys[q] for q in range(n)])))
    show(plot(func,a,b) + rects, xmin = a, xmax = b, ymin = min_y, ymax = max_y)
︡7ea637a0-4d6d-4491-a7e4-50e10140c0cf︡{"html": "<!--notruncate--><div padding=6 id='div-interact-4'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">n&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-n-4' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-n-4-lbl'></font></td></tr></table><script>(function(){ var values = [\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\",\"20\",\"21\",\"22\",\"23\",\"24\",\"25\",\"26\",\"27\",\"28\",\"29\",\"30\",\"31\",\"32\",\"33\",\"34\",\"35\",\"36\",\"37\",\"38\",\"39\",\"40\",\"41\",\"42\",\"43\",\"44\",\"45\",\"46\",\"47\",\"48\",\"49\",\"50\",\"51\",\"52\",\"53\",\"54\",\"55\",\"56\",\"57\",\"58\",\"59\",\"60\",\"61\",\"62\",\"63\",\"64\",\"65\",\"66\",\"67\",\"68\",\"69\",\"70\",\"71\",\"72\",\"73\",\"74\",\"75\",\"76\",\"77\",\"78\",\"79\",\"80\",\"81\",\"82\",\"83\",\"84\",\"85\",\"86\",\"87\",\"88\",\"89\",\"90\",\"91\",\"92\",\"93\",\"94\",\"95\",\"96\",\"97\",\"98\",\"99\",\"100\"]; setTimeout(function() {\n    $('#slider-n-4').slider({\n    \tstepping: 1, min: 0, max: 99, startValue: 3,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-n-4-lbl').text(values[position]); interact(4, \"sage.server.notebook.interact.update(4, \\\"n\\\", 16, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(4)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-n-4-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-n-4-lbl').text(values[$('#slider-n-4').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"x^2\" size=80 onchange='interact(4, \"sage.server.notebook.interact.update(4, \\\"f\\\", 17, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(4)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">start&nbsp;</font></td><td><input type='text' value=\"0\" size=80 onchange='interact(4, \"sage.server.notebook.interact.update(4, \\\"start\\\", 18, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(4)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">end&nbsp;</font></td><td><input type='text' value=\"1\" size=80 onchange='interact(4, \"sage.server.notebook.interact.update(4, \\\"end\\\", 19, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(4)\")'></input></td></tr>\n</table><div id='cell-interact-4'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠89d32351-ee2a-43dc-ae32-c1fb93fe4cf9︠
x = var('x')
@interact
def _(f=sin(x), g=cos(x), xrange=input_box((0,1)), yrange='auto', a=1,
      action=selector(['f', 'df/dx', 'int f', 'num f', 'den f', '1/f', 'finv',
                       'f+a', 'f-a', 'f*a', 'f/a', 'f^a', 'f(x+a)', 'f(x*a)',
                       'f+g', 'f-g', 'f*g', 'f/g', 'f(g)'],
             width=15, nrows=5, label="h = "),
      do_plot = ("Draw Plots", True)):
    try:
        f = SR(f); g = SR(g); a = SR(a)
    except TypeError, msg:
        print msg[-200:]
        print "Unable to make sense of f,g, or a as symbolic expressions."
        return
    if not (isinstance(xrange, tuple) and len(xrange) == 2):
          xrange = (0,1)
    h = 0; lbl = ''
    if action == 'f':
        h = f
        lbl = 'f'
    elif action == 'df/dx':
        h = f.derivative(x)
        lbl = '\\frac{df}{dx}'
    elif action == 'int f':
        h = f.integrate(x)
        lbl = '\\int f dx'
    elif action == 'num f':
        h = f.numerator()
        lbl = '\\text{numer(f)}'
    elif action == 'den f':
        h = f.denominator()
        lbl = '\\text{denom(f)}'
    elif action == '1/f':
        h = 1/f
        lbl = '\\frac{1}{f}'
    elif action == 'finv':
        h = solve(f == var('y'), x)[0].rhs()
        lbl = 'f^{-1}(y)'
    elif action == 'f+a':
        h = f+a
        lbl = 'f + a'
    elif action == 'f-a':
        h = f-a
        lbl = 'f - a'
    elif action == 'f*a':
        h = f*a
        lbl = 'f \\times a'
    elif action == 'f/a':
        h = f/a
        lbl = '\\frac{f}{a}'
    elif action == 'f^a':
        h = f^a
        lbl = 'f^a'
    elif action == 'f^a':
        h = f^a
        lbl = 'f^a'
    elif action == 'f(x+a)':
        h = f(x+a)
        lbl = 'f(x+a)'
    elif action == 'f(x*a)':
        h = f(x*a)
        lbl = 'f(xa)'
    elif action == 'f+g':
        h = f+g
        lbl = 'f + g'
    elif action == 'f-g':
        h = f-g
        lbl = 'f - g'
    elif action == 'f*g':
        h = f*g
        lbl = 'f \\times g'
    elif action == 'f/g':
        h = f/g
        lbl = '\\frac{f}{g}'
    elif action == 'f(g)':
        h = f(g)
        lbl = 'f(g)'
    html('<center><font color="red">$f = %s$</font></center>'%latex(f))
    html('<center><font color="green">$g = %s$</font></center>'%latex(g))
    html('<center><font color="blue"><b>$h = %s = %s$</b></font></center>'%(lbl, latex(h)))
    if do_plot:
        P = plot(f, xrange, color='red', thickness=2) +  \
            plot(g, xrange, color='green', thickness=2) + \
            plot(h, xrange, color='blue', thickness=2)
        if yrange == 'auto':
            show(P, xmin=xrange[0], xmax=xrange[1])
        else:
            yrange = sage_eval(yrange)
            show(P, xmin=xrange[0], xmax=xrange[1], ymin=yrange[0], ymax=yrange[1])
︡e7c98e56-d78e-4eaa-8ce6-ea70f5799e3d︡{"html": "<!--notruncate--><div padding=6 id='div-interact-5'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"\n                                    sin(x)\" size=80 onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"f\\\", 20, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">g&nbsp;</font></td><td><input type='text' value=\"\n                                    cos(x)\" size=80 onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"g\\\", 21, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xrange&nbsp;</font></td><td><input type='text' value=\"(0, 1)\" size=80 onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"xrange\\\", 22, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">yrange&nbsp;</font></td><td><input type='text' value=\"auto\" size=80 onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"yrange\\\", 23, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">a&nbsp;</font></td><td><input type='text' value=\"1\" size=80 onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"a\\\", 24, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">h = &nbsp;</font></td><td><table style=\"border:1px solid #dfdfdf;background-color:#efefef\">\n<tr><td><button style='border-style:inset;width:15ex;' value='0' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f</button>\n<button style='border-style:outset;width:15ex;' value='1' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>df/dx</button>\n<button style='border-style:outset;width:15ex;' value='2' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>int f</button>\n<button style='border-style:outset;width:15ex;' value='3' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>num f</button>\n</td></tr>\n<tr><td><button style='border-style:outset;width:15ex;' value='4' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>den f</button>\n<button style='border-style:outset;width:15ex;' value='5' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>1/f</button>\n<button style='border-style:outset;width:15ex;' value='6' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>finv</button>\n<button style='border-style:outset;width:15ex;' value='7' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f+a</button>\n</td></tr>\n<tr><td><button style='border-style:outset;width:15ex;' value='8' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f-a</button>\n<button style='border-style:outset;width:15ex;' value='9' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f*a</button>\n<button style='border-style:outset;width:15ex;' value='10' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f/a</button>\n<button style='border-style:outset;width:15ex;' value='11' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f^a</button>\n</td></tr>\n<tr><td><button style='border-style:outset;width:15ex;' value='12' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f(x+a)</button>\n<button style='border-style:outset;width:15ex;' value='13' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f(x*a)</button>\n<button style='border-style:outset;width:15ex;' value='14' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f+g</button>\n<button style='border-style:outset;width:15ex;' value='15' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f-g</button>\n</td></tr>\n<tr><td><button style='border-style:outset;width:15ex;' value='16' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f*g</button>\n<button style='border-style:outset;width:15ex;' value='17' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f/g</button>\n<button style='border-style:outset;width:15ex;' value='18' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(5, \"sage.server.notebook.interact.update(5, \\\"action\\\", 25, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'>f(g)</button>\n</td></tr></table></td></tr>\n<tr><td align=right><font color=\"black\">Draw Plots&nbsp;</font></td><td><input type='checkbox' checked width=200px onchange='interact(5, \"sage.server.notebook.interact.update(5, \\\"do_plot\\\", 26, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(5)\")'></input></td></tr>\n</table><div id='cell-interact-5'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠9f1c60ed-d073-4d71-9553-54d979c03d99︠
# ideas from 'A simple tangent line grapher' by Marshall Hampton
# http://wiki.sagemath.org/interact

State = Data = None   # globals to allow incremental changes in interaction data

@interact
def newtraph(f = input_box(default=8*sin(x)*exp(-x)-1, label='f(x)'), 
             xmin = input_box(default=0), 
             xmax = input_box(default=4*pi), 
             x0 = input_box(default=3, label='x0'),
             show_calcs = ("Show Calcs",True),
             step = ['Next','Prev', 'Reset'] ):
    global State, Data
    state = [f,xmin,xmax,x0,show_calcs]
    if (state != State) or (step == 'Reset'):   # when any of the controls change
        Data = [ 1 ]                            # reset the plot
        State = state
    elif step == 'Next':
        N, = Data
        Data = [ N+1 ]
    elif step == 'Prev':
        N, = Data
        if N > 1:
            Data = [ N-1 ]
    N, = Data
    df = diff(f)

    theplot = plot( f, xmin, xmax )
    theplot += text( '\n$x_0$', (x0,0), rgbcolor=(1,0,0),
                     vertical_alignment="bottom" if f(x0) < 0 else "top" )
    theplot += points( [(x0,0)], rgbcolor=(1,0,0) )

    Trace = []
    def Err( msg, Trace=Trace ):
        Trace.append( '<font color="red"><b>Error: %s!!</b></font>' % (msg,) )
    def Disp( s, color="blue", Trace=Trace ):
        Trace.append( """<font color="%s">$ %s $</font>""" % (color,s,) )

    Disp( """f(x) = %s""" % (latex(f),) )
    Disp( """f'(x) = %s""" % (latex(df),) )

    stop = False
    is_inf = False
    xi = x0
    for i in range(N):
        fi = RR(f(xi))
        fpi = RR(df(xi))

        theplot += points( [(xi,fi)], rgbcolor=(1,0,0) )
        theplot += line( [(xi,0),(xi,fi)], linestyle=':', rgbcolor=(1,0,0) ) # vert dotted line
        Disp( """i = %d""" % (i,) )
        Disp( """~~~~x_{%d} = %.4g""" % (i,xi) )
        Disp( """~~~~f(x_{%d}) = %.4g""" % (i,fi) )
        Disp( """~~~~f'(x_{%d}) = %.4g""" % (i,fpi) )

        if fpi == 0.0:
            Err( 'Derivative is 0 at iteration %d' % (i+1,) )
            is_inf = True
            show_calcs = True
        else:
            xip1 = xi - fi/fpi
            Disp( r"""~~~~x_{%d} = %.4g - ({%.4g})/({%.4g}) = %.4g""" % (i+1,xi,fi,fpi,xip1) )
            if abs(xip1) > 10*(xmax-xmin):
                Err( 'Derivative is too close to 0!' )
                is_inf = True
                show_calcs = True
            elif not ((xmin - 0.5*(xmax-xmin)) <= xip1 <= (xmax + 0.5*(xmax-xmin))):
                Err( 'x value out of range; probable divergence!' )
                stop = True
                show_calcs = True
 
        if is_inf:
            xl = xi - 0.05*(xmax-xmin)
            xr = xi + 0.05*(xmax-xmin)
            yl = yr = fi
        else:
            xl = min(xi,xip1) - 0.01*(xmax-xmin)
            xr = max(xi,xip1) + 0.01*(xmax-xmin)
            yl = -(xip1-xl)*fpi
            yr = (xr-xip1)*fpi
            theplot += text( '\n$x_{%d}$' % (i+1,), (xip1,0), rgbcolor=(1,0,0),
                             vertical_alignment="bottom" if f(xip1) < 0 else "top" )
            theplot += points( [(xip1,0)], rgbcolor=(1,0,0) )

        theplot += line( [(xl,yl),(xr,yr)], rgbcolor=(1,0,0) )  # tangent

        if stop or is_inf:
            break
        epsa = 100.0*abs((xip1-xi)/xip1)
        nsf = 2 - log(2.0*epsa)/log(10.0)
        Disp( r"""~~~~~~~~\epsilon_a = \left|(%.4g - %.4g)/%.4g\right|\times100\%% = %.4g \%%""" % (xip1,xi,xip1,epsa) )
        Disp( r"""~~~~~~~~num.~sig.~fig. \approx %.2g""" % (nsf,) )
        xi = xip1

    show( theplot, xmin=xmin, xmax=xmax )
    if show_calcs:
        for t in Trace:
            html( t )
︡bc1648ca-a6f1-495c-8c81-24fb445aea5a︡{"html": "<!--notruncate--><div padding=6 id='div-interact-6'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f(x)&nbsp;</font></td><td><input type='text' value=\"\n                                  - x\n                              8  e    sin(x) - 1\" size=80 onchange='interact(6, \"sage.server.notebook.interact.update(6, \\\"f\\\", 27, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmin&nbsp;</font></td><td><input type='text' value=\"0\" size=80 onchange='interact(6, \"sage.server.notebook.interact.update(6, \\\"xmin\\\", 28, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmax&nbsp;</font></td><td><input type='text' value=\"\n                                     4  pi\" size=80 onchange='interact(6, \"sage.server.notebook.interact.update(6, \\\"xmax\\\", 29, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">x0&nbsp;</font></td><td><input type='text' value=\"3\" size=80 onchange='interact(6, \"sage.server.notebook.interact.update(6, \\\"x0\\\", 30, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">Show Calcs&nbsp;</font></td><td><input type='checkbox' checked width=200px onchange='interact(6, \"sage.server.notebook.interact.update(6, \\\"show_calcs\\\", 31, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">step&nbsp;</font></td><td><table style=\"border:1px solid #dfdfdf;background-color:#efefef\">\n<tr><td><button style='border-style:inset;' value='0' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(6, \"sage.server.notebook.interact.update(6, \\\"step\\\", 32, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'>Next</button>\n<button style='border-style:outset;' value='1' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(6, \"sage.server.notebook.interact.update(6, \\\"step\\\", 32, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'>Prev</button>\n<button style='border-style:outset;' value='2' onclick='$(\"BUTTON\", this.parentNode).css(\"border-style\", \"outset\"); $(this).css(\"border-style\", \"inset\"); interact(6, \"sage.server.notebook.interact.update(6, \\\"step\\\", 32, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(6)\")'>Reset</button>\n</td></tr></table></td></tr>\n</table><div id='cell-interact-6'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠7f55b8e3-8aed-4da9-a579-89d780b7019d︠
var('x')

x0  = 0
f   = sin(x)*e^(-x)
p   = plot(f,-1,5, thickness=2)
dot = point((x0,f(x0)),pointsize=80,rgbcolor=(1,0,0))
@interact
def _(order=(1..12)):
    ft = f.taylor(x,x0,order)
    pt = plot(ft,-1, 5, color='green', thickness=2)
    html('$f(x)\;=\;%s$'%latex(f))
    html('$\hat{f}(x;%s)\;=\;%s+\mathcal{O}(x^{%s})$'%(x0,latex(ft),order+1))
    show(dot + p + pt, ymin = -.5, ymax = 1)

taylor_series_animated.gif
︡b83ff665-4390-437e-be3c-07d5f213dbef︡{"html": "<!--notruncate--><div padding=6 id='div-interact-7'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">order&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-order-7' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-order-7-lbl'></font></td></tr></table><script>(function(){ var values = [\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\"]; setTimeout(function() {\n    $('#slider-order-7').slider({\n    \tstepping: 1, min: 0, max: 11, startValue: 0,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-order-7-lbl').text(values[position]); interact(7, \"sage.server.notebook.interact.update(7, \\\"order\\\", 33, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(7)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-order-7-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-order-7-lbl').text(values[$('#slider-order-7').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-7'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡{"stderr": "Traceback (most recent call last):\n  File \"<stdin>\", line 1, in <module>\n  File \"/home/sage/sagenb/sage_notebook/worksheets/MathBear/6/code/16.py\", line 21, in <module>\n    exec compile(ur'taylor_series_animated.gif' + '\\n', '', 'single')\n  File \"/home/sage/sage_install/sage-a/local/lib/python2.5/site-packages/SQLAlchemy-0.4.6-py2.5.egg/\", line 1, in <module>\n    \nNameError: name 'taylor_series_animated' is not defined"}︡
︠833ba412-e17d-4775-87cb-75e92fd073ad︠
from sage.plot.plot3d.platonic import index_face_set
def cuboid(v1,v2,**kwds):
    """
    Cuboid defined by corner points v1 and v2.
    """
    ptlist = []
    for vi in (v1,v2):
        for vj in (v1,v2):
            for vk in (v1,v2):
                ptlist.append([vi[0],vj[1],vk[2]])
    f_incs = [[0, 2, 6, 4], [0, 1, 3, 2], [0, 1, 5, 4], [1, 3, 7, 5], [2, 3, 7, 6], [4, 5, 7, 6]]
    
    if 'aspect_ratio' not in kwds:
        kwds['aspect_ratio'] = [1,1,1]
    return index_face_set(f_incs,ptlist,enclosed = True, **kwds)
var('x,y')
R16 = RealField(16)
npi = RDF(pi)
sin,cos = math.sin,math.cos 
html("<h1>The midpoint rule for a function of two variables</h1>")
@interact
def midpoint2d(func = input_box('y*sin(x)/x+sin(y)',type=str,label='function of x and y'), nx = slider(2,20,1,3,label='x subdivisions'), ny = slider(2,20,1,3,label='y subdivisions'), x_start = slider(-10,10,.1,0), x_end = slider(-10,10,.1,3*npi), y_start= slider(-10,10,.1,0), y_end= slider(-10,10,.1,3*npi)):
    f = sage_eval('lambda x,y: ' + func)
    delx = (x_end - x_start)/nx
    dely = (y_end - y_start)/nx
    xvals = [RDF(x_start + (i+1.0/2)*delx) for i in range(nx)]
    yvals = [RDF(y_start + (i+1.0/2)*dely) for i in range(ny)]
    num_approx = 0
    cubs = []
    darea = delx*dely
    for xv in xvals:
        for yv in yvals:
            num_approx += f(xv,yv)*darea
            cubs.append(cuboid([xv-delx/2,yv-dely/2,0],[xv+delx/2,yv+dely/2,f(xv,yv)], opacity = .5, rgbcolor = (1,0,0)))
    html("$$\int_{"+str(R16(y_start))+"}^{"+str(R16(y_end))+"} "+ "\int_{"+str(R16(x_start))+"}^{"+str(R16(x_end))+"} "+func+"\ dx \ dy$$")
    html('<p style="text-align: center;">Numerical approximation: ' + str(num_approx)+'</p>')
    p1 = plot3d(f,(x,x_start,x_end),(y,y_start,y_end))
    show(p1+sum(cubs))
︡425ca22a-f411-49f8-8d7f-9c3e4d12675d︡{"html": "<font color='black'><h1>The midpoint rule for a function of two variables</h1></font>"}︡{"html": "<!--notruncate--><div padding=6 id='div-interact-8'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">function of x and y&nbsp;</font></td><td><input type='text' value=\"y*sin(x)/x+sin(y)\" size=80 onchange='interact(8, \"sage.server.notebook.interact.update(8, \\\"func\\\", 34, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">x subdivisions&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-nx-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-nx-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\",\"20\"]; setTimeout(function() {\n    $('#slider-nx-8').slider({\n    \tstepping: 1, min: 0, max: 18, startValue: 1,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-nx-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"nx\\\", 35, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-nx-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-nx-8-lbl').text(values[$('#slider-nx-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">y subdivisions&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-ny-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-ny-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\",\"20\"]; setTimeout(function() {\n    $('#slider-ny-8').slider({\n    \tstepping: 1, min: 0, max: 18, startValue: 1,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-ny-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"ny\\\", 36, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-ny-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-ny-8-lbl').text(values[$('#slider-ny-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">x_start&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-x_start-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-x_start-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"-10.0000000000000\",\"-9.90000000000000\",\"-9.80000000000000\",\"-9.70000000000000\",\"-9.60000000000000\",\"-9.50000000000000\",\"-9.40000000000000\",\"-9.30000000000000\",\"-9.20000000000000\",\"-9.10000000000000\",\"-9.00000000000000\",\"-8.90000000000000\",\"-8.80000000000000\",\"-8.70000000000000\",\"-8.60000000000000\",\"-8.50000000000001\",\"-8.40000000000001\",\"-8.30000000000001\",\"-8.20000000000001\",\"-8.10000000000001\",\"-8.00000000000001\",\"-7.90000000000001\",\"-7.80000000000001\",\"-7.70000000000001\",\"-7.60000000000001\",\"-7.50000000000001\",\"-7.40000000000001\",\"-7.30000000000001\",\"-7.20000000000001\",\"-7.10000000000001\",\"-7.00000000000001\",\"-6.90000000000001\",\"-6.80000000000001\",\"-6.70000000000001\",\"-6.60000000000001\",\"-6.50000000000001\",\"-6.40000000000001\",\"-6.30000000000001\",\"-6.20000000000001\",\"-6.10000000000001\",\"-6.00000000000001\",\"-5.90000000000001\",\"-5.80000000000001\",\"-5.70000000000002\",\"-5.60000000000002\",\"-5.50000000000002\",\"-5.40000000000002\",\"-5.30000000000002\",\"-5.20000000000002\",\"-5.10000000000002\",\"-5.00000000000002\",\"-4.90000000000002\",\"-4.80000000000002\",\"-4.70000000000002\",\"-4.60000000000002\",\"-4.50000000000002\",\"-4.40000000000002\",\"-4.30000000000002\",\"-4.20000000000002\",\"-4.10000000000002\",\"-4.00000000000002\",\"-3.90000000000002\",\"-3.80000000000002\",\"-3.70000000000002\",\"-3.60000000000002\",\"-3.50000000000002\",\"-3.40000000000002\",\"-3.30000000000002\",\"-3.20000000000002\",\"-3.10000000000002\",\"-3.00000000000002\",\"-2.90000000000002\",\"-2.80000000000002\",\"-2.70000000000002\",\"-2.60000000000002\",\"-2.50000000000002\",\"-2.40000000000002\",\"-2.30000000000002\",\"-2.20000000000002\",\"-2.10000000000002\",\"-2.00000000000002\",\"-1.90000000000002\",\"-1.80000000000002\",\"-1.70000000000002\",\"-1.60000000000002\",\"-1.50000000000002\",\"-1.40000000000002\",\"-1.30000000000002\",\"-1.20000000000002\",\"-1.10000000000002\",\"-1.00000000000002\",\"-0.900000000000019\",\"-0.800000000000019\",\"-0.700000000000019\",\"-0.600000000000019\",\"-0.500000000000019\",\"-0.400000000000019\",\"-0.300000000000019\",\"-0.200000000000019\",\"-0.100000000000019\",\"-1.87905246917808e-14\",\"0.0999999999999812\",\"0.199999999999981\",\"0.299999999999981\",\"0.399999999999981\",\"0.499999999999981\",\"0.599999999999981\",\"0.699999999999981\",\"0.799999999999981\",\"0.899999999999981\",\"0.999999999999981\",\"1.09999999999998\",\"1.19999999999998\",\"1.29999999999998\",\"1.39999999999998\",\"1.49999999999998\",\"1.59999999999998\",\"1.69999999999998\",\"1.79999999999998\",\"1.89999999999998\",\"1.99999999999998\",\"2.09999999999998\",\"2.19999999999998\",\"2.29999999999998\",\"2.39999999999998\",\"2.49999999999998\",\"2.59999999999998\",\"2.69999999999998\",\"2.79999999999998\",\"2.89999999999998\",\"2.99999999999998\",\"3.09999999999998\",\"3.19999999999998\",\"3.29999999999998\",\"3.39999999999998\",\"3.49999999999998\",\"3.59999999999998\",\"3.69999999999998\",\"3.79999999999998\",\"3.89999999999998\",\"3.99999999999998\",\"4.09999999999998\",\"4.19999999999998\",\"4.29999999999998\",\"4.39999999999998\",\"4.49999999999998\",\"4.59999999999998\",\"4.69999999999998\",\"4.79999999999998\",\"4.89999999999998\",\"4.99999999999998\",\"5.09999999999998\",\"5.19999999999998\",\"5.29999999999998\",\"5.39999999999998\",\"5.49999999999998\",\"5.59999999999998\",\"5.69999999999998\",\"5.79999999999998\",\"5.89999999999998\",\"5.99999999999998\",\"6.09999999999998\",\"6.19999999999998\",\"6.29999999999998\",\"6.39999999999998\",\"6.49999999999998\",\"6.59999999999997\",\"6.69999999999997\",\"6.79999999999997\",\"6.89999999999997\",\"6.99999999999997\",\"7.09999999999997\",\"7.19999999999997\",\"7.29999999999997\",\"7.39999999999997\",\"7.49999999999997\",\"7.59999999999997\",\"7.69999999999997\",\"7.79999999999997\",\"7.89999999999997\",\"7.99999999999997\",\"8.09999999999997\",\"8.19999999999997\",\"8.29999999999997\",\"8.39999999999997\",\"8.49999999999997\",\"8.59999999999997\",\"8.69999999999997\",\"8.79999999999997\",\"8.89999999999997\",\"8.99999999999997\",\"9.09999999999997\",\"9.19999999999997\",\"9.29999999999997\",\"9.39999999999996\",\"9.49999999999996\",\"9.59999999999996\",\"9.69999999999996\",\"9.79999999999996\",\"9.89999999999996\",\"10.0000000000000\"]; setTimeout(function() {\n    $('#slider-x_start-8').slider({\n    \tstepping: 1, min: 0, max: 200, startValue: 100,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-x_start-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"x_start\\\", 37, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-x_start-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-x_start-8-lbl').text(values[$('#slider-x_start-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">x_end&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-x_end-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-x_end-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"-10.0000000000000\",\"-9.90000000000000\",\"-9.80000000000000\",\"-9.70000000000000\",\"-9.60000000000000\",\"-9.50000000000000\",\"-9.40000000000000\",\"-9.30000000000000\",\"-9.20000000000000\",\"-9.10000000000000\",\"-9.00000000000000\",\"-8.90000000000000\",\"-8.80000000000000\",\"-8.70000000000000\",\"-8.60000000000000\",\"-8.50000000000001\",\"-8.40000000000001\",\"-8.30000000000001\",\"-8.20000000000001\",\"-8.10000000000001\",\"-8.00000000000001\",\"-7.90000000000001\",\"-7.80000000000001\",\"-7.70000000000001\",\"-7.60000000000001\",\"-7.50000000000001\",\"-7.40000000000001\",\"-7.30000000000001\",\"-7.20000000000001\",\"-7.10000000000001\",\"-7.00000000000001\",\"-6.90000000000001\",\"-6.80000000000001\",\"-6.70000000000001\",\"-6.60000000000001\",\"-6.50000000000001\",\"-6.40000000000001\",\"-6.30000000000001\",\"-6.20000000000001\",\"-6.10000000000001\",\"-6.00000000000001\",\"-5.90000000000001\",\"-5.80000000000001\",\"-5.70000000000002\",\"-5.60000000000002\",\"-5.50000000000002\",\"-5.40000000000002\",\"-5.30000000000002\",\"-5.20000000000002\",\"-5.10000000000002\",\"-5.00000000000002\",\"-4.90000000000002\",\"-4.80000000000002\",\"-4.70000000000002\",\"-4.60000000000002\",\"-4.50000000000002\",\"-4.40000000000002\",\"-4.30000000000002\",\"-4.20000000000002\",\"-4.10000000000002\",\"-4.00000000000002\",\"-3.90000000000002\",\"-3.80000000000002\",\"-3.70000000000002\",\"-3.60000000000002\",\"-3.50000000000002\",\"-3.40000000000002\",\"-3.30000000000002\",\"-3.20000000000002\",\"-3.10000000000002\",\"-3.00000000000002\",\"-2.90000000000002\",\"-2.80000000000002\",\"-2.70000000000002\",\"-2.60000000000002\",\"-2.50000000000002\",\"-2.40000000000002\",\"-2.30000000000002\",\"-2.20000000000002\",\"-2.10000000000002\",\"-2.00000000000002\",\"-1.90000000000002\",\"-1.80000000000002\",\"-1.70000000000002\",\"-1.60000000000002\",\"-1.50000000000002\",\"-1.40000000000002\",\"-1.30000000000002\",\"-1.20000000000002\",\"-1.10000000000002\",\"-1.00000000000002\",\"-0.900000000000019\",\"-0.800000000000019\",\"-0.700000000000019\",\"-0.600000000000019\",\"-0.500000000000019\",\"-0.400000000000019\",\"-0.300000000000019\",\"-0.200000000000019\",\"-0.100000000000019\",\"-1.87905246917808e-14\",\"0.0999999999999812\",\"0.199999999999981\",\"0.299999999999981\",\"0.399999999999981\",\"0.499999999999981\",\"0.599999999999981\",\"0.699999999999981\",\"0.799999999999981\",\"0.899999999999981\",\"0.999999999999981\",\"1.09999999999998\",\"1.19999999999998\",\"1.29999999999998\",\"1.39999999999998\",\"1.49999999999998\",\"1.59999999999998\",\"1.69999999999998\",\"1.79999999999998\",\"1.89999999999998\",\"1.99999999999998\",\"2.09999999999998\",\"2.19999999999998\",\"2.29999999999998\",\"2.39999999999998\",\"2.49999999999998\",\"2.59999999999998\",\"2.69999999999998\",\"2.79999999999998\",\"2.89999999999998\",\"2.99999999999998\",\"3.09999999999998\",\"3.19999999999998\",\"3.29999999999998\",\"3.39999999999998\",\"3.49999999999998\",\"3.59999999999998\",\"3.69999999999998\",\"3.79999999999998\",\"3.89999999999998\",\"3.99999999999998\",\"4.09999999999998\",\"4.19999999999998\",\"4.29999999999998\",\"4.39999999999998\",\"4.49999999999998\",\"4.59999999999998\",\"4.69999999999998\",\"4.79999999999998\",\"4.89999999999998\",\"4.99999999999998\",\"5.09999999999998\",\"5.19999999999998\",\"5.29999999999998\",\"5.39999999999998\",\"5.49999999999998\",\"5.59999999999998\",\"5.69999999999998\",\"5.79999999999998\",\"5.89999999999998\",\"5.99999999999998\",\"6.09999999999998\",\"6.19999999999998\",\"6.29999999999998\",\"6.39999999999998\",\"6.49999999999998\",\"6.59999999999997\",\"6.69999999999997\",\"6.79999999999997\",\"6.89999999999997\",\"6.99999999999997\",\"7.09999999999997\",\"7.19999999999997\",\"7.29999999999997\",\"7.39999999999997\",\"7.49999999999997\",\"7.59999999999997\",\"7.69999999999997\",\"7.79999999999997\",\"7.89999999999997\",\"7.99999999999997\",\"8.09999999999997\",\"8.19999999999997\",\"8.29999999999997\",\"8.39999999999997\",\"8.49999999999997\",\"8.59999999999997\",\"8.69999999999997\",\"8.79999999999997\",\"8.89999999999997\",\"8.99999999999997\",\"9.09999999999997\",\"9.19999999999997\",\"9.29999999999997\",\"9.39999999999996\",\"9.49999999999996\",\"9.59999999999996\",\"9.69999999999996\",\"9.79999999999996\",\"9.89999999999996\",\"10.0000000000000\"]; setTimeout(function() {\n    $('#slider-x_end-8').slider({\n    \tstepping: 1, min: 0, max: 200, startValue: 194,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-x_end-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"x_end\\\", 38, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-x_end-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-x_end-8-lbl').text(values[$('#slider-x_end-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">y_start&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-y_start-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-y_start-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"-10.0000000000000\",\"-9.90000000000000\",\"-9.80000000000000\",\"-9.70000000000000\",\"-9.60000000000000\",\"-9.50000000000000\",\"-9.40000000000000\",\"-9.30000000000000\",\"-9.20000000000000\",\"-9.10000000000000\",\"-9.00000000000000\",\"-8.90000000000000\",\"-8.80000000000000\",\"-8.70000000000000\",\"-8.60000000000000\",\"-8.50000000000001\",\"-8.40000000000001\",\"-8.30000000000001\",\"-8.20000000000001\",\"-8.10000000000001\",\"-8.00000000000001\",\"-7.90000000000001\",\"-7.80000000000001\",\"-7.70000000000001\",\"-7.60000000000001\",\"-7.50000000000001\",\"-7.40000000000001\",\"-7.30000000000001\",\"-7.20000000000001\",\"-7.10000000000001\",\"-7.00000000000001\",\"-6.90000000000001\",\"-6.80000000000001\",\"-6.70000000000001\",\"-6.60000000000001\",\"-6.50000000000001\",\"-6.40000000000001\",\"-6.30000000000001\",\"-6.20000000000001\",\"-6.10000000000001\",\"-6.00000000000001\",\"-5.90000000000001\",\"-5.80000000000001\",\"-5.70000000000002\",\"-5.60000000000002\",\"-5.50000000000002\",\"-5.40000000000002\",\"-5.30000000000002\",\"-5.20000000000002\",\"-5.10000000000002\",\"-5.00000000000002\",\"-4.90000000000002\",\"-4.80000000000002\",\"-4.70000000000002\",\"-4.60000000000002\",\"-4.50000000000002\",\"-4.40000000000002\",\"-4.30000000000002\",\"-4.20000000000002\",\"-4.10000000000002\",\"-4.00000000000002\",\"-3.90000000000002\",\"-3.80000000000002\",\"-3.70000000000002\",\"-3.60000000000002\",\"-3.50000000000002\",\"-3.40000000000002\",\"-3.30000000000002\",\"-3.20000000000002\",\"-3.10000000000002\",\"-3.00000000000002\",\"-2.90000000000002\",\"-2.80000000000002\",\"-2.70000000000002\",\"-2.60000000000002\",\"-2.50000000000002\",\"-2.40000000000002\",\"-2.30000000000002\",\"-2.20000000000002\",\"-2.10000000000002\",\"-2.00000000000002\",\"-1.90000000000002\",\"-1.80000000000002\",\"-1.70000000000002\",\"-1.60000000000002\",\"-1.50000000000002\",\"-1.40000000000002\",\"-1.30000000000002\",\"-1.20000000000002\",\"-1.10000000000002\",\"-1.00000000000002\",\"-0.900000000000019\",\"-0.800000000000019\",\"-0.700000000000019\",\"-0.600000000000019\",\"-0.500000000000019\",\"-0.400000000000019\",\"-0.300000000000019\",\"-0.200000000000019\",\"-0.100000000000019\",\"-1.87905246917808e-14\",\"0.0999999999999812\",\"0.199999999999981\",\"0.299999999999981\",\"0.399999999999981\",\"0.499999999999981\",\"0.599999999999981\",\"0.699999999999981\",\"0.799999999999981\",\"0.899999999999981\",\"0.999999999999981\",\"1.09999999999998\",\"1.19999999999998\",\"1.29999999999998\",\"1.39999999999998\",\"1.49999999999998\",\"1.59999999999998\",\"1.69999999999998\",\"1.79999999999998\",\"1.89999999999998\",\"1.99999999999998\",\"2.09999999999998\",\"2.19999999999998\",\"2.29999999999998\",\"2.39999999999998\",\"2.49999999999998\",\"2.59999999999998\",\"2.69999999999998\",\"2.79999999999998\",\"2.89999999999998\",\"2.99999999999998\",\"3.09999999999998\",\"3.19999999999998\",\"3.29999999999998\",\"3.39999999999998\",\"3.49999999999998\",\"3.59999999999998\",\"3.69999999999998\",\"3.79999999999998\",\"3.89999999999998\",\"3.99999999999998\",\"4.09999999999998\",\"4.19999999999998\",\"4.29999999999998\",\"4.39999999999998\",\"4.49999999999998\",\"4.59999999999998\",\"4.69999999999998\",\"4.79999999999998\",\"4.89999999999998\",\"4.99999999999998\",\"5.09999999999998\",\"5.19999999999998\",\"5.29999999999998\",\"5.39999999999998\",\"5.49999999999998\",\"5.59999999999998\",\"5.69999999999998\",\"5.79999999999998\",\"5.89999999999998\",\"5.99999999999998\",\"6.09999999999998\",\"6.19999999999998\",\"6.29999999999998\",\"6.39999999999998\",\"6.49999999999998\",\"6.59999999999997\",\"6.69999999999997\",\"6.79999999999997\",\"6.89999999999997\",\"6.99999999999997\",\"7.09999999999997\",\"7.19999999999997\",\"7.29999999999997\",\"7.39999999999997\",\"7.49999999999997\",\"7.59999999999997\",\"7.69999999999997\",\"7.79999999999997\",\"7.89999999999997\",\"7.99999999999997\",\"8.09999999999997\",\"8.19999999999997\",\"8.29999999999997\",\"8.39999999999997\",\"8.49999999999997\",\"8.59999999999997\",\"8.69999999999997\",\"8.79999999999997\",\"8.89999999999997\",\"8.99999999999997\",\"9.09999999999997\",\"9.19999999999997\",\"9.29999999999997\",\"9.39999999999996\",\"9.49999999999996\",\"9.59999999999996\",\"9.69999999999996\",\"9.79999999999996\",\"9.89999999999996\",\"10.0000000000000\"]; setTimeout(function() {\n    $('#slider-y_start-8').slider({\n    \tstepping: 1, min: 0, max: 200, startValue: 100,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-y_start-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"y_start\\\", 39, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-y_start-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-y_start-8-lbl').text(values[$('#slider-y_start-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">y_end&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-y_end-8' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-y_end-8-lbl'></font></td></tr></table><script>(function(){ var values = [\"-10.0000000000000\",\"-9.90000000000000\",\"-9.80000000000000\",\"-9.70000000000000\",\"-9.60000000000000\",\"-9.50000000000000\",\"-9.40000000000000\",\"-9.30000000000000\",\"-9.20000000000000\",\"-9.10000000000000\",\"-9.00000000000000\",\"-8.90000000000000\",\"-8.80000000000000\",\"-8.70000000000000\",\"-8.60000000000000\",\"-8.50000000000001\",\"-8.40000000000001\",\"-8.30000000000001\",\"-8.20000000000001\",\"-8.10000000000001\",\"-8.00000000000001\",\"-7.90000000000001\",\"-7.80000000000001\",\"-7.70000000000001\",\"-7.60000000000001\",\"-7.50000000000001\",\"-7.40000000000001\",\"-7.30000000000001\",\"-7.20000000000001\",\"-7.10000000000001\",\"-7.00000000000001\",\"-6.90000000000001\",\"-6.80000000000001\",\"-6.70000000000001\",\"-6.60000000000001\",\"-6.50000000000001\",\"-6.40000000000001\",\"-6.30000000000001\",\"-6.20000000000001\",\"-6.10000000000001\",\"-6.00000000000001\",\"-5.90000000000001\",\"-5.80000000000001\",\"-5.70000000000002\",\"-5.60000000000002\",\"-5.50000000000002\",\"-5.40000000000002\",\"-5.30000000000002\",\"-5.20000000000002\",\"-5.10000000000002\",\"-5.00000000000002\",\"-4.90000000000002\",\"-4.80000000000002\",\"-4.70000000000002\",\"-4.60000000000002\",\"-4.50000000000002\",\"-4.40000000000002\",\"-4.30000000000002\",\"-4.20000000000002\",\"-4.10000000000002\",\"-4.00000000000002\",\"-3.90000000000002\",\"-3.80000000000002\",\"-3.70000000000002\",\"-3.60000000000002\",\"-3.50000000000002\",\"-3.40000000000002\",\"-3.30000000000002\",\"-3.20000000000002\",\"-3.10000000000002\",\"-3.00000000000002\",\"-2.90000000000002\",\"-2.80000000000002\",\"-2.70000000000002\",\"-2.60000000000002\",\"-2.50000000000002\",\"-2.40000000000002\",\"-2.30000000000002\",\"-2.20000000000002\",\"-2.10000000000002\",\"-2.00000000000002\",\"-1.90000000000002\",\"-1.80000000000002\",\"-1.70000000000002\",\"-1.60000000000002\",\"-1.50000000000002\",\"-1.40000000000002\",\"-1.30000000000002\",\"-1.20000000000002\",\"-1.10000000000002\",\"-1.00000000000002\",\"-0.900000000000019\",\"-0.800000000000019\",\"-0.700000000000019\",\"-0.600000000000019\",\"-0.500000000000019\",\"-0.400000000000019\",\"-0.300000000000019\",\"-0.200000000000019\",\"-0.100000000000019\",\"-1.87905246917808e-14\",\"0.0999999999999812\",\"0.199999999999981\",\"0.299999999999981\",\"0.399999999999981\",\"0.499999999999981\",\"0.599999999999981\",\"0.699999999999981\",\"0.799999999999981\",\"0.899999999999981\",\"0.999999999999981\",\"1.09999999999998\",\"1.19999999999998\",\"1.29999999999998\",\"1.39999999999998\",\"1.49999999999998\",\"1.59999999999998\",\"1.69999999999998\",\"1.79999999999998\",\"1.89999999999998\",\"1.99999999999998\",\"2.09999999999998\",\"2.19999999999998\",\"2.29999999999998\",\"2.39999999999998\",\"2.49999999999998\",\"2.59999999999998\",\"2.69999999999998\",\"2.79999999999998\",\"2.89999999999998\",\"2.99999999999998\",\"3.09999999999998\",\"3.19999999999998\",\"3.29999999999998\",\"3.39999999999998\",\"3.49999999999998\",\"3.59999999999998\",\"3.69999999999998\",\"3.79999999999998\",\"3.89999999999998\",\"3.99999999999998\",\"4.09999999999998\",\"4.19999999999998\",\"4.29999999999998\",\"4.39999999999998\",\"4.49999999999998\",\"4.59999999999998\",\"4.69999999999998\",\"4.79999999999998\",\"4.89999999999998\",\"4.99999999999998\",\"5.09999999999998\",\"5.19999999999998\",\"5.29999999999998\",\"5.39999999999998\",\"5.49999999999998\",\"5.59999999999998\",\"5.69999999999998\",\"5.79999999999998\",\"5.89999999999998\",\"5.99999999999998\",\"6.09999999999998\",\"6.19999999999998\",\"6.29999999999998\",\"6.39999999999998\",\"6.49999999999998\",\"6.59999999999997\",\"6.69999999999997\",\"6.79999999999997\",\"6.89999999999997\",\"6.99999999999997\",\"7.09999999999997\",\"7.19999999999997\",\"7.29999999999997\",\"7.39999999999997\",\"7.49999999999997\",\"7.59999999999997\",\"7.69999999999997\",\"7.79999999999997\",\"7.89999999999997\",\"7.99999999999997\",\"8.09999999999997\",\"8.19999999999997\",\"8.29999999999997\",\"8.39999999999997\",\"8.49999999999997\",\"8.59999999999997\",\"8.69999999999997\",\"8.79999999999997\",\"8.89999999999997\",\"8.99999999999997\",\"9.09999999999997\",\"9.19999999999997\",\"9.29999999999997\",\"9.39999999999996\",\"9.49999999999996\",\"9.59999999999996\",\"9.69999999999996\",\"9.79999999999996\",\"9.89999999999996\",\"10.0000000000000\"]; setTimeout(function() {\n    $('#slider-y_end-8').slider({\n    \tstepping: 1, min: 0, max: 200, startValue: 194,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-y_end-8-lbl').text(values[position]); interact(8, \"sage.server.notebook.interact.update(8, \\\"y_end\\\", 40, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(8)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-y_end-8-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-y_end-8-lbl').text(values[$('#slider-y_end-8').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-8'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠feae8d04-c03c-4afb-9320-59ab58d73e9c︠
npi = RDF(pi)
from math import cos,sin
def rot(t):
    return matrix([[cos(t),sin(t)],[-sin(t),cos(t)]])

def pursuit(n,x0,y0,lamb,steps = 100, threshold = .01):
    paths = [[[x0,y0]]]
    for i in range(1,n):
        rx,ry = list(rot(2*npi*i/n)*vector([x0,y0]))
        paths.append([[rx,ry]])
    oldpath = [x[-1] for x in paths]
    for q in range(steps):
        diffs = [[oldpath[(j+1)%n][0]-oldpath[j][0],oldpath[(j+1)%n][1]-oldpath[j][1]] for j in range(n)]
        npath = [[oldpath[j][0]+lamb*diffs[j][0],oldpath[j][1]+lamb*diffs[j][1]] for j in range(n)]
        for j in range(n):
            paths[j].append(npath[j])
        oldpath = npath
    return paths
html('<h3>Curves of Pursuit</h3>')
@interact
def curves_of_pursuit(n = slider([2..20],default = 6, label="# of points"),steps = slider([2^i for i in range(1,10)],default = 10, label="# of steps"), stepsize = slider(srange(.01,1,.01),default = .2, label="stepsize"), colorize = checkbox(default = False)):
    outpaths = pursuit(n,1,0,stepsize, steps = steps)
    mcolor = (0,0,0)
    outer = line([q[0] for q in outpaths]+[outpaths[0][0]], rgbcolor = mcolor)
    if colorize:
        colors = [hue(j/steps,1,1) for j in range(len(outpaths[0]))]
    else:
        colors = [(0,0,0) for j in range(len(outpaths[0]))]
    nested = sum([line([q[j] for q in outpaths]+[outpaths[0][j]], rgbcolor = colors[j]) for j in range(len(outpaths[0]))])
    lpaths = [line(x, rgbcolor = mcolor) for x in outpaths]
    show(sum(lpaths)+nested, axes = False, figsize = [5,5], xmin = -1, xmax = 1, ymin = -1, ymax =1)
︡387b6c43-48a8-4f0f-9acd-1091c42ae2d5︡{"html": "<font color='black'><h3>Curves of Pursuit</h3></font>"}︡{"html": "<!--notruncate--><div padding=6 id='div-interact-9'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\"># of points&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-n-9' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-n-9-lbl'></font></td></tr></table><script>(function(){ var values = [\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\",\"20\"]; setTimeout(function() {\n    $('#slider-n-9').slider({\n    \tstepping: 1, min: 0, max: 18, startValue: 4,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-n-9-lbl').text(values[position]); interact(9, \"sage.server.notebook.interact.update(9, \\\"n\\\", 41, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(9)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-n-9-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-n-9-lbl').text(values[$('#slider-n-9').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\"># of steps&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-steps-9' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-steps-9-lbl'></font></td></tr></table><script>(function(){ var values = [\"2\",\"4\",\"8\",\"16\",\"32\",\"64\",\"128\",\"256\",\"512\"]; setTimeout(function() {\n    $('#slider-steps-9').slider({\n    \tstepping: 1, min: 0, max: 8, startValue: 2,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-steps-9-lbl').text(values[position]); interact(9, \"sage.server.notebook.interact.update(9, \\\"steps\\\", 42, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(9)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-steps-9-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-steps-9-lbl').text(values[$('#slider-steps-9').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">stepsize&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-stepsize-9' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-stepsize-9-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0100000000000000\",\"0.0200000000000000\",\"0.0300000000000000\",\"0.0400000000000000\",\"0.0500000000000000\",\"0.0600000000000000\",\"0.0700000000000000\",\"0.0800000000000000\",\"0.0900000000000000\",\"0.100000000000000\",\"0.110000000000000\",\"0.120000000000000\",\"0.130000000000000\",\"0.140000000000000\",\"0.150000000000000\",\"0.160000000000000\",\"0.170000000000000\",\"0.180000000000000\",\"0.190000000000000\",\"0.200000000000000\",\"0.210000000000000\",\"0.220000000000000\",\"0.230000000000000\",\"0.240000000000000\",\"0.250000000000000\",\"0.260000000000000\",\"0.270000000000000\",\"0.280000000000000\",\"0.290000000000000\",\"0.300000000000000\",\"0.310000000000000\",\"0.320000000000000\",\"0.330000000000000\",\"0.340000000000000\",\"0.350000000000000\",\"0.360000000000000\",\"0.370000000000000\",\"0.380000000000000\",\"0.390000000000000\",\"0.400000000000000\",\"0.410000000000000\",\"0.420000000000000\",\"0.430000000000000\",\"0.440000000000000\",\"0.450000000000000\",\"0.460000000000000\",\"0.470000000000000\",\"0.480000000000000\",\"0.490000000000000\",\"0.500000000000000\",\"0.510000000000000\",\"0.520000000000000\",\"0.530000000000000\",\"0.540000000000000\",\"0.550000000000000\",\"0.560000000000000\",\"0.570000000000000\",\"0.580000000000000\",\"0.590000000000000\",\"0.600000000000000\",\"0.610000000000000\",\"0.620000000000000\",\"0.630000000000000\",\"0.640000000000000\",\"0.650000000000000\",\"0.660000000000000\",\"0.670000000000000\",\"0.680000000000000\",\"0.690000000000000\",\"0.700000000000000\",\"0.710000000000000\",\"0.720000000000000\",\"0.730000000000000\",\"0.740000000000000\",\"0.750000000000000\",\"0.760000000000000\",\"0.770000000000000\",\"0.780000000000000\",\"0.790000000000000\",\"0.800000000000000\",\"0.810000000000000\",\"0.820000000000001\",\"0.830000000000001\",\"0.840000000000001\",\"0.850000000000001\",\"0.860000000000001\",\"0.870000000000001\",\"0.880000000000001\",\"0.890000000000001\",\"0.900000000000001\",\"0.910000000000001\",\"0.920000000000001\",\"0.930000000000001\",\"0.940000000000001\",\"0.950000000000001\",\"0.960000000000001\",\"0.970000000000001\",\"0.980000000000001\",\"0.990000000000001\"]; setTimeout(function() {\n    $('#slider-stepsize-9').slider({\n    \tstepping: 1, min: 0, max: 98, startValue: 19,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-stepsize-9-lbl').text(values[position]); interact(9, \"sage.server.notebook.interact.update(9, \\\"stepsize\\\", 43, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(9)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-stepsize-9-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-stepsize-9-lbl').text(values[$('#slider-stepsize-9').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">colorize&nbsp;</font></td><td><input type='checkbox'  width=200px onchange='interact(9, \"sage.server.notebook.interact.update(9, \\\"colorize\\\", 44, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(9)\")'></input></td></tr>\n</table><div id='cell-interact-9'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠3db934a8-026b-4d8e-bdb0-b6877b021a91︠
var('x,y')
@interact
def example(clr=Color('orange'), f=4*x*exp(-x^2-y^2), xrange='(-2, 2)', yrange='(-2,2)', 
    zrot=(0,pi), xrot=(0,pi), zoom=(1,(1/2,3)), square_aspect=('Square Frame', False),
    tachyon=('Ray Tracer', True)):
    xmin, xmax = sage_eval(xrange); ymin, ymax = sage_eval(yrange)
    P = plot3d(f, (x, xmin, xmax), (y, ymin, ymax), color=clr)
    html('<h1>Plot of $f(x,y) = %s$</h1>'%latex(f))
    aspect_ratio = [1,1,1] if square_aspect else [1,1,1/2]
    show(P.rotate((0,0,1), -zrot).rotate((1,0,0),xrot), 
         viewer='tachyon' if tachyon else 'jmol', 
         figsize=6, zoom=zoom, frame=False,
         frame_aspect_ratio=aspect_ratio)
︡feb4fc27-06a3-42e3-ab00-c15575f3508e︡{"html": "<!--notruncate--><div padding=6 id='div-interact-12'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">clr&nbsp;</font></td><td><table><tr><td><div id='color-selector-clr-12-picker'></div></td><td>\n<input type='text' id='color-selector-clr-12' name='color' onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"clr\\\", 45, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\");$.farbtastic(\"#color-selector-clr-12-picker\").setColor(this.value);' value='#ff8000'/></td></tr></table><script>setTimeout(function() {\n          $('#color-selector-clr-12-picker').farbtastic('#color-selector-clr-12');\n          $.farbtastic('#color-selector-clr-12-picker').linkTo(function(color) {\n              var t = get_element('color-selector-clr-12');\n              if(color!=t.value) {\n                  t.value = color;\n                  t.style.backgroundColor = color; \n                  interact(12, \"sage.server.notebook.interact.update(12, \\\"clr\\\", 45, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(color)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\");\n              }\n              return;\n            })\n       }, 1);</script></td></tr>\n<tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"\n                                         2    2\n                                      - y  - x\n                                4 x  e\" size=80 onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"f\\\", 46, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xrange&nbsp;</font></td><td><input type='text' value=\"(-2, 2)\" size=80 onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"xrange\\\", 47, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">yrange&nbsp;</font></td><td><input type='text' value=\"(-2,2)\" size=80 onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"yrange\\\", 48, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">zrot&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-zrot-12' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-zrot-12-lbl'></font></td></tr></table><script>(function(){ var values = [\"0\",\"0.00200400801603*pi\",\"0.00400801603206*pi\",\"0.0060120240481*pi\",\"0.00801603206413*pi\",\"0.0100200400802*pi\",\"0.0120240480962*pi\",\"0.0140280561122*pi\",\"0.0160320641283*pi\",\"0.0180360721443*pi\",\"0.0200400801603*pi\",\"0.0220440881764*pi\",\"0.0240480961924*pi\",\"0.0260521042084*pi\",\"0.0280561122244*pi\",\"0.0300601202405*pi\",\"0.0320641282565*pi\",\"0.0340681362725*pi\",\"0.0360721442886*pi\",\"0.0380761523046*pi\",\"0.0400801603206*pi\",\"0.0420841683367*pi\",\"0.0440881763527*pi\",\"0.0460921843687*pi\",\"0.0480961923848*pi\",\"0.0501002004008*pi\",\"0.0521042084168*pi\",\"0.0541082164329*pi\",\"0.0561122244489*pi\",\"0.0581162324649*pi\",\"0.060120240481*pi\",\"0.062124248497*pi\",\"0.064128256513*pi\",\"0.0661322645291*pi\",\"0.0681362725451*pi\",\"0.0701402805611*pi\",\"0.0721442885772*pi\",\"0.0741482965932*pi\",\"0.0761523046092*pi\",\"0.0781563126253*pi\",\"0.0801603206413*pi\",\"0.0821643286573*pi\",\"0.0841683366733*pi\",\"0.0861723446894*pi\",\"0.0881763527054*pi\",\"0.0901803607214*pi\",\"0.0921843687375*pi\",\"0.0941883767535*pi\",\"0.0961923847695*pi\",\"0.0981963927856*pi\",\"0.100200400802*pi\",\"0.102204408818*pi\",\"0.104208416834*pi\",\"0.10621242485*pi\",\"0.108216432866*pi\",\"0.110220440882*pi\",\"0.112224448898*pi\",\"0.114228456914*pi\",\"0.11623246493*pi\",\"0.118236472946*pi\",\"0.120240480962*pi\",\"0.122244488978*pi\",\"0.124248496994*pi\",\"0.12625250501*pi\",\"0.128256513026*pi\",\"0.130260521042*pi\",\"0.132264529058*pi\",\"0.134268537074*pi\",\"0.13627254509*pi\",\"0.138276553106*pi\",\"0.140280561122*pi\",\"0.142284569138*pi\",\"0.144288577154*pi\",\"0.14629258517*pi\",\"0.148296593186*pi\",\"0.150300601202*pi\",\"0.152304609218*pi\",\"0.154308617234*pi\",\"0.156312625251*pi\",\"0.158316633267*pi\",\"0.160320641283*pi\",\"0.162324649299*pi\",\"0.164328657315*pi\",\"0.166332665331*pi\",\"0.168336673347*pi\",\"0.170340681363*pi\",\"0.172344689379*pi\",\"0.174348697395*pi\",\"0.176352705411*pi\",\"0.178356713427*pi\",\"0.180360721443*pi\",\"0.182364729459*pi\",\"0.184368737475*pi\",\"0.186372745491*pi\",\"0.188376753507*pi\",\"0.190380761523*pi\",\"0.192384769539*pi\",\"0.194388777555*pi\",\"0.196392785571*pi\",\"0.198396793587*pi\",\"0.200400801603*pi\",\"0.202404809619*pi\",\"0.204408817635*pi\",\"0.206412825651*pi\",\"0.208416833667*pi\",\"0.210420841683*pi\",\"0.212424849699*pi\",\"0.214428857715*pi\",\"0.216432865731*pi\",\"0.218436873747*pi\",\"0.220440881764*pi\",\"0.22244488978*pi\",\"0.224448897796*pi\",\"0.226452905812*pi\",\"0.228456913828*pi\",\"0.230460921844*pi\",\"0.23246492986*pi\",\"0.234468937876*pi\",\"0.236472945892*pi\",\"0.238476953908*pi\",\"0.240480961924*pi\",\"0.24248496994*pi\",\"0.244488977956*pi\",\"0.246492985972*pi\",\"0.248496993988*pi\",\"0.250501002004*pi\",\"0.25250501002*pi\",\"0.254509018036*pi\",\"0.256513026052*pi\",\"0.258517034068*pi\",\"0.260521042084*pi\",\"0.2625250501*pi\",\"0.264529058116*pi\",\"0.266533066132*pi\",\"0.268537074148*pi\",\"0.270541082164*pi\",\"0.27254509018*pi\",\"0.274549098196*pi\",\"0.276553106212*pi\",\"0.278557114228*pi\",\"0.280561122244*pi\",\"0.282565130261*pi\",\"0.284569138277*pi\",\"0.286573146293*pi\",\"0.288577154309*pi\",\"0.290581162325*pi\",\"0.292585170341*pi\",\"0.294589178357*pi\",\"0.296593186373*pi\",\"0.298597194389*pi\",\"0.300601202405*pi\",\"0.302605210421*pi\",\"0.304609218437*pi\",\"0.306613226453*pi\",\"0.308617234469*pi\",\"0.310621242485*pi\",\"0.312625250501*pi\",\"0.314629258517*pi\",\"0.316633266533*pi\",\"0.318637274549*pi\",\"0.320641282565*pi\",\"0.322645290581*pi\",\"0.324649298597*pi\",\"0.326653306613*pi\",\"0.328657314629*pi\",\"0.330661322645*pi\",\"0.332665330661*pi\",\"0.334669338677*pi\",\"0.336673346693*pi\",\"0.338677354709*pi\",\"0.340681362725*pi\",\"0.342685370741*pi\",\"0.344689378758*pi\",\"0.346693386774*pi\",\"0.34869739479*pi\",\"0.350701402806*pi\",\"0.352705410822*pi\",\"0.354709418838*pi\",\"0.356713426854*pi\",\"0.35871743487*pi\",\"0.360721442886*pi\",\"0.362725450902*pi\",\"0.364729458918*pi\",\"0.366733466934*pi\",\"0.36873747495*pi\",\"0.370741482966*pi\",\"0.372745490982*pi\",\"0.374749498998*pi\",\"0.376753507014*pi\",\"0.37875751503*pi\",\"0.380761523046*pi\",\"0.382765531062*pi\",\"0.384769539078*pi\",\"0.386773547094*pi\",\"0.38877755511*pi\",\"0.390781563126*pi\",\"0.392785571142*pi\",\"0.394789579158*pi\",\"0.396793587174*pi\",\"0.39879759519*pi\",\"0.400801603206*pi\",\"0.402805611222*pi\",\"0.404809619238*pi\",\"0.406813627255*pi\",\"0.408817635271*pi\",\"0.410821643287*pi\",\"0.412825651303*pi\",\"0.414829659319*pi\",\"0.416833667335*pi\",\"0.418837675351*pi\",\"0.420841683367*pi\",\"0.422845691383*pi\",\"0.424849699399*pi\",\"0.426853707415*pi\",\"0.428857715431*pi\",\"0.430861723447*pi\",\"0.432865731463*pi\",\"0.434869739479*pi\",\"0.436873747495*pi\",\"0.438877755511*pi\",\"0.440881763527*pi\",\"0.442885771543*pi\",\"0.444889779559*pi\",\"0.446893787575*pi\",\"0.448897795591*pi\",\"0.450901803607*pi\",\"0.452905811623*pi\",\"0.454909819639*pi\",\"0.456913827655*pi\",\"0.458917835671*pi\",\"0.460921843687*pi\",\"0.462925851703*pi\",\"0.464929859719*pi\",\"0.466933867735*pi\",\"0.468937875752*pi\",\"0.470941883768*pi\",\"0.472945891784*pi\",\"0.4749498998*pi\",\"0.476953907816*pi\",\"0.478957915832*pi\",\"0.480961923848*pi\",\"0.482965931864*pi\",\"0.48496993988*pi\",\"0.486973947896*pi\",\"0.488977955912*pi\",\"0.490981963928*pi\",\"0.492985971944*pi\",\"0.49498997996*pi\",\"0.496993987976*pi\",\"0.498997995992*pi\",\"0.501002004008*pi\",\"0.503006012024*pi\",\"0.50501002004*pi\",\"0.507014028056*pi\",\"0.509018036072*pi\",\"0.511022044088*pi\",\"0.513026052104*pi\",\"0.51503006012*pi\",\"0.517034068136*pi\",\"0.519038076152*pi\",\"0.521042084168*pi\",\"0.523046092184*pi\",\"0.5250501002*pi\",\"0.527054108216*pi\",\"0.529058116232*pi\",\"0.531062124248*pi\",\"0.533066132265*pi\",\"0.535070140281*pi\",\"0.537074148297*pi\",\"0.539078156313*pi\",\"0.541082164329*pi\",\"0.543086172345*pi\",\"0.545090180361*pi\",\"0.547094188377*pi\",\"0.549098196393*pi\",\"0.551102204409*pi\",\"0.553106212425*pi\",\"0.555110220441*pi\",\"0.557114228457*pi\",\"0.559118236473*pi\",\"0.561122244489*pi\",\"0.563126252505*pi\",\"0.565130260521*pi\",\"0.567134268537*pi\",\"0.569138276553*pi\",\"0.571142284569*pi\",\"0.573146292585*pi\",\"0.575150300601*pi\",\"0.577154308617*pi\",\"0.579158316633*pi\",\"0.581162324649*pi\",\"0.583166332665*pi\",\"0.585170340681*pi\",\"0.587174348697*pi\",\"0.589178356713*pi\",\"0.591182364729*pi\",\"0.593186372745*pi\",\"0.595190380762*pi\",\"0.597194388778*pi\",\"0.599198396794*pi\",\"0.60120240481*pi\",\"0.603206412826*pi\",\"0.605210420842*pi\",\"0.607214428858*pi\",\"0.609218436874*pi\",\"0.61122244489*pi\",\"0.613226452906*pi\",\"0.615230460922*pi\",\"0.617234468938*pi\",\"0.619238476954*pi\",\"0.62124248497*pi\",\"0.623246492986*pi\",\"0.625250501002*pi\",\"0.627254509018*pi\",\"0.629258517034*pi\",\"0.63126252505*pi\",\"0.633266533066*pi\",\"0.635270541082*pi\",\"0.637274549098*pi\",\"0.639278557114*pi\",\"0.64128256513*pi\",\"0.643286573146*pi\",\"0.645290581162*pi\",\"0.647294589178*pi\",\"0.649298597194*pi\",\"0.65130260521*pi\",\"0.653306613226*pi\",\"0.655310621242*pi\",\"0.657314629259*pi\",\"0.659318637275*pi\",\"0.661322645291*pi\",\"0.663326653307*pi\",\"0.665330661323*pi\",\"0.667334669339*pi\",\"0.669338677355*pi\",\"0.671342685371*pi\",\"0.673346693387*pi\",\"0.675350701403*pi\",\"0.677354709419*pi\",\"0.679358717435*pi\",\"0.681362725451*pi\",\"0.683366733467*pi\",\"0.685370741483*pi\",\"0.687374749499*pi\",\"0.689378757515*pi\",\"0.691382765531*pi\",\"0.693386773547*pi\",\"0.695390781563*pi\",\"0.697394789579*pi\",\"0.699398797595*pi\",\"0.701402805611*pi\",\"0.703406813627*pi\",\"0.705410821643*pi\",\"0.707414829659*pi\",\"0.709418837675*pi\",\"0.711422845691*pi\",\"0.713426853707*pi\",\"0.715430861723*pi\",\"0.717434869739*pi\",\"0.719438877756*pi\",\"0.721442885772*pi\",\"0.723446893788*pi\",\"0.725450901804*pi\",\"0.72745490982*pi\",\"0.729458917836*pi\",\"0.731462925852*pi\",\"0.733466933868*pi\",\"0.735470941884*pi\",\"0.7374749499*pi\",\"0.739478957916*pi\",\"0.741482965932*pi\",\"0.743486973948*pi\",\"0.745490981964*pi\",\"0.74749498998*pi\",\"0.749498997996*pi\",\"0.751503006012*pi\",\"0.753507014028*pi\",\"0.755511022044*pi\",\"0.75751503006*pi\",\"0.759519038076*pi\",\"0.761523046092*pi\",\"0.763527054108*pi\",\"0.765531062124*pi\",\"0.76753507014*pi\",\"0.769539078156*pi\",\"0.771543086172*pi\",\"0.773547094188*pi\",\"0.775551102204*pi\",\"0.77755511022*pi\",\"0.779559118236*pi\",\"0.781563126253*pi\",\"0.783567134269*pi\",\"0.785571142285*pi\",\"0.787575150301*pi\",\"0.789579158317*pi\",\"0.791583166333*pi\",\"0.793587174349*pi\",\"0.795591182365*pi\",\"0.797595190381*pi\",\"0.799599198397*pi\",\"0.801603206413*pi\",\"0.803607214429*pi\",\"0.805611222445*pi\",\"0.807615230461*pi\",\"0.809619238477*pi\",\"0.811623246493*pi\",\"0.813627254509*pi\",\"0.815631262525*pi\",\"0.817635270541*pi\",\"0.819639278557*pi\",\"0.821643286573*pi\",\"0.823647294589*pi\",\"0.825651302605*pi\",\"0.827655310621*pi\",\"0.829659318637*pi\",\"0.831663326653*pi\",\"0.833667334669*pi\",\"0.835671342685*pi\",\"0.837675350701*pi\",\"0.839679358717*pi\",\"0.841683366733*pi\",\"0.843687374749*pi\",\"0.845691382766*pi\",\"0.847695390782*pi\",\"0.849699398798*pi\",\"0.851703406814*pi\",\"0.85370741483*pi\",\"0.855711422846*pi\",\"0.857715430862*pi\",\"0.859719438878*pi\",\"0.861723446894*pi\",\"0.86372745491*pi\",\"0.865731462926*pi\",\"0.867735470942*pi\",\"0.869739478958*pi\",\"0.871743486974*pi\",\"0.87374749499*pi\",\"0.875751503006*pi\",\"0.877755511022*pi\",\"0.879759519038*pi\",\"0.881763527054*pi\",\"0.88376753507*pi\",\"0.885771543086*pi\",\"0.887775551102*pi\",\"0.889779559118*pi\",\"0.891783567134*pi\",\"0.89378757515*pi\",\"0.895791583166*pi\",\"0.897795591182*pi\",\"0.899799599198*pi\",\"0.901803607214*pi\",\"0.90380761523*pi\",\"0.905811623246*pi\",\"0.907815631263*pi\",\"0.909819639279*pi\",\"0.911823647295*pi\",\"0.913827655311*pi\",\"0.915831663327*pi\",\"0.917835671343*pi\",\"0.919839679359*pi\",\"0.921843687375*pi\",\"0.923847695391*pi\",\"0.925851703407*pi\",\"0.927855711423*pi\",\"0.929859719439*pi\",\"0.931863727455*pi\",\"0.933867735471*pi\",\"0.935871743487*pi\",\"0.937875751503*pi\",\"0.939879759519*pi\",\"0.941883767535*pi\",\"0.943887775551*pi\",\"0.945891783567*pi\",\"0.947895791583*pi\",\"0.949899799599*pi\",\"0.951903807615*pi\",\"0.953907815631*pi\",\"0.955911823647*pi\",\"0.957915831663*pi\",\"0.959919839679*pi\",\"0.961923847695*pi\",\"0.963927855711*pi\",\"0.965931863727*pi\",\"0.967935871743*pi\",\"0.96993987976*pi\",\"0.971943887776*pi\",\"0.973947895792*pi\",\"0.975951903808*pi\",\"0.977955911824*pi\",\"0.97995991984*pi\",\"0.981963927856*pi\",\"0.983967935872*pi\",\"0.985971943888*pi\",\"0.987975951904*pi\",\"0.98997995992*pi\",\"0.991983967936*pi\",\"0.993987975952*pi\",\"0.995991983968*pi\",\"0.997995991984*pi\",\"pi\"]; setTimeout(function() {\n    $('#slider-zrot-12').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 0,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-zrot-12-lbl').text(values[position]); interact(12, \"sage.server.notebook.interact.update(12, \\\"zrot\\\", 49, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-zrot-12-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-zrot-12-lbl').text(values[$('#slider-zrot-12').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">xrot&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-xrot-12' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-xrot-12-lbl'></font></td></tr></table><script>(function(){ var values = [\"0\",\"0.00200400801603*pi\",\"0.00400801603206*pi\",\"0.0060120240481*pi\",\"0.00801603206413*pi\",\"0.0100200400802*pi\",\"0.0120240480962*pi\",\"0.0140280561122*pi\",\"0.0160320641283*pi\",\"0.0180360721443*pi\",\"0.0200400801603*pi\",\"0.0220440881764*pi\",\"0.0240480961924*pi\",\"0.0260521042084*pi\",\"0.0280561122244*pi\",\"0.0300601202405*pi\",\"0.0320641282565*pi\",\"0.0340681362725*pi\",\"0.0360721442886*pi\",\"0.0380761523046*pi\",\"0.0400801603206*pi\",\"0.0420841683367*pi\",\"0.0440881763527*pi\",\"0.0460921843687*pi\",\"0.0480961923848*pi\",\"0.0501002004008*pi\",\"0.0521042084168*pi\",\"0.0541082164329*pi\",\"0.0561122244489*pi\",\"0.0581162324649*pi\",\"0.060120240481*pi\",\"0.062124248497*pi\",\"0.064128256513*pi\",\"0.0661322645291*pi\",\"0.0681362725451*pi\",\"0.0701402805611*pi\",\"0.0721442885772*pi\",\"0.0741482965932*pi\",\"0.0761523046092*pi\",\"0.0781563126253*pi\",\"0.0801603206413*pi\",\"0.0821643286573*pi\",\"0.0841683366733*pi\",\"0.0861723446894*pi\",\"0.0881763527054*pi\",\"0.0901803607214*pi\",\"0.0921843687375*pi\",\"0.0941883767535*pi\",\"0.0961923847695*pi\",\"0.0981963927856*pi\",\"0.100200400802*pi\",\"0.102204408818*pi\",\"0.104208416834*pi\",\"0.10621242485*pi\",\"0.108216432866*pi\",\"0.110220440882*pi\",\"0.112224448898*pi\",\"0.114228456914*pi\",\"0.11623246493*pi\",\"0.118236472946*pi\",\"0.120240480962*pi\",\"0.122244488978*pi\",\"0.124248496994*pi\",\"0.12625250501*pi\",\"0.128256513026*pi\",\"0.130260521042*pi\",\"0.132264529058*pi\",\"0.134268537074*pi\",\"0.13627254509*pi\",\"0.138276553106*pi\",\"0.140280561122*pi\",\"0.142284569138*pi\",\"0.144288577154*pi\",\"0.14629258517*pi\",\"0.148296593186*pi\",\"0.150300601202*pi\",\"0.152304609218*pi\",\"0.154308617234*pi\",\"0.156312625251*pi\",\"0.158316633267*pi\",\"0.160320641283*pi\",\"0.162324649299*pi\",\"0.164328657315*pi\",\"0.166332665331*pi\",\"0.168336673347*pi\",\"0.170340681363*pi\",\"0.172344689379*pi\",\"0.174348697395*pi\",\"0.176352705411*pi\",\"0.178356713427*pi\",\"0.180360721443*pi\",\"0.182364729459*pi\",\"0.184368737475*pi\",\"0.186372745491*pi\",\"0.188376753507*pi\",\"0.190380761523*pi\",\"0.192384769539*pi\",\"0.194388777555*pi\",\"0.196392785571*pi\",\"0.198396793587*pi\",\"0.200400801603*pi\",\"0.202404809619*pi\",\"0.204408817635*pi\",\"0.206412825651*pi\",\"0.208416833667*pi\",\"0.210420841683*pi\",\"0.212424849699*pi\",\"0.214428857715*pi\",\"0.216432865731*pi\",\"0.218436873747*pi\",\"0.220440881764*pi\",\"0.22244488978*pi\",\"0.224448897796*pi\",\"0.226452905812*pi\",\"0.228456913828*pi\",\"0.230460921844*pi\",\"0.23246492986*pi\",\"0.234468937876*pi\",\"0.236472945892*pi\",\"0.238476953908*pi\",\"0.240480961924*pi\",\"0.24248496994*pi\",\"0.244488977956*pi\",\"0.246492985972*pi\",\"0.248496993988*pi\",\"0.250501002004*pi\",\"0.25250501002*pi\",\"0.254509018036*pi\",\"0.256513026052*pi\",\"0.258517034068*pi\",\"0.260521042084*pi\",\"0.2625250501*pi\",\"0.264529058116*pi\",\"0.266533066132*pi\",\"0.268537074148*pi\",\"0.270541082164*pi\",\"0.27254509018*pi\",\"0.274549098196*pi\",\"0.276553106212*pi\",\"0.278557114228*pi\",\"0.280561122244*pi\",\"0.282565130261*pi\",\"0.284569138277*pi\",\"0.286573146293*pi\",\"0.288577154309*pi\",\"0.290581162325*pi\",\"0.292585170341*pi\",\"0.294589178357*pi\",\"0.296593186373*pi\",\"0.298597194389*pi\",\"0.300601202405*pi\",\"0.302605210421*pi\",\"0.304609218437*pi\",\"0.306613226453*pi\",\"0.308617234469*pi\",\"0.310621242485*pi\",\"0.312625250501*pi\",\"0.314629258517*pi\",\"0.316633266533*pi\",\"0.318637274549*pi\",\"0.320641282565*pi\",\"0.322645290581*pi\",\"0.324649298597*pi\",\"0.326653306613*pi\",\"0.328657314629*pi\",\"0.330661322645*pi\",\"0.332665330661*pi\",\"0.334669338677*pi\",\"0.336673346693*pi\",\"0.338677354709*pi\",\"0.340681362725*pi\",\"0.342685370741*pi\",\"0.344689378758*pi\",\"0.346693386774*pi\",\"0.34869739479*pi\",\"0.350701402806*pi\",\"0.352705410822*pi\",\"0.354709418838*pi\",\"0.356713426854*pi\",\"0.35871743487*pi\",\"0.360721442886*pi\",\"0.362725450902*pi\",\"0.364729458918*pi\",\"0.366733466934*pi\",\"0.36873747495*pi\",\"0.370741482966*pi\",\"0.372745490982*pi\",\"0.374749498998*pi\",\"0.376753507014*pi\",\"0.37875751503*pi\",\"0.380761523046*pi\",\"0.382765531062*pi\",\"0.384769539078*pi\",\"0.386773547094*pi\",\"0.38877755511*pi\",\"0.390781563126*pi\",\"0.392785571142*pi\",\"0.394789579158*pi\",\"0.396793587174*pi\",\"0.39879759519*pi\",\"0.400801603206*pi\",\"0.402805611222*pi\",\"0.404809619238*pi\",\"0.406813627255*pi\",\"0.408817635271*pi\",\"0.410821643287*pi\",\"0.412825651303*pi\",\"0.414829659319*pi\",\"0.416833667335*pi\",\"0.418837675351*pi\",\"0.420841683367*pi\",\"0.422845691383*pi\",\"0.424849699399*pi\",\"0.426853707415*pi\",\"0.428857715431*pi\",\"0.430861723447*pi\",\"0.432865731463*pi\",\"0.434869739479*pi\",\"0.436873747495*pi\",\"0.438877755511*pi\",\"0.440881763527*pi\",\"0.442885771543*pi\",\"0.444889779559*pi\",\"0.446893787575*pi\",\"0.448897795591*pi\",\"0.450901803607*pi\",\"0.452905811623*pi\",\"0.454909819639*pi\",\"0.456913827655*pi\",\"0.458917835671*pi\",\"0.460921843687*pi\",\"0.462925851703*pi\",\"0.464929859719*pi\",\"0.466933867735*pi\",\"0.468937875752*pi\",\"0.470941883768*pi\",\"0.472945891784*pi\",\"0.4749498998*pi\",\"0.476953907816*pi\",\"0.478957915832*pi\",\"0.480961923848*pi\",\"0.482965931864*pi\",\"0.48496993988*pi\",\"0.486973947896*pi\",\"0.488977955912*pi\",\"0.490981963928*pi\",\"0.492985971944*pi\",\"0.49498997996*pi\",\"0.496993987976*pi\",\"0.498997995992*pi\",\"0.501002004008*pi\",\"0.503006012024*pi\",\"0.50501002004*pi\",\"0.507014028056*pi\",\"0.509018036072*pi\",\"0.511022044088*pi\",\"0.513026052104*pi\",\"0.51503006012*pi\",\"0.517034068136*pi\",\"0.519038076152*pi\",\"0.521042084168*pi\",\"0.523046092184*pi\",\"0.5250501002*pi\",\"0.527054108216*pi\",\"0.529058116232*pi\",\"0.531062124248*pi\",\"0.533066132265*pi\",\"0.535070140281*pi\",\"0.537074148297*pi\",\"0.539078156313*pi\",\"0.541082164329*pi\",\"0.543086172345*pi\",\"0.545090180361*pi\",\"0.547094188377*pi\",\"0.549098196393*pi\",\"0.551102204409*pi\",\"0.553106212425*pi\",\"0.555110220441*pi\",\"0.557114228457*pi\",\"0.559118236473*pi\",\"0.561122244489*pi\",\"0.563126252505*pi\",\"0.565130260521*pi\",\"0.567134268537*pi\",\"0.569138276553*pi\",\"0.571142284569*pi\",\"0.573146292585*pi\",\"0.575150300601*pi\",\"0.577154308617*pi\",\"0.579158316633*pi\",\"0.581162324649*pi\",\"0.583166332665*pi\",\"0.585170340681*pi\",\"0.587174348697*pi\",\"0.589178356713*pi\",\"0.591182364729*pi\",\"0.593186372745*pi\",\"0.595190380762*pi\",\"0.597194388778*pi\",\"0.599198396794*pi\",\"0.60120240481*pi\",\"0.603206412826*pi\",\"0.605210420842*pi\",\"0.607214428858*pi\",\"0.609218436874*pi\",\"0.61122244489*pi\",\"0.613226452906*pi\",\"0.615230460922*pi\",\"0.617234468938*pi\",\"0.619238476954*pi\",\"0.62124248497*pi\",\"0.623246492986*pi\",\"0.625250501002*pi\",\"0.627254509018*pi\",\"0.629258517034*pi\",\"0.63126252505*pi\",\"0.633266533066*pi\",\"0.635270541082*pi\",\"0.637274549098*pi\",\"0.639278557114*pi\",\"0.64128256513*pi\",\"0.643286573146*pi\",\"0.645290581162*pi\",\"0.647294589178*pi\",\"0.649298597194*pi\",\"0.65130260521*pi\",\"0.653306613226*pi\",\"0.655310621242*pi\",\"0.657314629259*pi\",\"0.659318637275*pi\",\"0.661322645291*pi\",\"0.663326653307*pi\",\"0.665330661323*pi\",\"0.667334669339*pi\",\"0.669338677355*pi\",\"0.671342685371*pi\",\"0.673346693387*pi\",\"0.675350701403*pi\",\"0.677354709419*pi\",\"0.679358717435*pi\",\"0.681362725451*pi\",\"0.683366733467*pi\",\"0.685370741483*pi\",\"0.687374749499*pi\",\"0.689378757515*pi\",\"0.691382765531*pi\",\"0.693386773547*pi\",\"0.695390781563*pi\",\"0.697394789579*pi\",\"0.699398797595*pi\",\"0.701402805611*pi\",\"0.703406813627*pi\",\"0.705410821643*pi\",\"0.707414829659*pi\",\"0.709418837675*pi\",\"0.711422845691*pi\",\"0.713426853707*pi\",\"0.715430861723*pi\",\"0.717434869739*pi\",\"0.719438877756*pi\",\"0.721442885772*pi\",\"0.723446893788*pi\",\"0.725450901804*pi\",\"0.72745490982*pi\",\"0.729458917836*pi\",\"0.731462925852*pi\",\"0.733466933868*pi\",\"0.735470941884*pi\",\"0.7374749499*pi\",\"0.739478957916*pi\",\"0.741482965932*pi\",\"0.743486973948*pi\",\"0.745490981964*pi\",\"0.74749498998*pi\",\"0.749498997996*pi\",\"0.751503006012*pi\",\"0.753507014028*pi\",\"0.755511022044*pi\",\"0.75751503006*pi\",\"0.759519038076*pi\",\"0.761523046092*pi\",\"0.763527054108*pi\",\"0.765531062124*pi\",\"0.76753507014*pi\",\"0.769539078156*pi\",\"0.771543086172*pi\",\"0.773547094188*pi\",\"0.775551102204*pi\",\"0.77755511022*pi\",\"0.779559118236*pi\",\"0.781563126253*pi\",\"0.783567134269*pi\",\"0.785571142285*pi\",\"0.787575150301*pi\",\"0.789579158317*pi\",\"0.791583166333*pi\",\"0.793587174349*pi\",\"0.795591182365*pi\",\"0.797595190381*pi\",\"0.799599198397*pi\",\"0.801603206413*pi\",\"0.803607214429*pi\",\"0.805611222445*pi\",\"0.807615230461*pi\",\"0.809619238477*pi\",\"0.811623246493*pi\",\"0.813627254509*pi\",\"0.815631262525*pi\",\"0.817635270541*pi\",\"0.819639278557*pi\",\"0.821643286573*pi\",\"0.823647294589*pi\",\"0.825651302605*pi\",\"0.827655310621*pi\",\"0.829659318637*pi\",\"0.831663326653*pi\",\"0.833667334669*pi\",\"0.835671342685*pi\",\"0.837675350701*pi\",\"0.839679358717*pi\",\"0.841683366733*pi\",\"0.843687374749*pi\",\"0.845691382766*pi\",\"0.847695390782*pi\",\"0.849699398798*pi\",\"0.851703406814*pi\",\"0.85370741483*pi\",\"0.855711422846*pi\",\"0.857715430862*pi\",\"0.859719438878*pi\",\"0.861723446894*pi\",\"0.86372745491*pi\",\"0.865731462926*pi\",\"0.867735470942*pi\",\"0.869739478958*pi\",\"0.871743486974*pi\",\"0.87374749499*pi\",\"0.875751503006*pi\",\"0.877755511022*pi\",\"0.879759519038*pi\",\"0.881763527054*pi\",\"0.88376753507*pi\",\"0.885771543086*pi\",\"0.887775551102*pi\",\"0.889779559118*pi\",\"0.891783567134*pi\",\"0.89378757515*pi\",\"0.895791583166*pi\",\"0.897795591182*pi\",\"0.899799599198*pi\",\"0.901803607214*pi\",\"0.90380761523*pi\",\"0.905811623246*pi\",\"0.907815631263*pi\",\"0.909819639279*pi\",\"0.911823647295*pi\",\"0.913827655311*pi\",\"0.915831663327*pi\",\"0.917835671343*pi\",\"0.919839679359*pi\",\"0.921843687375*pi\",\"0.923847695391*pi\",\"0.925851703407*pi\",\"0.927855711423*pi\",\"0.929859719439*pi\",\"0.931863727455*pi\",\"0.933867735471*pi\",\"0.935871743487*pi\",\"0.937875751503*pi\",\"0.939879759519*pi\",\"0.941883767535*pi\",\"0.943887775551*pi\",\"0.945891783567*pi\",\"0.947895791583*pi\",\"0.949899799599*pi\",\"0.951903807615*pi\",\"0.953907815631*pi\",\"0.955911823647*pi\",\"0.957915831663*pi\",\"0.959919839679*pi\",\"0.961923847695*pi\",\"0.963927855711*pi\",\"0.965931863727*pi\",\"0.967935871743*pi\",\"0.96993987976*pi\",\"0.971943887776*pi\",\"0.973947895792*pi\",\"0.975951903808*pi\",\"0.977955911824*pi\",\"0.97995991984*pi\",\"0.981963927856*pi\",\"0.983967935872*pi\",\"0.985971943888*pi\",\"0.987975951904*pi\",\"0.98997995992*pi\",\"0.991983967936*pi\",\"0.993987975952*pi\",\"0.995991983968*pi\",\"0.997995991984*pi\",\"pi\"]; setTimeout(function() {\n    $('#slider-xrot-12').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 0,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-xrot-12-lbl').text(values[position]); interact(12, \"sage.server.notebook.interact.update(12, \\\"xrot\\\", 50, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-xrot-12-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-xrot-12-lbl').text(values[$('#slider-xrot-12').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">zoom&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-zoom-12' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-zoom-12-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.5\",\"0.50501002004008011\",\"0.51002004008016022\",\"0.51503006012024033\",\"0.52004008016032044\",\"0.52505010020040055\",\"0.53006012024048066\",\"0.53507014028056077\",\"0.54008016032064088\",\"0.54509018036072099\",\"0.5501002004008011\",\"0.55511022044088121\",\"0.56012024048096132\",\"0.56513026052104143\",\"0.57014028056112154\",\"0.57515030060120165\",\"0.58016032064128176\",\"0.58517034068136187\",\"0.59018036072144198\",\"0.59519038076152209\",\"0.6002004008016022\",\"0.60521042084168231\",\"0.61022044088176242\",\"0.61523046092184253\",\"0.62024048096192264\",\"0.62525050100200275\",\"0.63026052104208286\",\"0.63527054108216297\",\"0.64028056112224307\",\"0.64529058116232318\",\"0.65030060120240329\",\"0.6553106212424834\",\"0.66032064128256351\",\"0.66533066132264362\",\"0.67034068136272373\",\"0.67535070140280384\",\"0.68036072144288395\",\"0.68537074148296406\",\"0.69038076152304417\",\"0.69539078156312428\",\"0.70040080160320439\",\"0.7054108216432845\",\"0.71042084168336461\",\"0.71543086172344472\",\"0.72044088176352483\",\"0.72545090180360494\",\"0.73046092184368505\",\"0.73547094188376516\",\"0.74048096192384527\",\"0.74549098196392538\",\"0.75050100200400549\",\"0.7555110220440856\",\"0.76052104208416571\",\"0.76553106212424582\",\"0.77054108216432593\",\"0.77555110220440604\",\"0.78056112224448615\",\"0.78557114228456626\",\"0.79058116232464637\",\"0.79559118236472648\",\"0.80060120240480659\",\"0.8056112224448867\",\"0.81062124248496681\",\"0.81563126252504692\",\"0.82064128256512703\",\"0.82565130260520714\",\"0.83066132264528725\",\"0.83567134268536736\",\"0.84068136272544747\",\"0.84569138276552758\",\"0.85070140280560769\",\"0.8557114228456878\",\"0.86072144288576791\",\"0.86573146292584802\",\"0.87074148296592813\",\"0.87575150300600824\",\"0.88076152304608835\",\"0.88577154308616846\",\"0.89078156312624857\",\"0.89579158316632868\",\"0.90080160320640879\",\"0.9058116232464889\",\"0.910821643286569\",\"0.91583166332664911\",\"0.92084168336672922\",\"0.92585170340680933\",\"0.93086172344688944\",\"0.93587174348696955\",\"0.94088176352704966\",\"0.94589178356712977\",\"0.95090180360720988\",\"0.95591182364728999\",\"0.9609218436873701\",\"0.96593186372745021\",\"0.97094188376753032\",\"0.97595190380761043\",\"0.98096192384769054\",\"0.98597194388777065\",\"0.99098196392785076\",\"0.99599198396793087\",\"1.001002004008011\",\"1.0060120240480912\",\"1.0110220440881714\",\"1.0160320641282516\",\"1.0210420841683319\",\"1.0260521042084121\",\"1.0310621242484923\",\"1.0360721442885725\",\"1.0410821643286527\",\"1.046092184368733\",\"1.0511022044088132\",\"1.0561122244488934\",\"1.0611222444889736\",\"1.0661322645290539\",\"1.0711422845691341\",\"1.0761523046092143\",\"1.0811623246492945\",\"1.0861723446893747\",\"1.091182364729455\",\"1.0961923847695352\",\"1.1012024048096154\",\"1.1062124248496956\",\"1.1112224448897758\",\"1.1162324649298561\",\"1.1212424849699363\",\"1.1262525050100165\",\"1.1312625250500967\",\"1.1362725450901769\",\"1.1412825651302572\",\"1.1462925851703374\",\"1.1513026052104176\",\"1.1563126252504978\",\"1.161322645290578\",\"1.1663326653306583\",\"1.1713426853707385\",\"1.1763527054108187\",\"1.1813627254508989\",\"1.1863727454909792\",\"1.1913827655310594\",\"1.1963927855711396\",\"1.2014028056112198\",\"1.2064128256513\",\"1.2114228456913803\",\"1.2164328657314605\",\"1.2214428857715407\",\"1.2264529058116209\",\"1.2314629258517011\",\"1.2364729458917814\",\"1.2414829659318616\",\"1.2464929859719418\",\"1.251503006012022\",\"1.2565130260521022\",\"1.2615230460921825\",\"1.2665330661322627\",\"1.2715430861723429\",\"1.2765531062124231\",\"1.2815631262525033\",\"1.2865731462925836\",\"1.2915831663326638\",\"1.296593186372744\",\"1.3016032064128242\",\"1.3066132264529045\",\"1.3116232464929847\",\"1.3166332665330649\",\"1.3216432865731451\",\"1.3266533066132253\",\"1.3316633266533056\",\"1.3366733466933858\",\"1.341683366733466\",\"1.3466933867735462\",\"1.3517034068136264\",\"1.3567134268537067\",\"1.3617234468937869\",\"1.3667334669338671\",\"1.3717434869739473\",\"1.3767535070140275\",\"1.3817635270541078\",\"1.386773547094188\",\"1.3917835671342682\",\"1.3967935871743484\",\"1.4018036072144286\",\"1.4068136272545089\",\"1.4118236472945891\",\"1.4168336673346693\",\"1.4218436873747495\",\"1.4268537074148298\",\"1.43186372745491\",\"1.4368737474949902\",\"1.4418837675350704\",\"1.4468937875751506\",\"1.4519038076152309\",\"1.4569138276553111\",\"1.4619238476953913\",\"1.4669338677354715\",\"1.4719438877755517\",\"1.476953907815632\",\"1.4819639278557122\",\"1.4869739478957924\",\"1.4919839679358726\",\"1.4969939879759528\",\"1.5020040080160331\",\"1.5070140280561133\",\"1.5120240480961935\",\"1.5170340681362737\",\"1.5220440881763539\",\"1.5270541082164342\",\"1.5320641282565144\",\"1.5370741482965946\",\"1.5420841683366748\",\"1.5470941883767551\",\"1.5521042084168353\",\"1.5571142284569155\",\"1.5621242484969957\",\"1.5671342685370759\",\"1.5721442885771562\",\"1.5771543086172364\",\"1.5821643286573166\",\"1.5871743486973968\",\"1.592184368737477\",\"1.5971943887775573\",\"1.6022044088176375\",\"1.6072144288577177\",\"1.6122244488977979\",\"1.6172344689378781\",\"1.6222444889779584\",\"1.6272545090180386\",\"1.6322645290581188\",\"1.637274549098199\",\"1.6422845691382792\",\"1.6472945891783595\",\"1.6523046092184397\",\"1.6573146292585199\",\"1.6623246492986001\",\"1.6673346693386804\",\"1.6723446893787606\",\"1.6773547094188408\",\"1.682364729458921\",\"1.6873747494990012\",\"1.6923847695390815\",\"1.6973947895791617\",\"1.7024048096192419\",\"1.7074148296593221\",\"1.7124248496994023\",\"1.7174348697394826\",\"1.7224448897795628\",\"1.727454909819643\",\"1.7324649298597232\",\"1.7374749498998034\",\"1.7424849699398837\",\"1.7474949899799639\",\"1.7525050100200441\",\"1.7575150300601243\",\"1.7625250501002045\",\"1.7675350701402848\",\"1.772545090180365\",\"1.7775551102204452\",\"1.7825651302605254\",\"1.7875751503006057\",\"1.7925851703406859\",\"1.7975951903807661\",\"1.8026052104208463\",\"1.8076152304609265\",\"1.8126252505010068\",\"1.817635270541087\",\"1.8226452905811672\",\"1.8276553106212474\",\"1.8326653306613276\",\"1.8376753507014079\",\"1.8426853707414881\",\"1.8476953907815683\",\"1.8527054108216485\",\"1.8577154308617287\",\"1.862725450901809\",\"1.8677354709418892\",\"1.8727454909819694\",\"1.8777555110220496\",\"1.8827655310621298\",\"1.8877755511022101\",\"1.8927855711422903\",\"1.8977955911823705\",\"1.9028056112224507\",\"1.907815631262531\",\"1.9128256513026112\",\"1.9178356713426914\",\"1.9228456913827716\",\"1.9278557114228518\",\"1.9328657314629321\",\"1.9378757515030123\",\"1.9428857715430925\",\"1.9478957915831727\",\"1.9529058116232529\",\"1.9579158316633332\",\"1.9629258517034134\",\"1.9679358717434936\",\"1.9729458917835738\",\"1.977955911823654\",\"1.9829659318637343\",\"1.9879759519038145\",\"1.9929859719438947\",\"1.9979959919839749\",\"2.0030060120240551\",\"2.0080160320641354\",\"2.0130260521042156\",\"2.0180360721442958\",\"2.023046092184376\",\"2.0280561122244563\",\"2.0330661322645365\",\"2.0380761523046167\",\"2.0430861723446969\",\"2.0480961923847771\",\"2.0531062124248574\",\"2.0581162324649376\",\"2.0631262525050178\",\"2.068136272545098\",\"2.0731462925851782\",\"2.0781563126252585\",\"2.0831663326653387\",\"2.0881763527054189\",\"2.0931863727454991\",\"2.0981963927855793\",\"2.1032064128256596\",\"2.1082164328657398\",\"2.11322645290582\",\"2.1182364729459002\",\"2.1232464929859804\",\"2.1282565130260607\",\"2.1332665330661409\",\"2.1382765531062211\",\"2.1432865731463013\",\"2.1482965931863816\",\"2.1533066132264618\",\"2.158316633266542\",\"2.1633266533066222\",\"2.1683366733467024\",\"2.1733466933867827\",\"2.1783567134268629\",\"2.1833667334669431\",\"2.1883767535070233\",\"2.1933867735471035\",\"2.1983967935871838\",\"2.203406813627264\",\"2.2084168336673442\",\"2.2134268537074244\",\"2.2184368737475046\",\"2.2234468937875849\",\"2.2284569138276651\",\"2.2334669338677453\",\"2.2384769539078255\",\"2.2434869739479057\",\"2.248496993987986\",\"2.2535070140280662\",\"2.2585170340681464\",\"2.2635270541082266\",\"2.2685370741483069\",\"2.2735470941883871\",\"2.2785571142284673\",\"2.2835671342685475\",\"2.2885771543086277\",\"2.293587174348708\",\"2.2985971943887882\",\"2.3036072144288684\",\"2.3086172344689486\",\"2.3136272545090288\",\"2.3186372745491091\",\"2.3236472945891893\",\"2.3286573146292695\",\"2.3336673346693497\",\"2.3386773547094299\",\"2.3436873747495102\",\"2.3486973947895904\",\"2.3537074148296706\",\"2.3587174348697508\",\"2.363727454909831\",\"2.3687374749499113\",\"2.3737474949899915\",\"2.3787575150300717\",\"2.3837675350701519\",\"2.3887775551102322\",\"2.3937875751503124\",\"2.3987975951903926\",\"2.4038076152304728\",\"2.408817635270553\",\"2.4138276553106333\",\"2.4188376753507135\",\"2.4238476953907937\",\"2.4288577154308739\",\"2.4338677354709541\",\"2.4388777555110344\",\"2.4438877755511146\",\"2.4488977955911948\",\"2.453907815631275\",\"2.4589178356713552\",\"2.4639278557114355\",\"2.4689378757515157\",\"2.4739478957915959\",\"2.4789579158316761\",\"2.4839679358717563\",\"2.4889779559118366\",\"2.4939879759519168\",\"2.498997995991997\",\"2.5040080160320772\",\"2.5090180360721575\",\"2.5140280561122377\",\"2.5190380761523179\",\"2.5240480961923981\",\"2.5290581162324783\",\"2.5340681362725586\",\"2.5390781563126388\",\"2.544088176352719\",\"2.5490981963927992\",\"2.5541082164328794\",\"2.5591182364729597\",\"2.5641282565130399\",\"2.5691382765531201\",\"2.5741482965932003\",\"2.5791583166332805\",\"2.5841683366733608\",\"2.589178356713441\",\"2.5941883767535212\",\"2.5991983967936014\",\"2.6042084168336816\",\"2.6092184368737619\",\"2.6142284569138421\",\"2.6192384769539223\",\"2.6242484969940025\",\"2.6292585170340828\",\"2.634268537074163\",\"2.6392785571142432\",\"2.6442885771543234\",\"2.6492985971944036\",\"2.6543086172344839\",\"2.6593186372745641\",\"2.6643286573146443\",\"2.6693386773547245\",\"2.6743486973948047\",\"2.679358717434885\",\"2.6843687374749652\",\"2.6893787575150454\",\"2.6943887775551256\",\"2.6993987975952058\",\"2.7044088176352861\",\"2.7094188376753663\",\"2.7144288577154465\",\"2.7194388777555267\",\"2.7244488977956069\",\"2.7294589178356872\",\"2.7344689378757674\",\"2.7394789579158476\",\"2.7444889779559278\",\"2.7494989979960081\",\"2.7545090180360883\",\"2.7595190380761685\",\"2.7645290581162487\",\"2.7695390781563289\",\"2.7745490981964092\",\"2.7795591182364894\",\"2.7845691382765696\",\"2.7895791583166498\",\"2.79458917835673\",\"2.7995991983968103\",\"2.8046092184368905\",\"2.8096192384769707\",\"2.8146292585170509\",\"2.8196392785571311\",\"2.8246492985972114\",\"2.8296593186372916\",\"2.8346693386773718\",\"2.839679358717452\",\"2.8446893787575322\",\"2.8496993987976125\",\"2.8547094188376927\",\"2.8597194388777729\",\"2.8647294589178531\",\"2.8697394789579334\",\"2.8747494989980136\",\"2.8797595190380938\",\"2.884769539078174\",\"2.8897795591182542\",\"2.8947895791583345\",\"2.8997995991984147\",\"2.9048096192384949\",\"2.9098196392785751\",\"2.9148296593186553\",\"2.9198396793587356\",\"2.9248496993988158\",\"2.929859719438896\",\"2.9348697394789762\",\"2.9398797595190564\",\"2.9448897795591367\",\"2.9498997995992169\",\"2.9549098196392971\",\"2.9599198396793773\",\"2.9649298597194575\",\"2.9699398797595378\",\"2.974949899799618\",\"2.9799599198396982\",\"2.9849699398797784\",\"2.9899799599198587\",\"2.9949899799599389\",\"3.0\"]; setTimeout(function() {\n    $('#slider-zoom-12').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 100,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-zoom-12-lbl').text(values[position]); interact(12, \"sage.server.notebook.interact.update(12, \\\"zoom\\\", 51, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-zoom-12-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-zoom-12-lbl').text(values[$('#slider-zoom-12').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">Square Frame&nbsp;</font></td><td><input type='checkbox'  width=200px onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"square_aspect\\\", 52, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">Ray Tracer&nbsp;</font></td><td><input type='checkbox' checked width=200px onchange='interact(12, \"sage.server.notebook.interact.update(12, \\\"tachyon\\\", 53, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(12)\")'></input></td></tr>\n</table><div id='cell-interact-12'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠db7fc83f-8c4d-4ad8-bf75-bf29545dae96︠
var('s,t')
g(s) = ((0.57496*sqrt(121 - 16.0*s^2))/sqrt(10.+ s))
def P(color, rng):
    return parametric_plot3d((cos(t)*g(s), sin(t)*g(s), s), (s,rng[0],rng[1]), (t,0,2*pi), plot_points = [150,150], rgbcolor=color, frame = False, opacity = 1)
colorlist = ['red','blue','red','blue']
@interact
def _(band_number = selector(range(1,5)), current_color = Color('red')):
    html('<h1 align=center>Egg Painter</h1>')
    colorlist[band_number-1] = current_color
    egg = sum([P(colorlist[i],[-2.75+5.5*(i/4),-2.75+5.5*(i+1)/4]) for i in range(4)])
    show(egg)
︡df03bafa-b8ae-4c79-9dc4-cf51997337c8︡{"html": "<!--notruncate--><div padding=6 id='div-interact-13'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">band_number&nbsp;</font></td><td><select onchange='interact(13, \"sage.server.notebook.interact.update(13, \\\"band_number\\\", 54, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.options[this.selectedIndex].value)+\"\\\"), globals());sage.server.notebook.interact.recompute(13)\");'><option value='0' selected>1</option>\n<option value='1' >2</option>\n<option value='2' >3</option>\n<option value='3' >4</option>\n</select></td></tr>\n<tr><td align=right><font color=\"black\">current_color&nbsp;</font></td><td><table><tr><td><div id='color-selector-current_color-13-picker'></div></td><td>\n<input type='text' id='color-selector-current_color-13' name='color' onchange='interact(13, \"sage.server.notebook.interact.update(13, \\\"current_color\\\", 55, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(13)\");$.farbtastic(\"#color-selector-current_color-13-picker\").setColor(this.value);' value='#ff0000'/></td></tr></table><script>setTimeout(function() {\n          $('#color-selector-current_color-13-picker').farbtastic('#color-selector-current_color-13');\n          $.farbtastic('#color-selector-current_color-13-picker').linkTo(function(color) {\n              var t = get_element('color-selector-current_color-13');\n              if(color!=t.value) {\n                  t.value = color;\n                  t.style.backgroundColor = color; \n                  interact(13, \"sage.server.notebook.interact.update(13, \\\"current_color\\\", 55, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(color)+\"\\\"), globals());sage.server.notebook.interact.recompute(13)\");\n              }\n              return;\n            })\n       }, 1);</script></td></tr>\n</table><div id='cell-interact-13'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠605f895e-7ba3-4609-8139-f53bc05d8b6f︠
@interact
def color_experimenter(expression=input_box('', 'Expression', str), color=Color('red')):
    if expression:
        try:
            plot(SR(expression), rgbcolor=color).show()
        except TypeError:
            print "There's a problem with your expression."
︡8ce9826d-cc9a-4ae1-a2e5-8286098183a9︡{"html": "<!--notruncate--><div padding=6 id='div-interact-14'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">Expression&nbsp;</font></td><td><input type='text' value=\"\" size=80 onchange='interact(14, \"sage.server.notebook.interact.update(14, \\\"expression\\\", 56, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(14)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">color&nbsp;</font></td><td><table><tr><td><div id='color-selector-color-14-picker'></div></td><td>\n<input type='text' id='color-selector-color-14' name='color' onchange='interact(14, \"sage.server.notebook.interact.update(14, \\\"color\\\", 57, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(14)\");$.farbtastic(\"#color-selector-color-14-picker\").setColor(this.value);' value='#ff0000'/></td></tr></table><script>setTimeout(function() {\n          $('#color-selector-color-14-picker').farbtastic('#color-selector-color-14');\n          $.farbtastic('#color-selector-color-14-picker').linkTo(function(color) {\n              var t = get_element('color-selector-color-14');\n              if(color!=t.value) {\n                  t.value = color;\n                  t.style.backgroundColor = color; \n                  interact(14, \"sage.server.notebook.interact.update(14, \\\"color\\\", 57, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(color)+\"\\\"), globals());sage.server.notebook.interact.recompute(14)\");\n              }\n              return;\n            })\n       }, 1);</script></td></tr>\n</table><div id='cell-interact-14'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠4d014d7f-5bae-49ef-a954-3ac7953f5b8d︠
def error_msg(msg):
    print '<html><p style="font-family:Arial, sans-serif;color:#000"><span style="color:red;font-weight:bold">Error</span>: %s</p></html>' % msg

@interact
def interactive_2d_plotter(expression=input_box('sin(x)', 'Expression', str), x_range=range_slider(-10,10,1,(0,10), label='X Range'), square=checkbox(True, 'Square'), axes=checkbox(False, 'Show Axes')):
    if expression:
        try:
            expression = SR(expression) # turn string into a Sage expression
        except TypeError:
            print error_msg('This is not an expression.')
            return
        try:
                xmin, xmax = x_range
                if square or not axes:
                    print "var('%s')\nplot(%s).show(%s%s%s)" % (expression.variables()[0], repr(expression), 'aspect_ratio=1' if square else '', ', ' if square and not axes else '', 'axes=False' if not axes else '')
                    if square:
                        plot(expression, xmin, xmax).show(aspect_ratio=1, axes=axes)
                    else:
                        plot(expression, xmin, xmax).show(axes=axes)
                else:
                    print "var('%s')\nplot(%s)" % (expression.variables()[0], repr(expression))
                    plot(expression, xmin, xmax).show(axes=axes)
        except ValueError:
            print error_msg('This expression has more than one variable.')
            return
        except TypeError:
            print error_msg("This expression contains an unknown function.")
            return
︡024b47fb-37f0-4db8-ade9-58560ff61a7f︡{"html": "<!--notruncate--><div padding=6 id='div-interact-15'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">Expression&nbsp;</font></td><td><input type='text' value=\"sin(x)\" size=80 onchange='interact(15, \"sage.server.notebook.interact.update(15, \\\"expression\\\", 58, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(15)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">X Range&nbsp;</font></td><td><table>\n    <tr><td><div id='slider-x_range-15' class='ui-slider ui-slider-3' style='margin:0px;'>\n    <span class='ui-slider-handle'></span><span class='ui-slider-handle'></span>\n    </div></td></tr><tr><td><font color='black' id='slider-x_range-15-lbl'></font></td></tr></table><script>(function()\n    {\n        var values = [\"-10\",\"-9\",\"-8\",\"-7\",\"-6\",\"-5\",\"-4\",\"-3\",\"-2\",\"-1\",\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\"];\n        var pos = [10, 20];\n        var sel = '#slider-x_range-15';\n        var updatePos = function()\n        {\n            pos[0]=$(sel).slider('value', 0);\n            pos[1]=$(sel).slider('value', 1);\n            if(values!=null) $(sel+'-lbl').text(\"(\"+values[pos[0]]+\", \"+values[pos[1]]+\")\");\n        };\n        setTimeout(function()\n        {\n            $(sel).slider(\n            {\n                range: true,\n                stepping: 1,                \t\n                min: 0,\n                max: 20,\n                handles: [{start: 10},{start:20}],\n                change: function(e,ui){ updatePos(); interact(15, \"sage.server.notebook.interact.update(15, \\\"x_range\\\", 59, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(pos[0]+' '+pos[1])+\"\\\"), globals());sage.server.notebook.interact.recompute(15)\"); },\n                slide: updatePos\n            });\n            updatePos();\n        }, 1);\n    })();</script></td></tr>\n<tr><td align=right><font color=\"black\">Square&nbsp;</font></td><td><input type='checkbox' checked width=200px onchange='interact(15, \"sage.server.notebook.interact.update(15, \\\"square\\\", 60, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(15)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">Show Axes&nbsp;</font></td><td><input type='checkbox'  width=200px onchange='interact(15, \"sage.server.notebook.interact.update(15, \\\"axes\\\", 61, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.checked)+\"\\\"), globals());sage.server.notebook.interact.recompute(15)\")'></input></td></tr>\n</table><div id='cell-interact-15'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠5b7648dd-3e06-4b1f-a3b7-36f4d76a1cb6︠
x,y = var('x,y')
@interact
def _(f = input_box(default=y), g=input_box(default=-x*y+x^3-x), 
      xmin=input_box(default=-1), xmax=input_box(default=1), 
      ymin=input_box(default=-1), ymax=input_box(default=1), 
      start_x=input_box(default=0.5), start_y=input_box(default=0.5),  
      step_size=(0.01,(0.001, 0.2)), steps=(600,(0, 1400)) ):
    old_f = f
    f = f.function(x,y)
    old_g = g
    g = g.function(x,y)
    steps = int(steps)

    points = [ (start_x, start_y) ]
    for i in range(steps):
        xx, yy = points[-1]
        try:
            points.append( (xx+step_size*f(xx,yy), yy+step_size*g(xx,yy)) )
        except (ValueError, ArithmeticError, TypeError):
            break

    starting_point = point(points[0], pointsize=50)
    solution = line(points)
    vector_field = plot_vector_field( (f,g), (x,xmin,xmax), (y,ymin,ymax) )

    result = vector_field + starting_point + solution
    
    html(r"<h2>$ \frac{dx}{dt} = %s$  $ \frac{dy}{dt} = %s$</h2>"%(latex(old_f),latex(old_g)))
    print "Step size: %s"%step_size
    print "Steps: %s"%steps
    result.show(xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax)
︡367a2cfe-e15b-4450-af53-43be2ceb452d︡{"html": "<!--notruncate--><div padding=6 id='div-interact-16'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">f&nbsp;</font></td><td><input type='text' value=\"y\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"f\\\", 62, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">g&nbsp;</font></td><td><input type='text' value=\"\n                                         3\n                                - x y + x  - x\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"g\\\", 63, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmin&nbsp;</font></td><td><input type='text' value=\"-1\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"xmin\\\", 64, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmax&nbsp;</font></td><td><input type='text' value=\"1\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"xmax\\\", 65, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">ymin&nbsp;</font></td><td><input type='text' value=\"-1\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"ymin\\\", 66, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">ymax&nbsp;</font></td><td><input type='text' value=\"1\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"ymax\\\", 67, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">start_x&nbsp;</font></td><td><input type='text' value=\"0.500000000000000\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"start_x\\\", 68, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">start_y&nbsp;</font></td><td><input type='text' value=\"0.500000000000000\" size=80 onchange='interact(16, \"sage.server.notebook.interact.update(16, \\\"start_y\\\", 69, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">step_size&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-step_size-16' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-step_size-16-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.00100000000000000\",\"0.00139879759519038\",\"0.00179759519038076\",\"0.00219639278557114\",\"0.00259519038076152\",\"0.00299398797595190\",\"0.00339278557114228\",\"0.00379158316633266\",\"0.00419038076152305\",\"0.00458917835671343\",\"0.00498797595190381\",\"0.00538677354709419\",\"0.00578557114228457\",\"0.00618436873747495\",\"0.00658316633266533\",\"0.00698196392785571\",\"0.00738076152304609\",\"0.00777955911823647\",\"0.00817835671342685\",\"0.00857715430861723\",\"0.00897595190380761\",\"0.00937474949899800\",\"0.00977354709418838\",\"0.0101723446893788\",\"0.0105711422845691\",\"0.0109699398797595\",\"0.0113687374749499\",\"0.0117675350701403\",\"0.0121663326653307\",\"0.0125651302605210\",\"0.0129639278557114\",\"0.0133627254509018\",\"0.0137615230460922\",\"0.0141603206412826\",\"0.0145591182364729\",\"0.0149579158316633\",\"0.0153567134268537\",\"0.0157555110220441\",\"0.0161543086172345\",\"0.0165531062124249\",\"0.0169519038076152\",\"0.0173507014028056\",\"0.0177494989979960\",\"0.0181482965931864\",\"0.0185470941883768\",\"0.0189458917835671\",\"0.0193446893787575\",\"0.0197434869739479\",\"0.0201422845691383\",\"0.0205410821643287\",\"0.0209398797595191\",\"0.0213386773547094\",\"0.0217374749498998\",\"0.0221362725450902\",\"0.0225350701402806\",\"0.0229338677354710\",\"0.0233326653306614\",\"0.0237314629258517\",\"0.0241302605210421\",\"0.0245290581162325\",\"0.0249278557114229\",\"0.0253266533066133\",\"0.0257254509018036\",\"0.0261242484969940\",\"0.0265230460921844\",\"0.0269218436873748\",\"0.0273206412825652\",\"0.0277194388777556\",\"0.0281182364729459\",\"0.0285170340681363\",\"0.0289158316633267\",\"0.0293146292585171\",\"0.0297134268537075\",\"0.0301122244488979\",\"0.0305110220440882\",\"0.0309098196392786\",\"0.0313086172344690\",\"0.0317074148296594\",\"0.0321062124248498\",\"0.0325050100200402\",\"0.0329038076152305\",\"0.0333026052104209\",\"0.0337014028056113\",\"0.0341002004008017\",\"0.0344989979959921\",\"0.0348977955911824\",\"0.0352965931863728\",\"0.0356953907815632\",\"0.0360941883767536\",\"0.0364929859719440\",\"0.0368917835671344\",\"0.0372905811623247\",\"0.0376893787575151\",\"0.0380881763527055\",\"0.0384869739478959\",\"0.0388857715430863\",\"0.0392845691382767\",\"0.0396833667334670\",\"0.0400821643286574\",\"0.0404809619238478\",\"0.0408797595190382\",\"0.0412785571142286\",\"0.0416773547094189\",\"0.0420761523046093\",\"0.0424749498997997\",\"0.0428737474949901\",\"0.0432725450901805\",\"0.0436713426853709\",\"0.0440701402805612\",\"0.0444689378757516\",\"0.0448677354709420\",\"0.0452665330661324\",\"0.0456653306613228\",\"0.0460641282565132\",\"0.0464629258517035\",\"0.0468617234468939\",\"0.0472605210420843\",\"0.0476593186372747\",\"0.0480581162324651\",\"0.0484569138276554\",\"0.0488557114228458\",\"0.0492545090180362\",\"0.0496533066132266\",\"0.0500521042084170\",\"0.0504509018036074\",\"0.0508496993987977\",\"0.0512484969939881\",\"0.0516472945891785\",\"0.0520460921843689\",\"0.0524448897795593\",\"0.0528436873747497\",\"0.0532424849699400\",\"0.0536412825651304\",\"0.0540400801603208\",\"0.0544388777555112\",\"0.0548376753507016\",\"0.0552364729458919\",\"0.0556352705410823\",\"0.0560340681362727\",\"0.0564328657314631\",\"0.0568316633266535\",\"0.0572304609218439\",\"0.0576292585170342\",\"0.0580280561122246\",\"0.0584268537074150\",\"0.0588256513026054\",\"0.0592244488977958\",\"0.0596232464929862\",\"0.0600220440881765\",\"0.0604208416833669\",\"0.0608196392785573\",\"0.0612184368737477\",\"0.0616172344689381\",\"0.0620160320641285\",\"0.0624148296593188\",\"0.0628136272545092\",\"0.0632124248496996\",\"0.0636112224448900\",\"0.0640100200400803\",\"0.0644088176352707\",\"0.0648076152304611\",\"0.0652064128256515\",\"0.0656052104208418\",\"0.0660040080160322\",\"0.0664028056112226\",\"0.0668016032064130\",\"0.0672004008016033\",\"0.0675991983967937\",\"0.0679979959919841\",\"0.0683967935871745\",\"0.0687955911823648\",\"0.0691943887775552\",\"0.0695931863727456\",\"0.0699919839679360\",\"0.0703907815631264\",\"0.0707895791583167\",\"0.0711883767535071\",\"0.0715871743486975\",\"0.0719859719438879\",\"0.0723847695390782\",\"0.0727835671342686\",\"0.0731823647294590\",\"0.0735811623246494\",\"0.0739799599198397\",\"0.0743787575150301\",\"0.0747775551102205\",\"0.0751763527054109\",\"0.0755751503006012\",\"0.0759739478957916\",\"0.0763727454909820\",\"0.0767715430861724\",\"0.0771703406813627\",\"0.0775691382765531\",\"0.0779679358717435\",\"0.0783667334669339\",\"0.0787655310621242\",\"0.0791643286573146\",\"0.0795631262525050\",\"0.0799619238476954\",\"0.0803607214428857\",\"0.0807595190380761\",\"0.0811583166332665\",\"0.0815571142284569\",\"0.0819559118236472\",\"0.0823547094188376\",\"0.0827535070140280\",\"0.0831523046092184\",\"0.0835511022044087\",\"0.0839498997995991\",\"0.0843486973947895\",\"0.0847474949899799\",\"0.0851462925851702\",\"0.0855450901803606\",\"0.0859438877755510\",\"0.0863426853707414\",\"0.0867414829659317\",\"0.0871402805611221\",\"0.0875390781563125\",\"0.0879378757515029\",\"0.0883366733466932\",\"0.0887354709418836\",\"0.0891342685370740\",\"0.0895330661322644\",\"0.0899318637274547\",\"0.0903306613226451\",\"0.0907294589178355\",\"0.0911282565130259\",\"0.0915270541082163\",\"0.0919258517034066\",\"0.0923246492985970\",\"0.0927234468937874\",\"0.0931222444889778\",\"0.0935210420841681\",\"0.0939198396793585\",\"0.0943186372745489\",\"0.0947174348697393\",\"0.0951162324649296\",\"0.0955150300601200\",\"0.0959138276553104\",\"0.0963126252505008\",\"0.0967114228456911\",\"0.0971102204408815\",\"0.0975090180360719\",\"0.0979078156312623\",\"0.0983066132264526\",\"0.0987054108216430\",\"0.0991042084168334\",\"0.0995030060120238\",\"0.0999018036072141\",\"0.100300601202405\",\"0.100699398797595\",\"0.101098196392785\",\"0.101496993987976\",\"0.101895791583166\",\"0.102294589178356\",\"0.102693386773547\",\"0.103092184368737\",\"0.103490981963928\",\"0.103889779559118\",\"0.104288577154308\",\"0.104687374749499\",\"0.105086172344689\",\"0.105484969939879\",\"0.105883767535070\",\"0.106282565130260\",\"0.106681362725451\",\"0.107080160320641\",\"0.107478957915831\",\"0.107877755511022\",\"0.108276553106212\",\"0.108675350701402\",\"0.109074148296593\",\"0.109472945891783\",\"0.109871743486974\",\"0.110270541082164\",\"0.110669338677354\",\"0.111068136272545\",\"0.111466933867735\",\"0.111865731462925\",\"0.112264529058116\",\"0.112663326653306\",\"0.113062124248497\",\"0.113460921843687\",\"0.113859719438877\",\"0.114258517034068\",\"0.114657314629258\",\"0.115056112224448\",\"0.115454909819639\",\"0.115853707414829\",\"0.116252505010020\",\"0.116651302605210\",\"0.117050100200400\",\"0.117448897795591\",\"0.117847695390781\",\"0.118246492985971\",\"0.118645290581162\",\"0.119044088176352\",\"0.119442885771543\",\"0.119841683366733\",\"0.120240480961923\",\"0.120639278557114\",\"0.121038076152304\",\"0.121436873747494\",\"0.121835671342685\",\"0.122234468937875\",\"0.122633266533066\",\"0.123032064128256\",\"0.123430861723446\",\"0.123829659318637\",\"0.124228456913827\",\"0.124627254509017\",\"0.125026052104208\",\"0.125424849699398\",\"0.125823647294589\",\"0.126222444889779\",\"0.126621242484969\",\"0.127020040080160\",\"0.127418837675350\",\"0.127817635270540\",\"0.128216432865731\",\"0.128615230460921\",\"0.129014028056112\",\"0.129412825651302\",\"0.129811623246492\",\"0.130210420841683\",\"0.130609218436873\",\"0.131008016032063\",\"0.131406813627254\",\"0.131805611222444\",\"0.132204408817635\",\"0.132603206412825\",\"0.133002004008015\",\"0.133400801603206\",\"0.133799599198396\",\"0.134198396793586\",\"0.134597194388777\",\"0.134995991983967\",\"0.135394789579158\",\"0.135793587174348\",\"0.136192384769538\",\"0.136591182364729\",\"0.136989979959919\",\"0.137388777555109\",\"0.137787575150300\",\"0.138186372745490\",\"0.138585170340681\",\"0.138983967935871\",\"0.139382765531061\",\"0.139781563126252\",\"0.140180360721442\",\"0.140579158316632\",\"0.140977955911823\",\"0.141376753507013\",\"0.141775551102204\",\"0.142174348697394\",\"0.142573146292584\",\"0.142971943887775\",\"0.143370741482965\",\"0.143769539078155\",\"0.144168336673346\",\"0.144567134268536\",\"0.144965931863727\",\"0.145364729458917\",\"0.145763527054107\",\"0.146162324649298\",\"0.146561122244488\",\"0.146959919839678\",\"0.147358717434869\",\"0.147757515030059\",\"0.148156312625250\",\"0.148555110220440\",\"0.148953907815630\",\"0.149352705410821\",\"0.149751503006011\",\"0.150150300601201\",\"0.150549098196392\",\"0.150947895791582\",\"0.151346693386773\",\"0.151745490981963\",\"0.152144288577153\",\"0.152543086172344\",\"0.152941883767534\",\"0.153340681362724\",\"0.153739478957915\",\"0.154138276553105\",\"0.154537074148296\",\"0.154935871743486\",\"0.155334669338676\",\"0.155733466933867\",\"0.156132264529057\",\"0.156531062124247\",\"0.156929859719438\",\"0.157328657314628\",\"0.157727454909819\",\"0.158126252505009\",\"0.158525050100199\",\"0.158923847695390\",\"0.159322645290580\",\"0.159721442885770\",\"0.160120240480961\",\"0.160519038076151\",\"0.160917835671342\",\"0.161316633266532\",\"0.161715430861722\",\"0.162114228456913\",\"0.162513026052103\",\"0.162911823647293\",\"0.163310621242484\",\"0.163709418837674\",\"0.164108216432865\",\"0.164507014028055\",\"0.164905811623245\",\"0.165304609218436\",\"0.165703406813626\",\"0.166102204408816\",\"0.166501002004007\",\"0.166899799599197\",\"0.167298597194388\",\"0.167697394789578\",\"0.168096192384768\",\"0.168494989979959\",\"0.168893787575149\",\"0.169292585170339\",\"0.169691382765530\",\"0.170090180360720\",\"0.170488977955911\",\"0.170887775551101\",\"0.171286573146291\",\"0.171685370741482\",\"0.172084168336672\",\"0.172482965931862\",\"0.172881763527053\",\"0.173280561122243\",\"0.173679358717434\",\"0.174078156312624\",\"0.174476953907814\",\"0.174875751503005\",\"0.175274549098195\",\"0.175673346693385\",\"0.176072144288576\",\"0.176470941883766\",\"0.176869739478957\",\"0.177268537074147\",\"0.177667334669337\",\"0.178066132264528\",\"0.178464929859718\",\"0.178863727454908\",\"0.179262525050099\",\"0.179661322645289\",\"0.180060120240480\",\"0.180458917835670\",\"0.180857715430860\",\"0.181256513026051\",\"0.181655310621241\",\"0.182054108216432\",\"0.182452905811622\",\"0.182851703406812\",\"0.183250501002003\",\"0.183649298597193\",\"0.184048096192383\",\"0.184446893787574\",\"0.184845691382764\",\"0.185244488977955\",\"0.185643286573145\",\"0.186042084168335\",\"0.186440881763526\",\"0.186839679358716\",\"0.187238476953906\",\"0.187637274549097\",\"0.188036072144287\",\"0.188434869739478\",\"0.188833667334668\",\"0.189232464929858\",\"0.189631262525049\",\"0.190030060120239\",\"0.190428857715429\",\"0.190827655310620\",\"0.191226452905810\",\"0.191625250501001\",\"0.192024048096191\",\"0.192422845691381\",\"0.192821643286572\",\"0.193220440881762\",\"0.193619238476952\",\"0.194018036072143\",\"0.194416833667333\",\"0.194815631262524\",\"0.195214428857714\",\"0.195613226452904\",\"0.196012024048095\",\"0.196410821643285\",\"0.196809619238475\",\"0.197208416833666\",\"0.197607214428856\",\"0.198006012024047\",\"0.198404809619237\",\"0.198803607214427\",\"0.199202404809618\",\"0.199601202404808\",\"0.200000000000000\"]; setTimeout(function() {\n    $('#slider-step_size-16').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 23,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-step_size-16-lbl').text(values[position]); interact(16, \"sage.server.notebook.interact.update(16, \\\"step_size\\\", 70, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-step_size-16-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-step_size-16-lbl').text(values[$('#slider-step_size-16').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">steps&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-steps-16' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-steps-16-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0\",\"2.8056112224448899\",\"5.6112224448897798\",\"8.4168336673346698\",\"11.22244488977956\",\"14.02805611222445\",\"16.83366733466934\",\"19.639278557114231\",\"22.444889779559119\",\"25.250501002004007\",\"28.056112224448896\",\"30.861723446893784\",\"33.667334669338672\",\"36.47294589178356\",\"39.278557114228448\",\"42.084168336673336\",\"44.889779559118224\",\"47.695390781563113\",\"50.501002004008001\",\"53.306613226452889\",\"56.112224448897777\",\"58.917835671342665\",\"61.723446893787553\",\"64.529058116232449\",\"67.334669338677344\",\"70.140280561122239\",\"72.945891783567134\",\"75.75150300601203\",\"78.557114228456925\",\"81.36272545090182\",\"84.168336673346715\",\"86.973947895791611\",\"89.779559118236506\",\"92.585170340681401\",\"95.390781563126296\",\"98.196392785571192\",\"101.00200400801609\",\"103.80761523046098\",\"106.61322645290588\",\"109.41883767535077\",\"112.22444889779567\",\"115.03006012024056\",\"117.83567134268546\",\"120.64128256513035\",\"123.44689378757525\",\"126.25250501002014\",\"129.05811623246504\",\"131.86372745490993\",\"134.66933867735483\",\"137.47494989979973\",\"140.28056112224462\",\"143.08617234468952\",\"145.89178356713441\",\"148.69739478957931\",\"151.5030060120242\",\"154.3086172344691\",\"157.11422845691399\",\"159.91983967935889\",\"162.72545090180378\",\"165.53106212424868\",\"168.33667334669357\",\"171.14228456913847\",\"173.94789579158336\",\"176.75350701402826\",\"179.55911823647315\",\"182.36472945891805\",\"185.17034068136294\",\"187.97595190380784\",\"190.78156312625273\",\"193.58717434869763\",\"196.39278557114253\",\"199.19839679358742\",\"202.00400801603232\",\"204.80961923847721\",\"207.61523046092211\",\"210.420841683367\",\"213.2264529058119\",\"216.03206412825679\",\"218.83767535070169\",\"221.64328657314658\",\"224.44889779559148\",\"227.25450901803637\",\"230.06012024048127\",\"232.86573146292616\",\"235.67134268537106\",\"238.47695390781595\",\"241.28256513026085\",\"244.08817635270574\",\"246.89378757515064\",\"249.69939879759553\",\"252.50501002004043\",\"255.31062124248533\",\"258.11623246493019\",\"260.92184368737509\",\"263.72745490981998\",\"266.53306613226488\",\"269.33867735470977\",\"272.14428857715467\",\"274.94989979959956\",\"277.75551102204446\",\"280.56112224448935\",\"283.36673346693425\",\"286.17234468937914\",\"288.97795591182404\",\"291.78356713426894\",\"294.58917835671383\",\"297.39478957915873\",\"300.20040080160362\",\"303.00601202404852\",\"305.81162324649341\",\"308.61723446893831\",\"311.4228456913832\",\"314.2284569138281\",\"317.03406813627299\",\"319.83967935871789\",\"322.64529058116278\",\"325.45090180360768\",\"328.25651302605257\",\"331.06212424849747\",\"333.86773547094236\",\"336.67334669338726\",\"339.47895791583215\",\"342.28456913827705\",\"345.09018036072194\",\"347.89579158316684\",\"350.70140280561174\",\"353.50701402805663\",\"356.31262525050153\",\"359.11823647294642\",\"361.92384769539132\",\"364.72945891783621\",\"367.53507014028111\",\"370.340681362726\",\"373.1462925851709\",\"375.95190380761579\",\"378.75751503006069\",\"381.56312625250558\",\"384.36873747495048\",\"387.17434869739537\",\"389.97995991984027\",\"392.78557114228516\",\"395.59118236473006\",\"398.39679358717495\",\"401.20240480961985\",\"404.00801603206475\",\"406.81362725450964\",\"409.61923847695454\",\"412.42484969939943\",\"415.23046092184433\",\"418.03607214428922\",\"420.84168336673412\",\"423.64729458917901\",\"426.45290581162391\",\"429.2585170340688\",\"432.0641282565137\",\"434.86973947895859\",\"437.67535070140349\",\"440.48096192384838\",\"443.28657314629328\",\"446.09218436873817\",\"448.89779559118307\",\"451.70340681362796\",\"454.50901803607286\",\"457.31462925851775\",\"460.12024048096265\",\"462.92585170340755\",\"465.73146292585244\",\"468.53707414829734\",\"471.34268537074223\",\"474.14829659318713\",\"476.95390781563202\",\"479.75951903807692\",\"482.56513026052181\",\"485.37074148296671\",\"488.1763527054116\",\"490.9819639278565\",\"493.78757515030139\",\"496.59318637274629\",\"499.39879759519118\",\"502.20440881763608\",\"505.01002004008097\",\"507.81563126252587\",\"510.62124248497076\",\"513.4268537074156\",\"516.2324649298605\",\"519.03807615230539\",\"521.84368737475029\",\"524.64929859719518\",\"527.45490981964008\",\"530.26052104208497\",\"533.06613226452987\",\"535.87174348697476\",\"538.67735470941966\",\"541.48296593186456\",\"544.28857715430945\",\"547.09418837675435\",\"549.89979959919924\",\"552.70541082164414\",\"555.51102204408903\",\"558.31663326653393\",\"561.12224448897882\",\"563.92785571142372\",\"566.73346693386861\",\"569.53907815631351\",\"572.3446893787584\",\"575.1503006012033\",\"577.95591182364819\",\"580.76152304609309\",\"583.56713426853798\",\"586.37274549098288\",\"589.17835671342777\",\"591.98396793587267\",\"594.78957915831757\",\"597.59519038076246\",\"600.40080160320736\",\"603.20641282565225\",\"606.01202404809715\",\"608.81763527054204\",\"611.62324649298694\",\"614.42885771543183\",\"617.23446893787673\",\"620.04008016032162\",\"622.84569138276652\",\"625.65130260521141\",\"628.45691382765631\",\"631.2625250501012\",\"634.0681362725461\",\"636.87374749499099\",\"639.67935871743589\",\"642.48496993988078\",\"645.29058116232568\",\"648.09619238477057\",\"650.90180360721547\",\"653.70741482966037\",\"656.51302605210526\",\"659.31863727455016\",\"662.12424849699505\",\"664.92985971943995\",\"667.73547094188484\",\"670.54108216432974\",\"673.34669338677463\",\"676.15230460921953\",\"678.95791583166442\",\"681.76352705410932\",\"684.56913827655421\",\"687.37474949899911\",\"690.180360721444\",\"692.9859719438889\",\"695.79158316633379\",\"698.59719438877869\",\"701.40280561122358\",\"704.20841683366848\",\"707.01402805611337\",\"709.81963927855827\",\"712.62525050100317\",\"715.43086172344806\",\"718.23647294589296\",\"721.04208416833785\",\"723.84769539078275\",\"726.65330661322764\",\"729.45891783567254\",\"732.26452905811743\",\"735.07014028056233\",\"737.87575150300722\",\"740.68136272545212\",\"743.48697394789701\",\"746.29258517034191\",\"749.0981963927868\",\"751.9038076152317\",\"754.70941883767659\",\"757.51503006012149\",\"760.32064128256638\",\"763.12625250501128\",\"765.93186372745618\",\"768.73747494990107\",\"771.54308617234597\",\"774.34869739479086\",\"777.15430861723576\",\"779.95991983968065\",\"782.76553106212555\",\"785.57114228457044\",\"788.37675350701534\",\"791.18236472946023\",\"793.98797595190513\",\"796.79358717435002\",\"799.59919839679492\",\"802.40480961923981\",\"805.21042084168471\",\"808.0160320641296\",\"810.8216432865745\",\"813.62725450901939\",\"816.43286573146429\",\"819.23847695390918\",\"822.04408817635408\",\"824.84969939879898\",\"827.65531062124387\",\"830.46092184368877\",\"833.26653306613366\",\"836.07214428857856\",\"838.87775551102345\",\"841.68336673346835\",\"844.48897795591324\",\"847.29458917835814\",\"850.10020040080303\",\"852.90581162324793\",\"855.71142284569282\",\"858.51703406813772\",\"861.32264529058261\",\"864.12825651302751\",\"866.9338677354724\",\"869.7394789579173\",\"872.54509018036219\",\"875.35070140280709\",\"878.15631262525199\",\"880.96192384769688\",\"883.76753507014178\",\"886.57314629258667\",\"889.37875751503157\",\"892.18436873747646\",\"894.98997995992136\",\"897.79559118236625\",\"900.60120240481115\",\"903.40681362725604\",\"906.21242484970094\",\"909.01803607214583\",\"911.82364729459073\",\"914.62925851703562\",\"917.43486973948052\",\"920.24048096192541\",\"923.04609218437031\",\"925.8517034068152\",\"928.6573146292601\",\"931.46292585170499\",\"934.26853707414989\",\"937.07414829659479\",\"939.87975951903968\",\"942.68537074148458\",\"945.49098196392947\",\"948.29659318637437\",\"951.10220440881926\",\"953.90781563126416\",\"956.71342685370905\",\"959.51903807615395\",\"962.32464929859884\",\"965.13026052104374\",\"967.93587174348863\",\"970.74148296593353\",\"973.54709418837842\",\"976.35270541082332\",\"979.15831663326821\",\"981.96392785571311\",\"984.769539078158\",\"987.5751503006029\",\"990.38076152304779\",\"993.18637274549269\",\"995.99198396793759\",\"998.79759519038248\",\"1001.6032064128274\",\"1004.4088176352723\",\"1007.2144288577172\",\"1010.0200400801621\",\"1012.825651302607\",\"1015.6312625250519\",\"1018.4368737474967\",\"1021.2424849699416\",\"1024.0480961923865\",\"1026.8537074148314\",\"1029.6593186372763\",\"1032.4649298597212\",\"1035.2705410821661\",\"1038.076152304611\",\"1040.8817635270559\",\"1043.6873747495008\",\"1046.4929859719457\",\"1049.2985971943906\",\"1052.1042084168355\",\"1054.9098196392804\",\"1057.7154308617253\",\"1060.5210420841702\",\"1063.3266533066151\",\"1066.13226452906\",\"1068.9378757515049\",\"1071.7434869739498\",\"1074.5490981963947\",\"1077.3547094188395\",\"1080.1603206412844\",\"1082.9659318637293\",\"1085.7715430861742\",\"1088.5771543086191\",\"1091.382765531064\",\"1094.1883767535089\",\"1096.9939879759538\",\"1099.7995991983987\",\"1102.6052104208436\",\"1105.4108216432885\",\"1108.2164328657334\",\"1111.0220440881783\",\"1113.8276553106232\",\"1116.6332665330681\",\"1119.438877755513\",\"1122.2444889779579\",\"1125.0501002004028\",\"1127.8557114228477\",\"1130.6613226452926\",\"1133.4669338677375\",\"1136.2725450901823\",\"1139.0781563126272\",\"1141.8837675350721\",\"1144.689378757517\",\"1147.4949899799619\",\"1150.3006012024068\",\"1153.1062124248517\",\"1155.9118236472966\",\"1158.7174348697415\",\"1161.5230460921864\",\"1164.3286573146313\",\"1167.1342685370762\",\"1169.9398797595211\",\"1172.745490981966\",\"1175.5511022044109\",\"1178.3567134268558\",\"1181.1623246493007\",\"1183.9679358717456\",\"1186.7735470941905\",\"1189.5791583166354\",\"1192.3847695390803\",\"1195.1903807615251\",\"1197.99599198397\",\"1200.8016032064149\",\"1203.6072144288598\",\"1206.4128256513047\",\"1209.2184368737496\",\"1212.0240480961945\",\"1214.8296593186394\",\"1217.6352705410843\",\"1220.4408817635292\",\"1223.2464929859741\",\"1226.052104208419\",\"1228.8577154308639\",\"1231.6633266533088\",\"1234.4689378757537\",\"1237.2745490981986\",\"1240.0801603206435\",\"1242.8857715430884\",\"1245.6913827655333\",\"1248.4969939879782\",\"1251.3026052104231\",\"1254.1082164328679\",\"1256.9138276553128\",\"1259.7194388777577\",\"1262.5250501002026\",\"1265.3306613226475\",\"1268.1362725450924\",\"1270.9418837675373\",\"1273.7474949899822\",\"1276.5531062124271\",\"1279.358717434872\",\"1282.1643286573169\",\"1284.9699398797618\",\"1287.7755511022067\",\"1290.5811623246516\",\"1293.3867735470965\",\"1296.1923847695414\",\"1298.9979959919863\",\"1301.8036072144312\",\"1304.6092184368761\",\"1307.414829659321\",\"1310.2204408817659\",\"1313.0260521042107\",\"1315.8316633266556\",\"1318.6372745491005\",\"1321.4428857715454\",\"1324.2484969939903\",\"1327.0541082164352\",\"1329.8597194388801\",\"1332.665330661325\",\"1335.4709418837699\",\"1338.2765531062148\",\"1341.0821643286597\",\"1343.8877755511046\",\"1346.6933867735495\",\"1349.4989979959944\",\"1352.3046092184393\",\"1355.1102204408842\",\"1357.9158316633291\",\"1360.721442885774\",\"1363.5270541082189\",\"1366.3326653306638\",\"1369.1382765531087\",\"1371.9438877755535\",\"1374.7494989979984\",\"1377.5551102204433\",\"1380.3607214428882\",\"1383.1663326653331\",\"1385.971943887778\",\"1388.7775551102229\",\"1391.5831663326678\",\"1394.3887775551127\",\"1397.1943887775576\",\"1400.0\"]; setTimeout(function() {\n    $('#slider-steps-16').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 214,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-steps-16-lbl').text(values[position]); interact(16, \"sage.server.notebook.interact.update(16, \\\"steps\\\", 71, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(16)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-steps-16-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-steps-16-lbl').text(values[$('#slider-steps-16').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-16'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠9a6ac927-96cb-40e7-bef5-990189c02fdd︠
# Solve ODEs using sophisticated Methods like Runga-Kutta-Fehlberg
# by Harald Schilly, April 2008
# (jacobian doesn't work, please fix ...)
var('x y')
@interact
def _(fin = input_box(default=y+exp(x/10)-1/3*((x-1/2)^2+y^3)*x-x*y^3), gin=input_box(default=x^3-x+1/100*exp(y*x^2+x*y^2)-0.7*x), 
      xmin=input_box(default=-1), xmax=input_box(default=1.8), 
      ymin=input_box(default=-1.3), ymax=input_box(default=1.5), 
      x_start=(-1,(-2,2)), y_start=(0,(-2,2)), error=(0.5,(0,1)), 
      t_length=(23,(0, 100)) , num_of_points = (1500,(5,2000)),
      algorithm = selector([
         ("rkf45" , "runga-kutta-felhberg (4,5)"),
         ("rk2" , "embedded runga-kutta (2,3)"),
         ("rk4" , "4th order classical runga-kutta"),
         ("rk8pd" , 'runga-kutta prince-dormand (8,9)'),
         ("rk2imp" , "implicit 2nd order runga-kutta at gaussian points"),
         ("rk4imp" , "implicit 4th order runga-kutta at gaussian points"),
         ("bsimp" , "implicit burlisch-stoer (requires jacobian)"),
         ("gear1" , "M=1 implicit gear"),
         ("gear2" , "M=2 implicit gear")
      ])):
    f(x,y)=fin
    g(x,y)=gin    
    
    ff = f._fast_float_(*f.args())
    gg = g._fast_float_(*g.args())
    
    #solve
    path = []      
    err = error
    xerr = 0
    for yerr in [-err, 0, +err]:
      T=ode_solver()
      T.algorithm=algorithm
      T.function = lambda t, yp: [ff(yp[0],yp[1]), gg(yp[0],yp[1])]  
      T.jacobian = lambda t, yp: [[diff(fun,dval)(yp[0],yp[1]) for dval in [x,y]] for fun in [f,g]]
      T.ode_solve(y_0=[x_start + xerr, y_start + yerr],t_span=[0,t_length],num_points=num_of_points)
      path.append(line([p[1] for p in T.solution]))

    #plot
    vector_field = plot_vector_field( (f,g), (x,xmin,xmax), (y,ymin,ymax) )
    starting_point = point([x_start, y_start], pointsize=50)
    show(vector_field + starting_point + sum(path), aspect_ratio=1, figsize=[8,9])
︡8c52eb9a-2efb-4145-942a-bdefe998ea6b︡{"html": "<!--notruncate--><div padding=6 id='div-interact-17'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">fin&nbsp;</font></td><td><input type='text' value=\"\n                          3        1 2\n                      x (y  + (x - -) )\n                                   2         3         x/10\n                    - ----------------- - x y  + y +  e\n                              3\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"fin\\\", 72, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">gin&nbsp;</font></td><td><input type='text' value=\"\n                               2    2\n                            x y  + x  y\n                           e               3\n                          ------------- + x  - 1.7 x\n                               100\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"gin\\\", 73, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmin&nbsp;</font></td><td><input type='text' value=\"-1\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"xmin\\\", 74, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">xmax&nbsp;</font></td><td><input type='text' value=\"1.80000000000000\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"xmax\\\", 75, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">ymin&nbsp;</font></td><td><input type='text' value=\"-1.30000000000000\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"ymin\\\", 76, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">ymax&nbsp;</font></td><td><input type='text' value=\"1.50000000000000\" size=80 onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"ymax\\\", 77, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">x_start&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-x_start-17' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-x_start-17-lbl'></font></td></tr></table><script>(function(){ var values = [\"-2.0\",\"-1.9919839679358717\",\"-1.9839679358717435\",\"-1.9759519038076152\",\"-1.9679358717434869\",\"-1.9599198396793587\",\"-1.9519038076152304\",\"-1.9438877755511021\",\"-1.9358717434869739\",\"-1.9278557114228456\",\"-1.9198396793587174\",\"-1.9118236472945891\",\"-1.9038076152304608\",\"-1.8957915831663326\",\"-1.8877755511022043\",\"-1.879759519038076\",\"-1.8717434869739478\",\"-1.8637274549098195\",\"-1.8557114228456912\",\"-1.847695390781563\",\"-1.8396793587174347\",\"-1.8316633266533064\",\"-1.8236472945891782\",\"-1.8156312625250499\",\"-1.8076152304609217\",\"-1.7995991983967934\",\"-1.7915831663326651\",\"-1.7835671342685369\",\"-1.7755511022044086\",\"-1.7675350701402803\",\"-1.7595190380761521\",\"-1.7515030060120238\",\"-1.7434869739478955\",\"-1.7354709418837673\",\"-1.727454909819639\",\"-1.7194388777555107\",\"-1.7114228456913825\",\"-1.7034068136272542\",\"-1.6953907815631259\",\"-1.6873747494989977\",\"-1.6793587174348694\",\"-1.6713426853707412\",\"-1.6633266533066129\",\"-1.6553106212424846\",\"-1.6472945891783564\",\"-1.6392785571142281\",\"-1.6312625250500998\",\"-1.6232464929859716\",\"-1.6152304609218433\",\"-1.607214428857715\",\"-1.5991983967935868\",\"-1.5911823647294585\",\"-1.5831663326653302\",\"-1.575150300601202\",\"-1.5671342685370737\",\"-1.5591182364729455\",\"-1.5511022044088172\",\"-1.5430861723446889\",\"-1.5350701402805607\",\"-1.5270541082164324\",\"-1.5190380761523041\",\"-1.5110220440881759\",\"-1.5030060120240476\",\"-1.4949899799599193\",\"-1.4869739478957911\",\"-1.4789579158316628\",\"-1.4709418837675345\",\"-1.4629258517034063\",\"-1.454909819639278\",\"-1.4468937875751497\",\"-1.4388777555110215\",\"-1.4308617234468932\",\"-1.422845691382765\",\"-1.4148296593186367\",\"-1.4068136272545084\",\"-1.3987975951903802\",\"-1.3907815631262519\",\"-1.3827655310621236\",\"-1.3747494989979954\",\"-1.3667334669338671\",\"-1.3587174348697388\",\"-1.3507014028056106\",\"-1.3426853707414823\",\"-1.334669338677354\",\"-1.3266533066132258\",\"-1.3186372745490975\",\"-1.3106212424849693\",\"-1.302605210420841\",\"-1.2945891783567127\",\"-1.2865731462925845\",\"-1.2785571142284562\",\"-1.2705410821643279\",\"-1.2625250501001997\",\"-1.2545090180360714\",\"-1.2464929859719431\",\"-1.2384769539078149\",\"-1.2304609218436866\",\"-1.2224448897795583\",\"-1.2144288577154301\",\"-1.2064128256513018\",\"-1.1983967935871735\",\"-1.1903807615230453\",\"-1.182364729458917\",\"-1.1743486973947888\",\"-1.1663326653306605\",\"-1.1583166332665322\",\"-1.150300601202404\",\"-1.1422845691382757\",\"-1.1342685370741474\",\"-1.1262525050100192\",\"-1.1182364729458909\",\"-1.1102204408817626\",\"-1.1022044088176344\",\"-1.0941883767535061\",\"-1.0861723446893778\",\"-1.0781563126252496\",\"-1.0701402805611213\",\"-1.0621242484969931\",\"-1.0541082164328648\",\"-1.0460921843687365\",\"-1.0380761523046083\",\"-1.03006012024048\",\"-1.0220440881763517\",\"-1.0140280561122235\",\"-1.0060120240480952\",\"-0.99799599198396693\",\"-0.98997995991983867\",\"-0.98196392785571041\",\"-0.97394789579158214\",\"-0.96593186372745388\",\"-0.95791583166332561\",\"-0.94989979959919735\",\"-0.94188376753506908\",\"-0.93386773547094082\",\"-0.92585170340681255\",\"-0.91783567134268429\",\"-0.90981963927855602\",\"-0.90180360721442776\",\"-0.8937875751502995\",\"-0.88577154308617123\",\"-0.87775551102204297\",\"-0.8697394789579147\",\"-0.86172344689378644\",\"-0.85370741482965817\",\"-0.84569138276552991\",\"-0.83767535070140164\",\"-0.82965931863727338\",\"-0.82164328657314512\",\"-0.81362725450901685\",\"-0.80561122244488859\",\"-0.79759519038076032\",\"-0.78957915831663206\",\"-0.78156312625250379\",\"-0.77354709418837553\",\"-0.76553106212424726\",\"-0.757515030060119\",\"-0.74949899799599073\",\"-0.74148296593186247\",\"-0.73346693386773421\",\"-0.72545090180360594\",\"-0.71743486973947768\",\"-0.70941883767534941\",\"-0.70140280561122115\",\"-0.69338677354709288\",\"-0.68537074148296462\",\"-0.67735470941883635\",\"-0.66933867735470809\",\"-0.66132264529057982\",\"-0.65330661322645156\",\"-0.6452905811623233\",\"-0.63727454909819503\",\"-0.62925851703406677\",\"-0.6212424849699385\",\"-0.61322645290581024\",\"-0.60521042084168197\",\"-0.59719438877755371\",\"-0.58917835671342544\",\"-0.58116232464929718\",\"-0.57314629258516891\",\"-0.56513026052104065\",\"-0.55711422845691239\",\"-0.54909819639278412\",\"-0.54108216432865586\",\"-0.53306613226452759\",\"-0.52505010020039933\",\"-0.51703406813627106\",\"-0.5090180360721428\",\"-0.50100200400801453\",\"-0.49298597194388627\",\"-0.48496993987975801\",\"-0.47695390781562974\",\"-0.46893787575150148\",\"-0.46092184368737321\",\"-0.45290581162324495\",\"-0.44488977955911668\",\"-0.43687374749498842\",\"-0.42885771543086015\",\"-0.42084168336673189\",\"-0.41282565130260362\",\"-0.40480961923847536\",\"-0.3967935871743471\",\"-0.38877755511021883\",\"-0.38076152304609057\",\"-0.3727454909819623\",\"-0.36472945891783404\",\"-0.35671342685370577\",\"-0.34869739478957751\",\"-0.34068136272544924\",\"-0.33266533066132098\",\"-0.32464929859719271\",\"-0.31663326653306445\",\"-0.30861723446893619\",\"-0.30060120240480792\",\"-0.29258517034067966\",\"-0.28456913827655139\",\"-0.27655310621242313\",\"-0.26853707414829486\",\"-0.2605210420841666\",\"-0.25250501002003833\",\"-0.24448897795591007\",\"-0.23647294589178181\",\"-0.22845691382765354\",\"-0.22044088176352528\",\"-0.21242484969939701\",\"-0.20440881763526875\",\"-0.19639278557114048\",\"-0.18837675350701222\",\"-0.18036072144288395\",\"-0.17234468937875569\",\"-0.16432865731462742\",\"-0.15631262525049916\",\"-0.1482965931863709\",\"-0.14028056112224263\",\"-0.13226452905811437\",\"-0.12424849699398612\",\"-0.11623246492985786\",\"-0.10821643286572961\",\"-0.10020040080160136\",\"-0.092184368737473113\",\"-0.084168336673344862\",\"-0.076152304609216612\",\"-0.068136272545088361\",\"-0.060120240480960103\",\"-0.052104208416831846\",\"-0.044088176352703588\",\"-0.036072144288575331\",\"-0.028056112224447073\",\"-0.020040080160318816\",\"-0.01202404809619056\",\"-0.0040080160320623039\",\"0.004008016032065952\",\"0.012024048096194208\",\"0.020040080160322465\",\"0.028056112224450723\",\"0.036072144288578981\",\"0.044088176352707238\",\"0.052104208416835496\",\"0.060120240480963753\",\"0.068136272545092011\",\"0.076152304609220262\",\"0.084168336673348512\",\"0.092184368737476763\",\"0.10020040080160501\",\"0.10821643286573326\",\"0.11623246492986151\",\"0.12424849699398977\",\"0.13226452905811803\",\"0.14028056112224629\",\"0.14829659318637456\",\"0.15631262525050282\",\"0.16432865731463109\",\"0.17234468937875935\",\"0.18036072144288762\",\"0.18837675350701588\",\"0.19639278557114415\",\"0.20440881763527241\",\"0.21242484969940068\",\"0.22044088176352894\",\"0.2284569138276572\",\"0.23647294589178547\",\"0.24448897795591373\",\"0.252505010020042\",\"0.26052104208417026\",\"0.26853707414829853\",\"0.27655310621242679\",\"0.28456913827655506\",\"0.29258517034068332\",\"0.30060120240481158\",\"0.30861723446893985\",\"0.31663326653306811\",\"0.32464929859719638\",\"0.33266533066132464\",\"0.34068136272545291\",\"0.34869739478958117\",\"0.35671342685370944\",\"0.3647294589178377\",\"0.37274549098196597\",\"0.38076152304609423\",\"0.38877755511022249\",\"0.39679358717435076\",\"0.40480961923847902\",\"0.41282565130260729\",\"0.42084168336673555\",\"0.42885771543086382\",\"0.43687374749499208\",\"0.44488977955912035\",\"0.45290581162324861\",\"0.46092184368737688\",\"0.46893787575150514\",\"0.4769539078156334\",\"0.48496993987976167\",\"0.49298597194388993\",\"0.5010020040080182\",\"0.50901803607214646\",\"0.51703406813627473\",\"0.52505010020040299\",\"0.53306613226453126\",\"0.54108216432865952\",\"0.54909819639278779\",\"0.55711422845691605\",\"0.56513026052104431\",\"0.57314629258517258\",\"0.58116232464930084\",\"0.58917835671342911\",\"0.59719438877755737\",\"0.60521042084168564\",\"0.6132264529058139\",\"0.62124248496994217\",\"0.62925851703407043\",\"0.63727454909819869\",\"0.64529058116232696\",\"0.65330661322645522\",\"0.66132264529058349\",\"0.66933867735471175\",\"0.67735470941884002\",\"0.68537074148296828\",\"0.69338677354709655\",\"0.70140280561122481\",\"0.70941883767535308\",\"0.71743486973948134\",\"0.7254509018036096\",\"0.73346693386773787\",\"0.74148296593186613\",\"0.7494989979959944\",\"0.75751503006012266\",\"0.76553106212425093\",\"0.77354709418837919\",\"0.78156312625250746\",\"0.78957915831663572\",\"0.79759519038076399\",\"0.80561122244489225\",\"0.81362725450902051\",\"0.82164328657314878\",\"0.82965931863727704\",\"0.83767535070140531\",\"0.84569138276553357\",\"0.85370741482966184\",\"0.8617234468937901\",\"0.86973947895791837\",\"0.87775551102204663\",\"0.8857715430861749\",\"0.89378757515030316\",\"0.90180360721443142\",\"0.90981963927855969\",\"0.91783567134268795\",\"0.92585170340681622\",\"0.93386773547094448\",\"0.94188376753507275\",\"0.94989979959920101\",\"0.95791583166332928\",\"0.96593186372745754\",\"0.9739478957915858\",\"0.98196392785571407\",\"0.98997995991984233\",\"0.9979959919839706\",\"1.0060120240480988\",\"1.014028056112227\",\"1.0220440881763553\",\"1.0300601202404835\",\"1.0380761523046118\",\"1.0460921843687401\",\"1.0541082164328683\",\"1.0621242484969966\",\"1.0701402805611249\",\"1.0781563126252531\",\"1.0861723446893814\",\"1.0941883767535097\",\"1.1022044088176379\",\"1.1102204408817662\",\"1.1182364729458945\",\"1.1262525050100227\",\"1.134268537074151\",\"1.1422845691382792\",\"1.1503006012024075\",\"1.1583166332665358\",\"1.166332665330664\",\"1.1743486973947923\",\"1.1823647294589206\",\"1.1903807615230488\",\"1.1983967935871771\",\"1.2064128256513054\",\"1.2144288577154336\",\"1.2224448897795619\",\"1.2304609218436902\",\"1.2384769539078184\",\"1.2464929859719467\",\"1.254509018036075\",\"1.2625250501002032\",\"1.2705410821643315\",\"1.2785571142284597\",\"1.286573146292588\",\"1.2945891783567163\",\"1.3026052104208445\",\"1.3106212424849728\",\"1.3186372745491011\",\"1.3266533066132293\",\"1.3346693386773576\",\"1.3426853707414859\",\"1.3507014028056141\",\"1.3587174348697424\",\"1.3667334669338707\",\"1.3747494989979989\",\"1.3827655310621272\",\"1.3907815631262554\",\"1.3987975951903837\",\"1.406813627254512\",\"1.4148296593186402\",\"1.4228456913827685\",\"1.4308617234468968\",\"1.438877755511025\",\"1.4468937875751533\",\"1.4549098196392816\",\"1.4629258517034098\",\"1.4709418837675381\",\"1.4789579158316664\",\"1.4869739478957946\",\"1.4949899799599229\",\"1.5030060120240512\",\"1.5110220440881794\",\"1.5190380761523077\",\"1.5270541082164359\",\"1.5350701402805642\",\"1.5430861723446925\",\"1.5511022044088207\",\"1.559118236472949\",\"1.5671342685370773\",\"1.5751503006012055\",\"1.5831663326653338\",\"1.5911823647294621\",\"1.5991983967935903\",\"1.6072144288577186\",\"1.6152304609218469\",\"1.6232464929859751\",\"1.6312625250501034\",\"1.6392785571142316\",\"1.6472945891783599\",\"1.6553106212424882\",\"1.6633266533066164\",\"1.6713426853707447\",\"1.679358717434873\",\"1.6873747494990012\",\"1.6953907815631295\",\"1.7034068136272578\",\"1.711422845691386\",\"1.7194388777555143\",\"1.7274549098196426\",\"1.7354709418837708\",\"1.7434869739478991\",\"1.7515030060120274\",\"1.7595190380761556\",\"1.7675350701402839\",\"1.7755511022044121\",\"1.7835671342685404\",\"1.7915831663326687\",\"1.7995991983967969\",\"1.8076152304609252\",\"1.8156312625250535\",\"1.8236472945891817\",\"1.83166332665331\",\"1.8396793587174383\",\"1.8476953907815665\",\"1.8557114228456948\",\"1.8637274549098231\",\"1.8717434869739513\",\"1.8797595190380796\",\"1.8877755511022078\",\"1.8957915831663361\",\"1.9038076152304644\",\"1.9118236472945926\",\"1.9198396793587209\",\"1.9278557114228492\",\"1.9358717434869774\",\"1.9438877755511057\",\"1.951903807615234\",\"1.9599198396793622\",\"1.9679358717434905\",\"1.9759519038076188\",\"1.983967935871747\",\"1.9919839679358753\",\"2.0\"]; setTimeout(function() {\n    $('#slider-x_start-17').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 125,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-x_start-17-lbl').text(values[position]); interact(17, \"sage.server.notebook.interact.update(17, \\\"x_start\\\", 78, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-x_start-17-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-x_start-17-lbl').text(values[$('#slider-x_start-17').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">y_start&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-y_start-17' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-y_start-17-lbl'></font></td></tr></table><script>(function(){ var values = [\"-2.0\",\"-1.9919839679358717\",\"-1.9839679358717435\",\"-1.9759519038076152\",\"-1.9679358717434869\",\"-1.9599198396793587\",\"-1.9519038076152304\",\"-1.9438877755511021\",\"-1.9358717434869739\",\"-1.9278557114228456\",\"-1.9198396793587174\",\"-1.9118236472945891\",\"-1.9038076152304608\",\"-1.8957915831663326\",\"-1.8877755511022043\",\"-1.879759519038076\",\"-1.8717434869739478\",\"-1.8637274549098195\",\"-1.8557114228456912\",\"-1.847695390781563\",\"-1.8396793587174347\",\"-1.8316633266533064\",\"-1.8236472945891782\",\"-1.8156312625250499\",\"-1.8076152304609217\",\"-1.7995991983967934\",\"-1.7915831663326651\",\"-1.7835671342685369\",\"-1.7755511022044086\",\"-1.7675350701402803\",\"-1.7595190380761521\",\"-1.7515030060120238\",\"-1.7434869739478955\",\"-1.7354709418837673\",\"-1.727454909819639\",\"-1.7194388777555107\",\"-1.7114228456913825\",\"-1.7034068136272542\",\"-1.6953907815631259\",\"-1.6873747494989977\",\"-1.6793587174348694\",\"-1.6713426853707412\",\"-1.6633266533066129\",\"-1.6553106212424846\",\"-1.6472945891783564\",\"-1.6392785571142281\",\"-1.6312625250500998\",\"-1.6232464929859716\",\"-1.6152304609218433\",\"-1.607214428857715\",\"-1.5991983967935868\",\"-1.5911823647294585\",\"-1.5831663326653302\",\"-1.575150300601202\",\"-1.5671342685370737\",\"-1.5591182364729455\",\"-1.5511022044088172\",\"-1.5430861723446889\",\"-1.5350701402805607\",\"-1.5270541082164324\",\"-1.5190380761523041\",\"-1.5110220440881759\",\"-1.5030060120240476\",\"-1.4949899799599193\",\"-1.4869739478957911\",\"-1.4789579158316628\",\"-1.4709418837675345\",\"-1.4629258517034063\",\"-1.454909819639278\",\"-1.4468937875751497\",\"-1.4388777555110215\",\"-1.4308617234468932\",\"-1.422845691382765\",\"-1.4148296593186367\",\"-1.4068136272545084\",\"-1.3987975951903802\",\"-1.3907815631262519\",\"-1.3827655310621236\",\"-1.3747494989979954\",\"-1.3667334669338671\",\"-1.3587174348697388\",\"-1.3507014028056106\",\"-1.3426853707414823\",\"-1.334669338677354\",\"-1.3266533066132258\",\"-1.3186372745490975\",\"-1.3106212424849693\",\"-1.302605210420841\",\"-1.2945891783567127\",\"-1.2865731462925845\",\"-1.2785571142284562\",\"-1.2705410821643279\",\"-1.2625250501001997\",\"-1.2545090180360714\",\"-1.2464929859719431\",\"-1.2384769539078149\",\"-1.2304609218436866\",\"-1.2224448897795583\",\"-1.2144288577154301\",\"-1.2064128256513018\",\"-1.1983967935871735\",\"-1.1903807615230453\",\"-1.182364729458917\",\"-1.1743486973947888\",\"-1.1663326653306605\",\"-1.1583166332665322\",\"-1.150300601202404\",\"-1.1422845691382757\",\"-1.1342685370741474\",\"-1.1262525050100192\",\"-1.1182364729458909\",\"-1.1102204408817626\",\"-1.1022044088176344\",\"-1.0941883767535061\",\"-1.0861723446893778\",\"-1.0781563126252496\",\"-1.0701402805611213\",\"-1.0621242484969931\",\"-1.0541082164328648\",\"-1.0460921843687365\",\"-1.0380761523046083\",\"-1.03006012024048\",\"-1.0220440881763517\",\"-1.0140280561122235\",\"-1.0060120240480952\",\"-0.99799599198396693\",\"-0.98997995991983867\",\"-0.98196392785571041\",\"-0.97394789579158214\",\"-0.96593186372745388\",\"-0.95791583166332561\",\"-0.94989979959919735\",\"-0.94188376753506908\",\"-0.93386773547094082\",\"-0.92585170340681255\",\"-0.91783567134268429\",\"-0.90981963927855602\",\"-0.90180360721442776\",\"-0.8937875751502995\",\"-0.88577154308617123\",\"-0.87775551102204297\",\"-0.8697394789579147\",\"-0.86172344689378644\",\"-0.85370741482965817\",\"-0.84569138276552991\",\"-0.83767535070140164\",\"-0.82965931863727338\",\"-0.82164328657314512\",\"-0.81362725450901685\",\"-0.80561122244488859\",\"-0.79759519038076032\",\"-0.78957915831663206\",\"-0.78156312625250379\",\"-0.77354709418837553\",\"-0.76553106212424726\",\"-0.757515030060119\",\"-0.74949899799599073\",\"-0.74148296593186247\",\"-0.73346693386773421\",\"-0.72545090180360594\",\"-0.71743486973947768\",\"-0.70941883767534941\",\"-0.70140280561122115\",\"-0.69338677354709288\",\"-0.68537074148296462\",\"-0.67735470941883635\",\"-0.66933867735470809\",\"-0.66132264529057982\",\"-0.65330661322645156\",\"-0.6452905811623233\",\"-0.63727454909819503\",\"-0.62925851703406677\",\"-0.6212424849699385\",\"-0.61322645290581024\",\"-0.60521042084168197\",\"-0.59719438877755371\",\"-0.58917835671342544\",\"-0.58116232464929718\",\"-0.57314629258516891\",\"-0.56513026052104065\",\"-0.55711422845691239\",\"-0.54909819639278412\",\"-0.54108216432865586\",\"-0.53306613226452759\",\"-0.52505010020039933\",\"-0.51703406813627106\",\"-0.5090180360721428\",\"-0.50100200400801453\",\"-0.49298597194388627\",\"-0.48496993987975801\",\"-0.47695390781562974\",\"-0.46893787575150148\",\"-0.46092184368737321\",\"-0.45290581162324495\",\"-0.44488977955911668\",\"-0.43687374749498842\",\"-0.42885771543086015\",\"-0.42084168336673189\",\"-0.41282565130260362\",\"-0.40480961923847536\",\"-0.3967935871743471\",\"-0.38877755511021883\",\"-0.38076152304609057\",\"-0.3727454909819623\",\"-0.36472945891783404\",\"-0.35671342685370577\",\"-0.34869739478957751\",\"-0.34068136272544924\",\"-0.33266533066132098\",\"-0.32464929859719271\",\"-0.31663326653306445\",\"-0.30861723446893619\",\"-0.30060120240480792\",\"-0.29258517034067966\",\"-0.28456913827655139\",\"-0.27655310621242313\",\"-0.26853707414829486\",\"-0.2605210420841666\",\"-0.25250501002003833\",\"-0.24448897795591007\",\"-0.23647294589178181\",\"-0.22845691382765354\",\"-0.22044088176352528\",\"-0.21242484969939701\",\"-0.20440881763526875\",\"-0.19639278557114048\",\"-0.18837675350701222\",\"-0.18036072144288395\",\"-0.17234468937875569\",\"-0.16432865731462742\",\"-0.15631262525049916\",\"-0.1482965931863709\",\"-0.14028056112224263\",\"-0.13226452905811437\",\"-0.12424849699398612\",\"-0.11623246492985786\",\"-0.10821643286572961\",\"-0.10020040080160136\",\"-0.092184368737473113\",\"-0.084168336673344862\",\"-0.076152304609216612\",\"-0.068136272545088361\",\"-0.060120240480960103\",\"-0.052104208416831846\",\"-0.044088176352703588\",\"-0.036072144288575331\",\"-0.028056112224447073\",\"-0.020040080160318816\",\"-0.01202404809619056\",\"-0.0040080160320623039\",\"0.004008016032065952\",\"0.012024048096194208\",\"0.020040080160322465\",\"0.028056112224450723\",\"0.036072144288578981\",\"0.044088176352707238\",\"0.052104208416835496\",\"0.060120240480963753\",\"0.068136272545092011\",\"0.076152304609220262\",\"0.084168336673348512\",\"0.092184368737476763\",\"0.10020040080160501\",\"0.10821643286573326\",\"0.11623246492986151\",\"0.12424849699398977\",\"0.13226452905811803\",\"0.14028056112224629\",\"0.14829659318637456\",\"0.15631262525050282\",\"0.16432865731463109\",\"0.17234468937875935\",\"0.18036072144288762\",\"0.18837675350701588\",\"0.19639278557114415\",\"0.20440881763527241\",\"0.21242484969940068\",\"0.22044088176352894\",\"0.2284569138276572\",\"0.23647294589178547\",\"0.24448897795591373\",\"0.252505010020042\",\"0.26052104208417026\",\"0.26853707414829853\",\"0.27655310621242679\",\"0.28456913827655506\",\"0.29258517034068332\",\"0.30060120240481158\",\"0.30861723446893985\",\"0.31663326653306811\",\"0.32464929859719638\",\"0.33266533066132464\",\"0.34068136272545291\",\"0.34869739478958117\",\"0.35671342685370944\",\"0.3647294589178377\",\"0.37274549098196597\",\"0.38076152304609423\",\"0.38877755511022249\",\"0.39679358717435076\",\"0.40480961923847902\",\"0.41282565130260729\",\"0.42084168336673555\",\"0.42885771543086382\",\"0.43687374749499208\",\"0.44488977955912035\",\"0.45290581162324861\",\"0.46092184368737688\",\"0.46893787575150514\",\"0.4769539078156334\",\"0.48496993987976167\",\"0.49298597194388993\",\"0.5010020040080182\",\"0.50901803607214646\",\"0.51703406813627473\",\"0.52505010020040299\",\"0.53306613226453126\",\"0.54108216432865952\",\"0.54909819639278779\",\"0.55711422845691605\",\"0.56513026052104431\",\"0.57314629258517258\",\"0.58116232464930084\",\"0.58917835671342911\",\"0.59719438877755737\",\"0.60521042084168564\",\"0.6132264529058139\",\"0.62124248496994217\",\"0.62925851703407043\",\"0.63727454909819869\",\"0.64529058116232696\",\"0.65330661322645522\",\"0.66132264529058349\",\"0.66933867735471175\",\"0.67735470941884002\",\"0.68537074148296828\",\"0.69338677354709655\",\"0.70140280561122481\",\"0.70941883767535308\",\"0.71743486973948134\",\"0.7254509018036096\",\"0.73346693386773787\",\"0.74148296593186613\",\"0.7494989979959944\",\"0.75751503006012266\",\"0.76553106212425093\",\"0.77354709418837919\",\"0.78156312625250746\",\"0.78957915831663572\",\"0.79759519038076399\",\"0.80561122244489225\",\"0.81362725450902051\",\"0.82164328657314878\",\"0.82965931863727704\",\"0.83767535070140531\",\"0.84569138276553357\",\"0.85370741482966184\",\"0.8617234468937901\",\"0.86973947895791837\",\"0.87775551102204663\",\"0.8857715430861749\",\"0.89378757515030316\",\"0.90180360721443142\",\"0.90981963927855969\",\"0.91783567134268795\",\"0.92585170340681622\",\"0.93386773547094448\",\"0.94188376753507275\",\"0.94989979959920101\",\"0.95791583166332928\",\"0.96593186372745754\",\"0.9739478957915858\",\"0.98196392785571407\",\"0.98997995991984233\",\"0.9979959919839706\",\"1.0060120240480988\",\"1.014028056112227\",\"1.0220440881763553\",\"1.0300601202404835\",\"1.0380761523046118\",\"1.0460921843687401\",\"1.0541082164328683\",\"1.0621242484969966\",\"1.0701402805611249\",\"1.0781563126252531\",\"1.0861723446893814\",\"1.0941883767535097\",\"1.1022044088176379\",\"1.1102204408817662\",\"1.1182364729458945\",\"1.1262525050100227\",\"1.134268537074151\",\"1.1422845691382792\",\"1.1503006012024075\",\"1.1583166332665358\",\"1.166332665330664\",\"1.1743486973947923\",\"1.1823647294589206\",\"1.1903807615230488\",\"1.1983967935871771\",\"1.2064128256513054\",\"1.2144288577154336\",\"1.2224448897795619\",\"1.2304609218436902\",\"1.2384769539078184\",\"1.2464929859719467\",\"1.254509018036075\",\"1.2625250501002032\",\"1.2705410821643315\",\"1.2785571142284597\",\"1.286573146292588\",\"1.2945891783567163\",\"1.3026052104208445\",\"1.3106212424849728\",\"1.3186372745491011\",\"1.3266533066132293\",\"1.3346693386773576\",\"1.3426853707414859\",\"1.3507014028056141\",\"1.3587174348697424\",\"1.3667334669338707\",\"1.3747494989979989\",\"1.3827655310621272\",\"1.3907815631262554\",\"1.3987975951903837\",\"1.406813627254512\",\"1.4148296593186402\",\"1.4228456913827685\",\"1.4308617234468968\",\"1.438877755511025\",\"1.4468937875751533\",\"1.4549098196392816\",\"1.4629258517034098\",\"1.4709418837675381\",\"1.4789579158316664\",\"1.4869739478957946\",\"1.4949899799599229\",\"1.5030060120240512\",\"1.5110220440881794\",\"1.5190380761523077\",\"1.5270541082164359\",\"1.5350701402805642\",\"1.5430861723446925\",\"1.5511022044088207\",\"1.559118236472949\",\"1.5671342685370773\",\"1.5751503006012055\",\"1.5831663326653338\",\"1.5911823647294621\",\"1.5991983967935903\",\"1.6072144288577186\",\"1.6152304609218469\",\"1.6232464929859751\",\"1.6312625250501034\",\"1.6392785571142316\",\"1.6472945891783599\",\"1.6553106212424882\",\"1.6633266533066164\",\"1.6713426853707447\",\"1.679358717434873\",\"1.6873747494990012\",\"1.6953907815631295\",\"1.7034068136272578\",\"1.711422845691386\",\"1.7194388777555143\",\"1.7274549098196426\",\"1.7354709418837708\",\"1.7434869739478991\",\"1.7515030060120274\",\"1.7595190380761556\",\"1.7675350701402839\",\"1.7755511022044121\",\"1.7835671342685404\",\"1.7915831663326687\",\"1.7995991983967969\",\"1.8076152304609252\",\"1.8156312625250535\",\"1.8236472945891817\",\"1.83166332665331\",\"1.8396793587174383\",\"1.8476953907815665\",\"1.8557114228456948\",\"1.8637274549098231\",\"1.8717434869739513\",\"1.8797595190380796\",\"1.8877755511022078\",\"1.8957915831663361\",\"1.9038076152304644\",\"1.9118236472945926\",\"1.9198396793587209\",\"1.9278557114228492\",\"1.9358717434869774\",\"1.9438877755511057\",\"1.951903807615234\",\"1.9599198396793622\",\"1.9679358717434905\",\"1.9759519038076188\",\"1.983967935871747\",\"1.9919839679358753\",\"2.0\"]; setTimeout(function() {\n    $('#slider-y_start-17').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 249,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-y_start-17-lbl').text(values[position]); interact(17, \"sage.server.notebook.interact.update(17, \\\"y_start\\\", 79, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-y_start-17-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-y_start-17-lbl').text(values[$('#slider-y_start-17').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">error&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-error-17' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-error-17-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0\",\"0.002004008016032064\",\"0.0040080160320641279\",\"0.0060120240480961915\",\"0.0080160320641282558\",\"0.01002004008016032\",\"0.012024048096192385\",\"0.014028056112224449\",\"0.016032064128256512\",\"0.018036072144288574\",\"0.020040080160320637\",\"0.0220440881763527\",\"0.024048096192384762\",\"0.026052104208416825\",\"0.028056112224448888\",\"0.03006012024048095\",\"0.032064128256513016\",\"0.034068136272545083\",\"0.036072144288577149\",\"0.038076152304609215\",\"0.040080160320641281\",\"0.042084168336673347\",\"0.044088176352705413\",\"0.046092184368737479\",\"0.048096192384769546\",\"0.050100200400801612\",\"0.052104208416833678\",\"0.054108216432865744\",\"0.05611222444889781\",\"0.058116232464929876\",\"0.060120240480961942\",\"0.062124248496994008\",\"0.064128256513026075\",\"0.066132264529058141\",\"0.068136272545090207\",\"0.070140280561122273\",\"0.072144288577154339\",\"0.074148296593186405\",\"0.076152304609218471\",\"0.078156312625250537\",\"0.080160320641282604\",\"0.08216432865731467\",\"0.084168336673346736\",\"0.086172344689378802\",\"0.088176352705410868\",\"0.090180360721442934\",\"0.092184368737475\",\"0.094188376753507067\",\"0.096192384769539133\",\"0.098196392785571199\",\"0.10020040080160326\",\"0.10220440881763533\",\"0.1042084168336674\",\"0.10621242484969946\",\"0.10821643286573153\",\"0.1102204408817636\",\"0.11222444889779566\",\"0.11422845691382773\",\"0.11623246492985979\",\"0.11823647294589186\",\"0.12024048096192393\",\"0.12224448897795599\",\"0.12424849699398806\",\"0.12625250501002011\",\"0.12825651302605218\",\"0.13026052104208424\",\"0.13226452905811631\",\"0.13426853707414838\",\"0.13627254509018044\",\"0.13827655310621251\",\"0.14028056112224457\",\"0.14228456913827664\",\"0.14428857715430871\",\"0.14629258517034077\",\"0.14829659318637284\",\"0.1503006012024049\",\"0.15230460921843697\",\"0.15430861723446904\",\"0.1563126252505011\",\"0.15831663326653317\",\"0.16032064128256523\",\"0.1623246492985973\",\"0.16432865731462937\",\"0.16633266533066143\",\"0.1683366733466935\",\"0.17034068136272557\",\"0.17234468937875763\",\"0.1743486973947897\",\"0.17635270541082176\",\"0.17835671342685383\",\"0.1803607214428859\",\"0.18236472945891796\",\"0.18436873747495003\",\"0.18637274549098209\",\"0.18837675350701416\",\"0.19038076152304623\",\"0.19238476953907829\",\"0.19438877755511036\",\"0.19639278557114243\",\"0.19839679358717449\",\"0.20040080160320656\",\"0.20240480961923862\",\"0.20440881763527069\",\"0.20641282565130276\",\"0.20841683366733482\",\"0.21042084168336689\",\"0.21242484969939895\",\"0.21442885771543102\",\"0.21643286573146309\",\"0.21843687374749515\",\"0.22044088176352722\",\"0.22244488977955928\",\"0.22444889779559135\",\"0.22645290581162342\",\"0.22845691382765548\",\"0.23046092184368755\",\"0.23246492985971962\",\"0.23446893787575168\",\"0.23647294589178375\",\"0.23847695390781581\",\"0.24048096192384788\",\"0.24248496993987995\",\"0.24448897795591201\",\"0.24649298597194408\",\"0.24849699398797614\",\"0.25050100200400821\",\"0.25250501002004028\",\"0.25450901803607234\",\"0.25651302605210441\",\"0.25851703406813648\",\"0.26052104208416854\",\"0.26252505010020061\",\"0.26452905811623267\",\"0.26653306613226474\",\"0.26853707414829681\",\"0.27054108216432887\",\"0.27254509018036094\",\"0.274549098196393\",\"0.27655310621242507\",\"0.27855711422845714\",\"0.2805611222444892\",\"0.28256513026052127\",\"0.28456913827655334\",\"0.2865731462925854\",\"0.28857715430861747\",\"0.29058116232464953\",\"0.2925851703406816\",\"0.29458917835671367\",\"0.29659318637274573\",\"0.2985971943887778\",\"0.30060120240480986\",\"0.30260521042084193\",\"0.304609218436874\",\"0.30661322645290606\",\"0.30861723446893813\",\"0.31062124248497019\",\"0.31262525050100226\",\"0.31462925851703433\",\"0.31663326653306639\",\"0.31863727454909846\",\"0.32064128256513053\",\"0.32264529058116259\",\"0.32464929859719466\",\"0.32665330661322672\",\"0.32865731462925879\",\"0.33066132264529086\",\"0.33266533066132292\",\"0.33466933867735499\",\"0.33667334669338705\",\"0.33867735470941912\",\"0.34068136272545119\",\"0.34268537074148325\",\"0.34468937875751532\",\"0.34669338677354739\",\"0.34869739478957945\",\"0.35070140280561152\",\"0.35270541082164358\",\"0.35470941883767565\",\"0.35671342685370772\",\"0.35871743486973978\",\"0.36072144288577185\",\"0.36272545090180391\",\"0.36472945891783598\",\"0.36673346693386805\",\"0.36873747494990011\",\"0.37074148296593218\",\"0.37274549098196424\",\"0.37474949899799631\",\"0.37675350701402838\",\"0.37875751503006044\",\"0.38076152304609251\",\"0.38276553106212458\",\"0.38476953907815664\",\"0.38677354709418871\",\"0.38877755511022077\",\"0.39078156312625284\",\"0.39278557114228491\",\"0.39478957915831697\",\"0.39679358717434904\",\"0.3987975951903811\",\"0.40080160320641317\",\"0.40280561122244524\",\"0.4048096192384773\",\"0.40681362725450937\",\"0.40881763527054144\",\"0.4108216432865735\",\"0.41282565130260557\",\"0.41482965931863763\",\"0.4168336673346697\",\"0.41883767535070177\",\"0.42084168336673383\",\"0.4228456913827659\",\"0.42484969939879796\",\"0.42685370741483003\",\"0.4288577154308621\",\"0.43086172344689416\",\"0.43286573146292623\",\"0.43486973947895829\",\"0.43687374749499036\",\"0.43887775551102243\",\"0.44088176352705449\",\"0.44288577154308656\",\"0.44488977955911863\",\"0.44689378757515069\",\"0.44889779559118276\",\"0.45090180360721482\",\"0.45290581162324689\",\"0.45490981963927896\",\"0.45691382765531102\",\"0.45891783567134309\",\"0.46092184368737515\",\"0.46292585170340722\",\"0.46492985971943929\",\"0.46693386773547135\",\"0.46893787575150342\",\"0.47094188376753549\",\"0.47294589178356755\",\"0.47494989979959962\",\"0.47695390781563168\",\"0.47895791583166375\",\"0.48096192384769582\",\"0.48296593186372788\",\"0.48496993987975995\",\"0.48697394789579201\",\"0.48897795591182408\",\"0.49098196392785615\",\"0.49298597194388821\",\"0.49498997995992028\",\"0.49699398797595234\",\"0.49899799599198441\",\"0.50100200400801642\",\"0.50300601202404849\",\"0.50501002004008055\",\"0.50701402805611262\",\"0.50901803607214469\",\"0.51102204408817675\",\"0.51302605210420882\",\"0.51503006012024088\",\"0.51703406813627295\",\"0.51903807615230502\",\"0.52104208416833708\",\"0.52304609218436915\",\"0.52505010020040122\",\"0.52705410821643328\",\"0.52905811623246535\",\"0.53106212424849741\",\"0.53306613226452948\",\"0.53507014028056155\",\"0.53707414829659361\",\"0.53907815631262568\",\"0.54108216432865774\",\"0.54308617234468981\",\"0.54509018036072188\",\"0.54709418837675394\",\"0.54909819639278601\",\"0.55110220440881807\",\"0.55310621242485014\",\"0.55511022044088221\",\"0.55711422845691427\",\"0.55911823647294634\",\"0.56112224448897841\",\"0.56312625250501047\",\"0.56513026052104254\",\"0.5671342685370746\",\"0.56913827655310667\",\"0.57114228456913874\",\"0.5731462925851708\",\"0.57515030060120287\",\"0.57715430861723493\",\"0.579158316633267\",\"0.58116232464929907\",\"0.58316633266533113\",\"0.5851703406813632\",\"0.58717434869739527\",\"0.58917835671342733\",\"0.5911823647294594\",\"0.59318637274549146\",\"0.59519038076152353\",\"0.5971943887775556\",\"0.59919839679358766\",\"0.60120240480961973\",\"0.60320641282565179\",\"0.60521042084168386\",\"0.60721442885771593\",\"0.60921843687374799\",\"0.61122244488978006\",\"0.61322645290581212\",\"0.61523046092184419\",\"0.61723446893787626\",\"0.61923847695390832\",\"0.62124248496994039\",\"0.62324649298597246\",\"0.62525050100200452\",\"0.62725450901803659\",\"0.62925851703406865\",\"0.63126252505010072\",\"0.63326653306613279\",\"0.63527054108216485\",\"0.63727454909819692\",\"0.63927855711422898\",\"0.64128256513026105\",\"0.64328657314629312\",\"0.64529058116232518\",\"0.64729458917835725\",\"0.64929859719438932\",\"0.65130260521042138\",\"0.65330661322645345\",\"0.65531062124248551\",\"0.65731462925851758\",\"0.65931863727454965\",\"0.66132264529058171\",\"0.66332665330661378\",\"0.66533066132264584\",\"0.66733466933867791\",\"0.66933867735470998\",\"0.67134268537074204\",\"0.67334669338677411\",\"0.67535070140280618\",\"0.67735470941883824\",\"0.67935871743487031\",\"0.68136272545090237\",\"0.68336673346693444\",\"0.68537074148296651\",\"0.68737474949899857\",\"0.68937875751503064\",\"0.6913827655310627\",\"0.69338677354709477\",\"0.69539078156312684\",\"0.6973947895791589\",\"0.69939879759519097\",\"0.70140280561122303\",\"0.7034068136272551\",\"0.70541082164328717\",\"0.70741482965931923\",\"0.7094188376753513\",\"0.71142284569138337\",\"0.71342685370741543\",\"0.7154308617234475\",\"0.71743486973947956\",\"0.71943887775551163\",\"0.7214428857715437\",\"0.72344689378757576\",\"0.72545090180360783\",\"0.72745490981963989\",\"0.72945891783567196\",\"0.73146292585170403\",\"0.73346693386773609\",\"0.73547094188376816\",\"0.73747494989980023\",\"0.73947895791583229\",\"0.74148296593186436\",\"0.74348697394789642\",\"0.74549098196392849\",\"0.74749498997996056\",\"0.74949899799599262\",\"0.75150300601202469\",\"0.75350701402805675\",\"0.75551102204408882\",\"0.75751503006012089\",\"0.75951903807615295\",\"0.76152304609218502\",\"0.76352705410821708\",\"0.76553106212424915\",\"0.76753507014028122\",\"0.76953907815631328\",\"0.77154308617234535\",\"0.77354709418837742\",\"0.77555110220440948\",\"0.77755511022044155\",\"0.77955911823647361\",\"0.78156312625250568\",\"0.78356713426853775\",\"0.78557114228456981\",\"0.78757515030060188\",\"0.78957915831663394\",\"0.79158316633266601\",\"0.79358717434869808\",\"0.79559118236473014\",\"0.79759519038076221\",\"0.79959919839679428\",\"0.80160320641282634\",\"0.80360721442885841\",\"0.80561122244489047\",\"0.80761523046092254\",\"0.80961923847695461\",\"0.81162324649298667\",\"0.81362725450901874\",\"0.8156312625250508\",\"0.81763527054108287\",\"0.81963927855711494\",\"0.821643286573147\",\"0.82364729458917907\",\"0.82565130260521113\",\"0.8276553106212432\",\"0.82965931863727527\",\"0.83166332665330733\",\"0.8336673346693394\",\"0.83567134268537147\",\"0.83767535070140353\",\"0.8396793587174356\",\"0.84168336673346766\",\"0.84368737474949973\",\"0.8456913827655318\",\"0.84769539078156386\",\"0.84969939879759593\",\"0.85170340681362799\",\"0.85370741482966006\",\"0.85571142284569213\",\"0.85771543086172419\",\"0.85971943887775626\",\"0.86172344689378833\",\"0.86372745490982039\",\"0.86573146292585246\",\"0.86773547094188452\",\"0.86973947895791659\",\"0.87174348697394866\",\"0.87374749498998072\",\"0.87575150300601279\",\"0.87775551102204485\",\"0.87975951903807692\",\"0.88176352705410899\",\"0.88376753507014105\",\"0.88577154308617312\",\"0.88777555110220518\",\"0.88977955911823725\",\"0.89178356713426932\",\"0.89378757515030138\",\"0.89579158316633345\",\"0.89779559118236552\",\"0.89979959919839758\",\"0.90180360721442965\",\"0.90380761523046171\",\"0.90581162324649378\",\"0.90781563126252585\",\"0.90981963927855791\",\"0.91182364729458998\",\"0.91382765531062204\",\"0.91583166332665411\",\"0.91783567134268618\",\"0.91983967935871824\",\"0.92184368737475031\",\"0.92384769539078238\",\"0.92585170340681444\",\"0.92785571142284651\",\"0.92985971943887857\",\"0.93186372745491064\",\"0.93386773547094271\",\"0.93587174348697477\",\"0.93787575150300684\",\"0.9398797595190389\",\"0.94188376753507097\",\"0.94388777555110304\",\"0.9458917835671351\",\"0.94789579158316717\",\"0.94989979959919923\",\"0.9519038076152313\",\"0.95390781563126337\",\"0.95591182364729543\",\"0.9579158316633275\",\"0.95991983967935957\",\"0.96192384769539163\",\"0.9639278557114237\",\"0.96593186372745576\",\"0.96793587174348783\",\"0.9699398797595199\",\"0.97194388777555196\",\"0.97394789579158403\",\"0.97595190380761609\",\"0.97795591182364816\",\"0.97995991983968023\",\"0.98196392785571229\",\"0.98396793587174436\",\"0.98597194388777643\",\"0.98797595190380849\",\"0.98997995991984056\",\"0.99198396793587262\",\"0.99398797595190469\",\"0.99599198396793676\",\"0.99799599198396882\",\"1.0\"]; setTimeout(function() {\n    $('#slider-error-17').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 249,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-error-17-lbl').text(values[position]); interact(17, \"sage.server.notebook.interact.update(17, \\\"error\\\", 80, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-error-17-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-error-17-lbl').text(values[$('#slider-error-17').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">t_length&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-t_length-17' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-t_length-17-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.0\",\"0.20040080160320642\",\"0.40080160320641284\",\"0.60120240480961928\",\"0.80160320641282568\",\"1.0020040080160322\",\"1.2024048096192386\",\"1.402805611222445\",\"1.6032064128256514\",\"1.8036072144288577\",\"2.0040080160320644\",\"2.204408817635271\",\"2.4048096192384776\",\"2.6052104208416842\",\"2.8056112224448908\",\"3.0060120240480974\",\"3.206412825651304\",\"3.4068136272545106\",\"3.6072144288577173\",\"3.8076152304609239\",\"4.0080160320641305\",\"4.2084168336673367\",\"4.4088176352705428\",\"4.609218436873749\",\"4.8096192384769552\",\"5.0100200400801613\",\"5.2104208416833675\",\"5.4108216432865737\",\"5.6112224448897798\",\"5.811623246492986\",\"6.0120240480961922\",\"6.2124248496993983\",\"6.4128256513026045\",\"6.6132264529058107\",\"6.8136272545090169\",\"7.014028056112223\",\"7.2144288577154292\",\"7.4148296593186354\",\"7.6152304609218415\",\"7.8156312625250477\",\"8.0160320641282539\",\"8.2164328657314609\",\"8.416833667334668\",\"8.617234468937875\",\"8.8176352705410821\",\"9.0180360721442892\",\"9.2184368737474962\",\"9.4188376753507033\",\"9.6192384769539103\",\"9.8196392785571174\",\"10.020040080160324\",\"10.220440881763531\",\"10.420841683366739\",\"10.621242484969946\",\"10.821643286573153\",\"11.02204408817636\",\"11.222444889779567\",\"11.422845691382774\",\"11.623246492985981\",\"11.823647294589188\",\"12.024048096192395\",\"12.224448897795602\",\"12.424849699398809\",\"12.625250501002016\",\"12.825651302605223\",\"13.02605210420843\",\"13.226452905811637\",\"13.426853707414844\",\"13.627254509018051\",\"13.827655310621259\",\"14.028056112224466\",\"14.228456913827673\",\"14.42885771543088\",\"14.629258517034087\",\"14.829659318637294\",\"15.030060120240501\",\"15.230460921843708\",\"15.430861723446915\",\"15.631262525050122\",\"15.831663326653329\",\"16.032064128256536\",\"16.232464929859741\",\"16.432865731462947\",\"16.633266533066152\",\"16.833667334669357\",\"17.034068136272563\",\"17.234468937875768\",\"17.434869739478973\",\"17.635270541082178\",\"17.835671342685384\",\"18.036072144288589\",\"18.236472945891794\",\"18.436873747495\",\"18.637274549098205\",\"18.83767535070141\",\"19.038076152304615\",\"19.238476953907821\",\"19.438877755511026\",\"19.639278557114231\",\"19.839679358717436\",\"20.040080160320642\",\"20.240480961923847\",\"20.440881763527052\",\"20.641282565130258\",\"20.841683366733463\",\"21.042084168336668\",\"21.242484969939873\",\"21.442885771543079\",\"21.643286573146284\",\"21.843687374749489\",\"22.044088176352695\",\"22.2444889779559\",\"22.444889779559105\",\"22.64529058116231\",\"22.845691382765516\",\"23.046092184368721\",\"23.246492985971926\",\"23.446893787575132\",\"23.647294589178337\",\"23.847695390781542\",\"24.048096192384747\",\"24.248496993987953\",\"24.448897795591158\",\"24.649298597194363\",\"24.849699398797569\",\"25.050100200400774\",\"25.250501002003979\",\"25.450901803607184\",\"25.65130260521039\",\"25.851703406813595\",\"26.0521042084168\",\"26.252505010020005\",\"26.452905811623211\",\"26.653306613226416\",\"26.853707414829621\",\"27.054108216432827\",\"27.254509018036032\",\"27.454909819639237\",\"27.655310621242442\",\"27.855711422845648\",\"28.056112224448853\",\"28.256513026052058\",\"28.456913827655264\",\"28.657314629258469\",\"28.857715430861674\",\"29.058116232464879\",\"29.258517034068085\",\"29.45891783567129\",\"29.659318637274495\",\"29.859719438877701\",\"30.060120240480906\",\"30.260521042084111\",\"30.460921843687316\",\"30.661322645290522\",\"30.861723446893727\",\"31.062124248496932\",\"31.262525050100137\",\"31.462925851703343\",\"31.663326653306548\",\"31.863727454909753\",\"32.064128256512959\",\"32.264529058116167\",\"32.464929859719376\",\"32.665330661322585\",\"32.865731462925794\",\"33.066132264529003\",\"33.266533066132212\",\"33.46693386773542\",\"33.667334669338629\",\"33.867735470941838\",\"34.068136272545047\",\"34.268537074148256\",\"34.468937875751465\",\"34.669338677354673\",\"34.869739478957882\",\"35.070140280561091\",\"35.2705410821643\",\"35.470941883767509\",\"35.671342685370718\",\"35.871743486973926\",\"36.072144288577135\",\"36.272545090180344\",\"36.472945891783553\",\"36.673346693386762\",\"36.873747494989971\",\"37.074148296593179\",\"37.274549098196388\",\"37.474949899799597\",\"37.675350701402806\",\"37.875751503006015\",\"38.076152304609224\",\"38.276553106212432\",\"38.476953907815641\",\"38.67735470941885\",\"38.877755511022059\",\"39.078156312625268\",\"39.278557114228477\",\"39.478957915831685\",\"39.679358717434894\",\"39.879759519038103\",\"40.080160320641312\",\"40.280561122244521\",\"40.48096192384773\",\"40.681362725450938\",\"40.881763527054147\",\"41.082164328657356\",\"41.282565130260565\",\"41.482965931863774\",\"41.683366733466983\",\"41.883767535070191\",\"42.0841683366734\",\"42.284569138276609\",\"42.484969939879818\",\"42.685370741483027\",\"42.885771543086236\",\"43.086172344689444\",\"43.286573146292653\",\"43.486973947895862\",\"43.687374749499071\",\"43.88777555110228\",\"44.088176352705489\",\"44.288577154308697\",\"44.488977955911906\",\"44.689378757515115\",\"44.889779559118324\",\"45.090180360721533\",\"45.290581162324742\",\"45.49098196392795\",\"45.691382765531159\",\"45.891783567134368\",\"46.092184368737577\",\"46.292585170340786\",\"46.492985971943995\",\"46.693386773547203\",\"46.893787575150412\",\"47.094188376753621\",\"47.29458917835683\",\"47.494989979960039\",\"47.695390781563248\",\"47.895791583166456\",\"48.096192384769665\",\"48.296593186372874\",\"48.496993987976083\",\"48.697394789579292\",\"48.897795591182501\",\"49.098196392785709\",\"49.298597194388918\",\"49.498997995992127\",\"49.699398797595336\",\"49.899799599198545\",\"50.100200400801754\",\"50.300601202404962\",\"50.501002004008171\",\"50.70140280561138\",\"50.901803607214589\",\"51.102204408817798\",\"51.302605210421007\",\"51.503006012024215\",\"51.703406813627424\",\"51.903807615230633\",\"52.104208416833842\",\"52.304609218437051\",\"52.50501002004026\",\"52.705410821643468\",\"52.905811623246677\",\"53.106212424849886\",\"53.306613226453095\",\"53.507014028056304\",\"53.707414829659513\",\"53.907815631262721\",\"54.10821643286593\",\"54.308617234469139\",\"54.509018036072348\",\"54.709418837675557\",\"54.909819639278766\",\"55.110220440881974\",\"55.310621242485183\",\"55.511022044088392\",\"55.711422845691601\",\"55.91182364729481\",\"56.112224448898019\",\"56.312625250501227\",\"56.513026052104436\",\"56.713426853707645\",\"56.913827655310854\",\"57.114228456914063\",\"57.314629258517272\",\"57.51503006012048\",\"57.715430861723689\",\"57.915831663326898\",\"58.116232464930107\",\"58.316633266533316\",\"58.517034068136525\",\"58.717434869739733\",\"58.917835671342942\",\"59.118236472946151\",\"59.31863727454936\",\"59.519038076152569\",\"59.719438877755778\",\"59.919839679358986\",\"60.120240480962195\",\"60.320641282565404\",\"60.521042084168613\",\"60.721442885771822\",\"60.921843687375031\",\"61.122244488978239\",\"61.322645290581448\",\"61.523046092184657\",\"61.723446893787866\",\"61.923847695391075\",\"62.124248496994284\",\"62.324649298597492\",\"62.525050100200701\",\"62.72545090180391\",\"62.925851703407119\",\"63.126252505010328\",\"63.326653306613537\",\"63.527054108216745\",\"63.727454909819954\",\"63.927855711423163\",\"64.128256513026372\",\"64.328657314629581\",\"64.52905811623279\",\"64.729458917835998\",\"64.929859719439207\",\"65.130260521042416\",\"65.330661322645625\",\"65.531062124248834\",\"65.731462925852043\",\"65.931863727455251\",\"66.13226452905846\",\"66.332665330661669\",\"66.533066132264878\",\"66.733466933868087\",\"66.933867735471296\",\"67.134268537074504\",\"67.334669338677713\",\"67.535070140280922\",\"67.735470941884131\",\"67.93587174348734\",\"68.136272545090549\",\"68.336673346693757\",\"68.537074148296966\",\"68.737474949900175\",\"68.937875751503384\",\"69.138276553106593\",\"69.338677354709802\",\"69.53907815631301\",\"69.739478957916219\",\"69.939879759519428\",\"70.140280561122637\",\"70.340681362725846\",\"70.541082164329055\",\"70.741482965932263\",\"70.941883767535472\",\"71.142284569138681\",\"71.34268537074189\",\"71.543086172345099\",\"71.743486973948308\",\"71.943887775551516\",\"72.144288577154725\",\"72.344689378757934\",\"72.545090180361143\",\"72.745490981964352\",\"72.945891783567561\",\"73.146292585170769\",\"73.346693386773978\",\"73.547094188377187\",\"73.747494989980396\",\"73.947895791583605\",\"74.148296593186814\",\"74.348697394790022\",\"74.549098196393231\",\"74.74949899799644\",\"74.949899799599649\",\"75.150300601202858\",\"75.350701402806067\",\"75.551102204409275\",\"75.751503006012484\",\"75.951903807615693\",\"76.152304609218902\",\"76.352705410822111\",\"76.55310621242532\",\"76.753507014028528\",\"76.953907815631737\",\"77.154308617234946\",\"77.354709418838155\",\"77.555110220441364\",\"77.755511022044573\",\"77.955911823647781\",\"78.15631262525099\",\"78.356713426854199\",\"78.557114228457408\",\"78.757515030060617\",\"78.957915831663826\",\"79.158316633267034\",\"79.358717434870243\",\"79.559118236473452\",\"79.759519038076661\",\"79.95991983967987\",\"80.160320641283079\",\"80.360721442886287\",\"80.561122244489496\",\"80.761523046092705\",\"80.961923847695914\",\"81.162324649299123\",\"81.362725450902332\",\"81.56312625250554\",\"81.763527054108749\",\"81.963927855711958\",\"82.164328657315167\",\"82.364729458918376\",\"82.565130260521585\",\"82.765531062124793\",\"82.965931863728002\",\"83.166332665331211\",\"83.36673346693442\",\"83.567134268537629\",\"83.767535070140838\",\"83.967935871744046\",\"84.168336673347255\",\"84.368737474950464\",\"84.569138276553673\",\"84.769539078156882\",\"84.969939879760091\",\"85.170340681363299\",\"85.370741482966508\",\"85.571142284569717\",\"85.771543086172926\",\"85.971943887776135\",\"86.172344689379344\",\"86.372745490982552\",\"86.573146292585761\",\"86.77354709418897\",\"86.973947895792179\",\"87.174348697395388\",\"87.374749498998597\",\"87.575150300601805\",\"87.775551102205014\",\"87.975951903808223\",\"88.176352705411432\",\"88.376753507014641\",\"88.57715430861785\",\"88.777555110221058\",\"88.977955911824267\",\"89.178356713427476\",\"89.378757515030685\",\"89.579158316633894\",\"89.779559118237103\",\"89.979959919840311\",\"90.18036072144352\",\"90.380761523046729\",\"90.581162324649938\",\"90.781563126253147\",\"90.981963927856356\",\"91.182364729459565\",\"91.382765531062773\",\"91.583166332665982\",\"91.783567134269191\",\"91.9839679358724\",\"92.184368737475609\",\"92.384769539078818\",\"92.585170340682026\",\"92.785571142285235\",\"92.985971943888444\",\"93.186372745491653\",\"93.386773547094862\",\"93.587174348698071\",\"93.787575150301279\",\"93.987975951904488\",\"94.188376753507697\",\"94.388777555110906\",\"94.589178356714115\",\"94.789579158317324\",\"94.989979959920532\",\"95.190380761523741\",\"95.39078156312695\",\"95.591182364730159\",\"95.791583166333368\",\"95.991983967936577\",\"96.192384769539785\",\"96.392785571142994\",\"96.593186372746203\",\"96.793587174349412\",\"96.993987975952621\",\"97.19438877755583\",\"97.394789579159038\",\"97.595190380762247\",\"97.795591182365456\",\"97.995991983968665\",\"98.196392785571874\",\"98.396793587175083\",\"98.597194388778291\",\"98.7975951903815\",\"98.997995991984709\",\"99.198396793587918\",\"99.398797595191127\",\"99.599198396794336\",\"99.799599198397544\",\"100.0\"]; setTimeout(function() {\n    $('#slider-t_length-17').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 115,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-t_length-17-lbl').text(values[position]); interact(17, \"sage.server.notebook.interact.update(17, \\\"t_length\\\", 81, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-t_length-17-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-t_length-17-lbl').text(values[$('#slider-t_length-17').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">num_of_points&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-num_of_points-17' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-num_of_points-17-lbl'></font></td></tr></table><script>(function(){ var values = [\"5.0\",\"8.9979959919839683\",\"12.995991983967937\",\"16.993987975951903\",\"20.99198396793587\",\"24.989979959919836\",\"28.987975951903802\",\"32.985971943887769\",\"36.983967935871739\",\"40.981963927855709\",\"44.979959919839679\",\"48.977955911823649\",\"52.975951903807619\",\"56.973947895791589\",\"60.971943887775559\",\"64.969939879759522\",\"68.967935871743492\",\"72.965931863727462\",\"76.963927855711432\",\"80.961923847695402\",\"84.959919839679372\",\"88.957915831663342\",\"92.955911823647313\",\"96.953907815631283\",\"100.95190380761525\",\"104.94989979959922\",\"108.94789579158319\",\"112.94589178356716\",\"116.94388777555113\",\"120.9418837675351\",\"124.93987975951907\",\"128.93787575150304\",\"132.93587174348701\",\"136.93386773547098\",\"140.93186372745495\",\"144.92985971943892\",\"148.92785571142289\",\"152.92585170340686\",\"156.92384769539083\",\"160.9218436873748\",\"164.91983967935877\",\"168.91783567134274\",\"172.91583166332671\",\"176.91382765531068\",\"180.91182364729465\",\"184.90981963927862\",\"188.90781563126259\",\"192.90581162324656\",\"196.90380761523053\",\"200.9018036072145\",\"204.89979959919847\",\"208.89779559118244\",\"212.89579158316641\",\"216.89378757515038\",\"220.89178356713435\",\"224.88977955911832\",\"228.88777555110229\",\"232.88577154308626\",\"236.88376753507023\",\"240.8817635270542\",\"244.87975951903817\",\"248.87775551102214\",\"252.87575150300611\",\"256.87374749499008\",\"260.87174348697403\",\"264.86973947895797\",\"268.86773547094191\",\"272.86573146292585\",\"276.86372745490979\",\"280.86172344689373\",\"284.85971943887768\",\"288.85771543086162\",\"292.85571142284556\",\"296.8537074148295\",\"300.85170340681344\",\"304.84969939879738\",\"308.84769539078133\",\"312.84569138276527\",\"316.84368737474921\",\"320.84168336673315\",\"324.83967935871709\",\"328.83767535070103\",\"332.83567134268498\",\"336.83366733466892\",\"340.83166332665286\",\"344.8296593186368\",\"348.82765531062074\",\"352.82565130260468\",\"356.82364729458862\",\"360.82164328657257\",\"364.81963927855651\",\"368.81763527054045\",\"372.81563126252439\",\"376.81362725450833\",\"380.81162324649227\",\"384.80961923847622\",\"388.80761523046016\",\"392.8056112224441\",\"396.80360721442804\",\"400.80160320641198\",\"404.79959919839592\",\"408.79759519037987\",\"412.79559118236381\",\"416.79358717434775\",\"420.79158316633169\",\"424.78957915831563\",\"428.78757515029957\",\"432.78557114228352\",\"436.78356713426746\",\"440.7815631262514\",\"444.77955911823534\",\"448.77755511021928\",\"452.77555110220322\",\"456.77354709418717\",\"460.77154308617111\",\"464.76953907815505\",\"468.76753507013899\",\"472.76553106212293\",\"476.76352705410687\",\"480.76152304609082\",\"484.75951903807476\",\"488.7575150300587\",\"492.75551102204264\",\"496.75350701402658\",\"500.75150300601052\",\"504.74949899799446\",\"508.74749498997841\",\"512.74549098196235\",\"516.74348697394635\",\"520.74148296593035\",\"524.73947895791434\",\"528.73747494989834\",\"532.73547094188234\",\"536.73346693386634\",\"540.73146292585034\",\"544.72945891783434\",\"548.72745490981833\",\"552.72545090180233\",\"556.72344689378633\",\"560.72144288577033\",\"564.71943887775433\",\"568.71743486973833\",\"572.71543086172233\",\"576.71342685370632\",\"580.71142284569032\",\"584.70941883767432\",\"588.70741482965832\",\"592.70541082164232\",\"596.70340681362632\",\"600.70140280561031\",\"604.69939879759431\",\"608.69739478957831\",\"612.69539078156231\",\"616.69338677354631\",\"620.69138276553031\",\"624.68937875751431\",\"628.6873747494983\",\"632.6853707414823\",\"636.6833667334663\",\"640.6813627254503\",\"644.6793587174343\",\"648.6773547094183\",\"652.67535070140229\",\"656.67334669338629\",\"660.67134268537029\",\"664.66933867735429\",\"668.66733466933829\",\"672.66533066132229\",\"676.66332665330629\",\"680.66132264529028\",\"684.65931863727428\",\"688.65731462925828\",\"692.65531062124228\",\"696.65330661322628\",\"700.65130260521028\",\"704.64929859719427\",\"708.64729458917827\",\"712.64529058116227\",\"716.64328657314627\",\"720.64128256513027\",\"724.63927855711427\",\"728.63727454909827\",\"732.63527054108226\",\"736.63326653306626\",\"740.63126252505026\",\"744.62925851703426\",\"748.62725450901826\",\"752.62525050100226\",\"756.62324649298625\",\"760.62124248497025\",\"764.61923847695425\",\"768.61723446893825\",\"772.61523046092225\",\"776.61322645290625\",\"780.61122244489025\",\"784.60921843687424\",\"788.60721442885824\",\"792.60521042084224\",\"796.60320641282624\",\"800.60120240481024\",\"804.59919839679424\",\"808.59719438877823\",\"812.59519038076223\",\"816.59318637274623\",\"820.59118236473023\",\"824.58917835671423\",\"828.58717434869823\",\"832.58517034068223\",\"836.58316633266622\",\"840.58116232465022\",\"844.57915831663422\",\"848.57715430861822\",\"852.57515030060222\",\"856.57314629258622\",\"860.57114228457021\",\"864.56913827655421\",\"868.56713426853821\",\"872.56513026052221\",\"876.56312625250621\",\"880.56112224449021\",\"884.55911823647421\",\"888.5571142284582\",\"892.5551102204422\",\"896.5531062124262\",\"900.5511022044102\",\"904.5490981963942\",\"908.5470941883782\",\"912.54509018036219\",\"916.54308617234619\",\"920.54108216433019\",\"924.53907815631419\",\"928.53707414829819\",\"932.53507014028219\",\"936.53306613226619\",\"940.53106212425018\",\"944.52905811623418\",\"948.52705410821818\",\"952.52505010020218\",\"956.52304609218618\",\"960.52104208417018\",\"964.51903807615417\",\"968.51703406813817\",\"972.51503006012217\",\"976.51302605210617\",\"980.51102204409017\",\"984.50901803607417\",\"988.50701402805817\",\"992.50501002004216\",\"996.50300601202616\",\"1000.5010020040102\",\"1004.4989979959942\",\"1008.4969939879782\",\"1012.4949899799622\",\"1016.4929859719462\",\"1020.4909819639302\",\"1024.4889779559142\",\"1028.4869739478982\",\"1032.4849699398821\",\"1036.4829659318661\",\"1040.4809619238501\",\"1044.4789579158341\",\"1048.4769539078181\",\"1052.4749498998021\",\"1056.4729458917861\",\"1060.4709418837701\",\"1064.4689378757541\",\"1068.4669338677381\",\"1072.4649298597221\",\"1076.4629258517061\",\"1080.4609218436901\",\"1084.4589178356741\",\"1088.4569138276581\",\"1092.4549098196421\",\"1096.4529058116261\",\"1100.4509018036101\",\"1104.4488977955941\",\"1108.4468937875781\",\"1112.4448897795621\",\"1116.4428857715461\",\"1120.4408817635301\",\"1124.4388777555141\",\"1128.4368737474981\",\"1132.4348697394821\",\"1136.4328657314661\",\"1140.4308617234501\",\"1144.4288577154341\",\"1148.4268537074181\",\"1152.4248496994021\",\"1156.4228456913861\",\"1160.4208416833701\",\"1164.4188376753541\",\"1168.4168336673381\",\"1172.4148296593221\",\"1176.4128256513061\",\"1180.4108216432901\",\"1184.4088176352741\",\"1188.4068136272581\",\"1192.4048096192421\",\"1196.4028056112261\",\"1200.4008016032101\",\"1204.3987975951941\",\"1208.3967935871781\",\"1212.3947895791621\",\"1216.3927855711461\",\"1220.3907815631301\",\"1224.3887775551141\",\"1228.3867735470981\",\"1232.3847695390821\",\"1236.3827655310661\",\"1240.3807615230501\",\"1244.3787575150341\",\"1248.3767535070181\",\"1252.3747494990021\",\"1256.3727454909861\",\"1260.3707414829701\",\"1264.3687374749541\",\"1268.3667334669381\",\"1272.3647294589221\",\"1276.3627254509061\",\"1280.3607214428901\",\"1284.3587174348741\",\"1288.3567134268581\",\"1292.354709418842\",\"1296.352705410826\",\"1300.35070140281\",\"1304.348697394794\",\"1308.346693386778\",\"1312.344689378762\",\"1316.342685370746\",\"1320.34068136273\",\"1324.338677354714\",\"1328.336673346698\",\"1332.334669338682\",\"1336.332665330666\",\"1340.33066132265\",\"1344.328657314634\",\"1348.326653306618\",\"1352.324649298602\",\"1356.322645290586\",\"1360.32064128257\",\"1364.318637274554\",\"1368.316633266538\",\"1372.314629258522\",\"1376.312625250506\",\"1380.31062124249\",\"1384.308617234474\",\"1388.306613226458\",\"1392.304609218442\",\"1396.302605210426\",\"1400.30060120241\",\"1404.298597194394\",\"1408.296593186378\",\"1412.294589178362\",\"1416.292585170346\",\"1420.29058116233\",\"1424.288577154314\",\"1428.286573146298\",\"1432.284569138282\",\"1436.282565130266\",\"1440.28056112225\",\"1444.278557114234\",\"1448.276553106218\",\"1452.274549098202\",\"1456.272545090186\",\"1460.27054108217\",\"1464.268537074154\",\"1468.266533066138\",\"1472.264529058122\",\"1476.262525050106\",\"1480.26052104209\",\"1484.258517034074\",\"1488.256513026058\",\"1492.254509018042\",\"1496.252505010026\",\"1500.25050100201\",\"1504.248496993994\",\"1508.246492985978\",\"1512.244488977962\",\"1516.242484969946\",\"1520.24048096193\",\"1524.238476953914\",\"1528.236472945898\",\"1532.234468937882\",\"1536.232464929866\",\"1540.23046092185\",\"1544.228456913834\",\"1548.226452905818\",\"1552.2244488978019\",\"1556.2224448897859\",\"1560.2204408817699\",\"1564.2184368737539\",\"1568.2164328657379\",\"1572.2144288577219\",\"1576.2124248497059\",\"1580.2104208416899\",\"1584.2084168336739\",\"1588.2064128256579\",\"1592.2044088176419\",\"1596.2024048096259\",\"1600.2004008016099\",\"1604.1983967935939\",\"1608.1963927855779\",\"1612.1943887775619\",\"1616.1923847695459\",\"1620.1903807615299\",\"1624.1883767535139\",\"1628.1863727454979\",\"1632.1843687374819\",\"1636.1823647294659\",\"1640.1803607214499\",\"1644.1783567134339\",\"1648.1763527054179\",\"1652.1743486974019\",\"1656.1723446893859\",\"1660.1703406813699\",\"1664.1683366733539\",\"1668.1663326653379\",\"1672.1643286573219\",\"1676.1623246493059\",\"1680.1603206412899\",\"1684.1583166332739\",\"1688.1563126252579\",\"1692.1543086172419\",\"1696.1523046092259\",\"1700.1503006012099\",\"1704.1482965931939\",\"1708.1462925851779\",\"1712.1442885771619\",\"1716.1422845691459\",\"1720.1402805611299\",\"1724.1382765531139\",\"1728.1362725450979\",\"1732.1342685370819\",\"1736.1322645290659\",\"1740.1302605210499\",\"1744.1282565130339\",\"1748.1262525050179\",\"1752.1242484970019\",\"1756.1222444889859\",\"1760.1202404809699\",\"1764.1182364729539\",\"1768.1162324649379\",\"1772.1142284569219\",\"1776.1122244489059\",\"1780.1102204408899\",\"1784.1082164328739\",\"1788.1062124248579\",\"1792.1042084168419\",\"1796.1022044088259\",\"1800.1002004008099\",\"1804.0981963927939\",\"1808.0961923847779\",\"1812.0941883767618\",\"1816.0921843687458\",\"1820.0901803607298\",\"1824.0881763527138\",\"1828.0861723446978\",\"1832.0841683366818\",\"1836.0821643286658\",\"1840.0801603206498\",\"1844.0781563126338\",\"1848.0761523046178\",\"1852.0741482966018\",\"1856.0721442885858\",\"1860.0701402805698\",\"1864.0681362725538\",\"1868.0661322645378\",\"1872.0641282565218\",\"1876.0621242485058\",\"1880.0601202404898\",\"1884.0581162324738\",\"1888.0561122244578\",\"1892.0541082164418\",\"1896.0521042084258\",\"1900.0501002004098\",\"1904.0480961923938\",\"1908.0460921843778\",\"1912.0440881763618\",\"1916.0420841683458\",\"1920.0400801603298\",\"1924.0380761523138\",\"1928.0360721442978\",\"1932.0340681362818\",\"1936.0320641282658\",\"1940.0300601202498\",\"1944.0280561122338\",\"1948.0260521042178\",\"1952.0240480962018\",\"1956.0220440881858\",\"1960.0200400801698\",\"1964.0180360721538\",\"1968.0160320641378\",\"1972.0140280561218\",\"1976.0120240481058\",\"1980.0100200400898\",\"1984.0080160320738\",\"1988.0060120240578\",\"1992.0040080160418\",\"1996.0020040080258\",\"2000.0\"]; setTimeout(function() {\n    $('#slider-num_of_points-17').slider({\n    \tstepping: 1, min: 0, max: 499, startValue: 374,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-num_of_points-17-lbl').text(values[position]); interact(17, \"sage.server.notebook.interact.update(17, \\\"num_of_points\\\", 82, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-num_of_points-17-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-num_of_points-17-lbl').text(values[$('#slider-num_of_points-17').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">algorithm&nbsp;</font></td><td><select onchange='interact(17, \"sage.server.notebook.interact.update(17, \\\"algorithm\\\", 83, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.options[this.selectedIndex].value)+\"\\\"), globals());sage.server.notebook.interact.recompute(17)\");'><option value='0' selected>'runga-kutta-felhberg (4,5)'</option>\n<option value='1' >'embedded runga-kutta (2,3)'</option>\n<option value='2' >'4th order classical runga-kutta'</option>\n<option value='3' >'runga-kutta prince-dormand (8,9)'</option>\n<option value='4' >'implicit 2nd order runga-kutta at gaussian points'</option>\n<option value='5' >'implicit 4th order runga-kutta at gaussian points'</option>\n<option value='6' >'implicit burlisch-stoer (requires jacobian)'</option>\n<option value='7' >'M=1 implicit gear'</option>\n<option value='8' >'M=2 implicit gear'</option>\n</select></td></tr>\n</table><div id='cell-interact-17'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
︠dc686424-e1ca-4134-bf70-9f09da23bc08︠
def cobweb(a_function, start, mask = 0, iterations = 20, xmin = 0, xmax = 1):
    '''
    Returns a graphics object of a plot of the function and a cobweb trajectory starting from the value start.

    INPUT:
        a_function: a function of one variable
        start: the starting value of the iteration
        mask: (optional) the number of initial iterates to ignore
        iterations: (optional) the number of iterations to draw, following the masked iterations
        xmin: (optional) the lower end of the plotted interval
        xmax: (optional) the upper end of the plotted interval
    
    EXAMPLES:
        sage: f = lambda x: 3.9*x*(1-x)
        sage: show(cobweb(f,.01,iterations=200), xmin = 0, xmax = 1, ymin=0)
    
    '''
    basic_plot = plot(a_function, xmin = xmin, xmax = xmax)
    id_plot = plot(lambda x: x, xmin = xmin, xmax = xmax)
    iter_list = []
    current = start
    for i in range(mask):
        current = a_function(current)
    for i in range(iterations):
        iter_list.append([current,a_function(current)])
        current = a_function(current)
        iter_list.append([current,current])
    cobweb = line(iter_list, rgbcolor = (1,0,0))
    return basic_plot + id_plot + cobweb
var('x')
@interact
def cobwebber(f_text = input_box(default = "3.8*x*(1-x)",label = "function", type=str), start_val = slider(0,1,.01,.5,label = 'start value'), its = slider([2^i for i in range(0,12)],default = 16, label="iterations")):
    def f(x):
        return eval(f_text)
    show(cobweb(f, start_val, iterations = its))
︡21a3ae1b-5d75-4a39-b937-9ce352b6e4bb︡{"html": "<!--notruncate--><div padding=6 id='div-interact-19'> <table width=800px height=20px bgcolor='#c5c5c5'\n                 cellpadding=15><tr><td bgcolor='#f9f9f9' valign=top align=left><table><tr><td align=right><font color=\"black\">function&nbsp;</font></td><td><input type='text' value=\"3.8*x*(1-x)\" size=80 onchange='interact(19, \"sage.server.notebook.interact.update(19, \\\"f_text\\\", 91, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(this.value)+\"\\\"), globals());sage.server.notebook.interact.recompute(19)\")'></input></td></tr>\n<tr><td align=right><font color=\"black\">start value&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-start_val-19' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-start_val-19-lbl'></font></td></tr></table><script>(function(){ var values = [\"0.000000000000000\",\"0.0100000000000000\",\"0.0200000000000000\",\"0.0300000000000000\",\"0.0400000000000000\",\"0.0500000000000000\",\"0.0600000000000000\",\"0.0700000000000000\",\"0.0800000000000000\",\"0.0900000000000000\",\"0.100000000000000\",\"0.110000000000000\",\"0.120000000000000\",\"0.130000000000000\",\"0.140000000000000\",\"0.150000000000000\",\"0.160000000000000\",\"0.170000000000000\",\"0.180000000000000\",\"0.190000000000000\",\"0.200000000000000\",\"0.210000000000000\",\"0.220000000000000\",\"0.230000000000000\",\"0.240000000000000\",\"0.250000000000000\",\"0.260000000000000\",\"0.270000000000000\",\"0.280000000000000\",\"0.290000000000000\",\"0.300000000000000\",\"0.310000000000000\",\"0.320000000000000\",\"0.330000000000000\",\"0.340000000000000\",\"0.350000000000000\",\"0.360000000000000\",\"0.370000000000000\",\"0.380000000000000\",\"0.390000000000000\",\"0.400000000000000\",\"0.410000000000000\",\"0.420000000000000\",\"0.430000000000000\",\"0.440000000000000\",\"0.450000000000000\",\"0.460000000000000\",\"0.470000000000000\",\"0.480000000000000\",\"0.490000000000000\",\"0.500000000000000\",\"0.510000000000000\",\"0.520000000000000\",\"0.530000000000000\",\"0.540000000000000\",\"0.550000000000000\",\"0.560000000000000\",\"0.570000000000000\",\"0.580000000000000\",\"0.590000000000000\",\"0.600000000000000\",\"0.610000000000000\",\"0.620000000000000\",\"0.630000000000000\",\"0.640000000000000\",\"0.650000000000000\",\"0.660000000000000\",\"0.670000000000000\",\"0.680000000000000\",\"0.690000000000000\",\"0.700000000000000\",\"0.710000000000000\",\"0.720000000000000\",\"0.730000000000000\",\"0.740000000000000\",\"0.750000000000000\",\"0.760000000000000\",\"0.770000000000000\",\"0.780000000000000\",\"0.790000000000000\",\"0.800000000000000\",\"0.810000000000000\",\"0.820000000000001\",\"0.830000000000001\",\"0.840000000000001\",\"0.850000000000001\",\"0.860000000000001\",\"0.870000000000001\",\"0.880000000000001\",\"0.890000000000001\",\"0.900000000000001\",\"0.910000000000001\",\"0.920000000000001\",\"0.930000000000001\",\"0.940000000000001\",\"0.950000000000001\",\"0.960000000000001\",\"0.970000000000001\",\"0.980000000000001\",\"0.990000000000001\",\"1.00000000000000\"]; setTimeout(function() {\n    $('#slider-start_val-19').slider({\n    \tstepping: 1, min: 0, max: 100, startValue: 50,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-start_val-19-lbl').text(values[position]); interact(19, \"sage.server.notebook.interact.update(19, \\\"start_val\\\", 92, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(19)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-start_val-19-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-start_val-19-lbl').text(values[$('#slider-start_val-19').slider('value')]);\n    }, 1); })();</script></td></tr>\n<tr><td align=right><font color=\"black\">iterations&nbsp;</font></td><td><table><tr><td>\n    \t<div id='slider-its-19' class='ui-slider ui-slider-3' style='margin:0px;'><span class='ui-slider-handle'></span></div>\n    \t</td><td><font color='black' id='slider-its-19-lbl'></font></td></tr></table><script>(function(){ var values = [\"1\",\"2\",\"4\",\"8\",\"16\",\"32\",\"64\",\"128\",\"256\",\"512\",\"1024\",\"2048\"]; setTimeout(function() {\n    $('#slider-its-19').slider({\n    \tstepping: 1, min: 0, max: 11, startValue: 4,\n    \tchange: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-its-19-lbl').text(values[position]); interact(19, \"sage.server.notebook.interact.update(19, \\\"its\\\", 93, sage.server.notebook.interact.standard_b64decode(\\\"\"+encode64(position)+\"\\\"), globals());sage.server.notebook.interact.recompute(19)\"); },\n    \tslide: function(e,ui) { if(values!=null) $('#slider-its-19-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-its-19-lbl').text(values[$('#slider-its-19').slider('value')]);\n    }, 1); })();</script></td></tr>\n</table><div id='cell-interact-19'><?__SAGE__START>\n        <table border=0 bgcolor='#white' width=100% height=100%>\n        <tr><td bgcolor=white align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td>\n                 </tr></table></div>\n                 "}︡
